package codeflies.com.mcc.Activity

import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.BrandAdapter
import codeflies.com.mcc.Adapter.OnBrandClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.BrandModel
import codeflies.com.mcc.Model.BrandPojo
import codeflies.com.mcc.databinding.ActivityBrandBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class BrandActivity : AppCompatActivity(), OnBrandClickListener {

    private lateinit var binding: ActivityBrandBinding
    private lateinit var sharedPreference: SharedPreference
    private lateinit var brandAdapter: BrandAdapter
    private lateinit var brandList: List<BrandPojo>
    private lateinit var progressDisplay: ProgressDisplay

    private fun validation(): Boolean {
        if (binding.otherbrandName.text.length == 0) {
            SnackBarUtils.showTopSnackbar(this@BrandActivity, "Please Enter Car Brand!", Color.RED)
            binding.otherbrandName.requestFocus()
            return false
        }
        return true
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityBrandBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@BrandActivity)
        sharedPreference = SharedPreference(this@BrandActivity)


        binding.brandSearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                brandAdapter.filter.filter(newText)
            }
        })



        progressDisplay.show()
        getBrand()
        binding.back.setOnClickListener {
            finish()
        }

        binding.submitBrand.setOnClickListener {
            if (validation()) {
                val resultIntent = Intent()
                resultIntent.putExtra(
                    "brandInfo",
                    binding.otherbrandName.text.toString() + "," + "0" + "," + "other"
                )
                setResult(Activity.RESULT_OK, resultIntent)
                finish()
            }
        }
    }

    private fun getBrand() {
        var token = sharedPreference.getData("token").toString()


        val countryCall = RetrofitClient.apiService.brandGet("Bearer $token")

        countryCall.enqueue(object : Callback<BrandModel> {
            override fun onResponse(call: Call<BrandModel>, response: Response<BrandModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        brandList = apiResponse.data

                        // Create a mutable copy of the original list
                        val modifiedDataList = brandList.toMutableList()

                        // Add the additional item
                        val additionalBrand = BrandPojo(id = -1, name = "Other")
                        modifiedDataList.add(additionalBrand)


                        brandAdapter = BrandAdapter(modifiedDataList, this@BrandActivity)
                        binding.brandRcy.adapter = brandAdapter
                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@BrandActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@BrandActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@BrandActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<BrandModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@BrandActivity, t.message.toString(), Color.RED)
            }
        })

    }

    override fun onBrandClick(brandPojo: BrandPojo) {
        if (brandPojo.name.equals("Other")) {
            binding.brandRcy.visibility = View.GONE
            binding.brandOther.visibility = View.VISIBLE


        } else {
            val resultIntent = Intent()
            resultIntent.putExtra("brandInfo", brandPojo.name + "," + brandPojo.id + "," + "")
            setResult(Activity.RESULT_OK, resultIntent)
            finish()
        }
    }
}