package codeflies.com.mcc.Activity

import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.ModelAdapter
import codeflies.com.mcc.Adapter.OnModelClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.BrandModelData
import codeflies.com.mcc.Model.BrandModelPojo
import codeflies.com.mcc.databinding.ActivityBrandModelBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class BrandModelActivity : AppCompatActivity(), OnModelClickListener {

    private lateinit var binding: ActivityBrandModelBinding
    private lateinit var sharedPreference: SharedPreference
    private lateinit var modelAdapter: ModelAdapter
    private lateinit var modelList: List<BrandModelPojo>
    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityBrandModelBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@BrandModelActivity)
        sharedPreference = SharedPreference(this@BrandModelActivity)


        binding.modelSearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                modelAdapter.filter.filter(newText)
            }
        })


        progressDisplay.show()
        getBrand()

        binding.back.setOnClickListener {
            finish()
        }

        binding.submitModel.setOnClickListener {
            if (validation()) {
                val resultIntent = Intent()
                resultIntent.putExtra(
                    "modelInfo",
                    binding.otherModelName.text.toString() + "," + "0"+ "," + "other"
                )
                setResult(Activity.RESULT_OK, resultIntent)
                finish()
            }
        }

    }

    private fun validation(): Boolean {
        if (binding.otherModelName.text.length == 0) {
            SnackBarUtils.showTopSnackbar(
                this@BrandModelActivity,
                "Please Enter Car Model!",
                Color.RED
            )
            binding.otherModelName.requestFocus()
            return false
        }
        return true
    }


    private fun getBrand() {
        var token = sharedPreference.getData("token").toString()

        val brandId = intent.getIntExtra("brandId", 0)

        val countryCall = RetrofitClient.apiService.modelGet("Bearer $token", brandId.toString())

        countryCall.enqueue(object : Callback<BrandModelData> {
            override fun onResponse(
                call: Call<BrandModelData>,
                response: Response<BrandModelData>
            ) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        modelList = apiResponse.data

                        // Create a mutable copy of the original list
                        val modifiedDataList = modelList.toMutableList()

                        // Add the additional item
                        val additionalBrand = BrandModelPojo(id = -1, name = "Other", brand_id = -1)
                        modifiedDataList.add(additionalBrand)

                        modelAdapter = ModelAdapter(modifiedDataList, this@BrandModelActivity)
                        binding.modelRcy.adapter = modelAdapter

                    } else {
                        binding.modelRcy.visibility = View.GONE
                        binding.modelOther.visibility = View.VISIBLE
                    }
                } else {
                    binding.modelRcy.visibility = View.GONE
                    binding.modelOther.visibility = View.VISIBLE
                }
            }

            override fun onFailure(call: Call<BrandModelData>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@BrandModelActivity,
                    t.message.toString(),
                    Color.RED
                )
            }
        })

    }


    override fun onModelClick(brandModelPojo: BrandModelPojo) {
        if (brandModelPojo.name.equals("Other")) {
            binding.modelRcy.visibility = View.GONE
            binding.modelOther.visibility = View.VISIBLE

        } else {
            val resultIntent = Intent()
            resultIntent.putExtra("modelInfo", brandModelPojo.name + "," + brandModelPojo.id+ "," + "")
            setResult(Activity.RESULT_OK, resultIntent)
            finish()
        }
    }


}