package codeflies.com.mcc.Activity

import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.CityAdapter
import codeflies.com.mcc.Adapter.OnCityClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CityData
import codeflies.com.mcc.Model.CityModel
import codeflies.com.mcc.databinding.ActivityCityBinding
import com.facebook.shimmer.Shimmer
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class CityActivity : AppCompatActivity(), OnCityClickListener {

    private lateinit var binding: ActivityCityBinding
    private lateinit var sharedPreference: SharedPreference
    private lateinit var cityAdapter: CityAdapter
    private lateinit var countryList: List<CityData>
    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityCityBinding.inflate(layoutInflater)
        setContentView(binding.root)

        sharedPreference = SharedPreference(this@CityActivity)
        progressDisplay = ProgressDisplay(this@CityActivity)

        binding.back.setOnClickListener {
            finish()
        }


        binding.citySearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                cityAdapter.filter.filter(newText)
            }
        })


        binding.shimmer.startShimmer()
        Shimmer.AlphaHighlightBuilder()
            .setDuration(1800) // Duration of the shimmer animation, in milliseconds
            .setBaseAlpha(0.7f) // Alpha of the content that's not shimmering
            .setHighlightAlpha(0.6f) // Alpha of the shimmer highlight
            .setDirection(Shimmer.Direction.LEFT_TO_RIGHT)
            .setAutoStart(true)
            .build()
        progressDisplay.show()
        getCity()
    }

    private fun getCity() {
        var token = sharedPreference.getData("token").toString()

        val countryId = intent.getIntExtra("countryId", 0)

        val countryCall = RetrofitClient.apiService.cityData("Bearer $token", countryId)

        countryCall.enqueue(object : Callback<CityModel> {
            override fun onResponse(call: Call<CityModel>, response: Response<CityModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        countryList = apiResponse.data
                        cityAdapter = CityAdapter(countryList, this@CityActivity)
                        binding.countryRcy.adapter = cityAdapter

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@CityActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@CityActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@CityActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<CityModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@CityActivity, t.message.toString(), Color.RED)
            }
        })

    }

    override fun onCityClick(city: CityData) {
        val resultIntent = Intent()
        resultIntent.putExtra("cityInfo", city.name + "," + city.id)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()
    }
}