package codeflies.com.mcc.Activity

import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.CountryAdapter
import codeflies.com.mcc.Adapter.OnCountryClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CountryData
import codeflies.com.mcc.Model.CountryModel
import codeflies.com.mcc.databinding.ActivityCountyBinding
import com.facebook.shimmer.Shimmer
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class CountryActivity : AppCompatActivity(), OnCountryClickListener {

    private lateinit var binding: ActivityCountyBinding
    private lateinit var sharedPreference: SharedPreference
    private lateinit var countryAdapter: CountryAdapter
    private lateinit var countryList: List<CountryData>

    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityCountyBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@CountryActivity)
        sharedPreference = SharedPreference(this@CountryActivity)

        binding.back.setOnClickListener {
            finish()
        }

        binding.countrySearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                countryAdapter.filter.filter(newText)
            }
        })



        binding.shimmer.startShimmer()
        Shimmer.AlphaHighlightBuilder()
            .setDuration(1800) // Duration of the shimmer animation, in milliseconds
            .setBaseAlpha(0.7f) // Alpha of the content that's not shimmering
            .setHighlightAlpha(0.6f) // Alpha of the shimmer highlight
            .setDirection(Shimmer.Direction.LEFT_TO_RIGHT)
            .setAutoStart(true)
            .build()
        progressDisplay.show()

        getCounty()
    }

    private fun getCounty() {
        var token = sharedPreference.getData("token").toString()

        val countryCall = RetrofitClient.apiService.countryGet("Bearer " + token)

        countryCall.enqueue(object : Callback<CountryModel> {
            override fun onResponse(call: Call<CountryModel>, response: Response<CountryModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        countryList = apiResponse.data
                        countryAdapter = CountryAdapter(countryList, this@CountryActivity)
                        binding.countryRcy.adapter = countryAdapter

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@CountryActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@CountryActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@CountryActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }

            }

            override fun onFailure(call: Call<CountryModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@CountryActivity, t.message.toString(), Color.RED)

            }
        })


    }

    override fun onCountryClick(country: CountryData) {

        val resultIntent = Intent()
        resultIntent.putExtra("countryInfo", country.name + "," + country.id)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()
    }

}