package codeflies.com.mcc.Activity

import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.EngineAdapter
import codeflies.com.mcc.Adapter.OnEngineClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.VariantItem
import codeflies.com.mcc.Model.VariantModel
import codeflies.com.mcc.databinding.ActivityEngineBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class EngineActivity : AppCompatActivity(), OnEngineClickListener {

    private lateinit var binding: ActivityEngineBinding
    private lateinit var enginAdapter: EngineAdapter
    private lateinit var variantList: List<VariantItem>
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay

    private fun validation(): Boolean {
        if (binding.otherEngineName.text.length == 0) {
            SnackBarUtils.showTopSnackbar(this@EngineActivity, "Please Enter Car Brand!", Color.RED)
            binding.otherEngineName.requestFocus()
            return false
        }
        return true
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityEngineBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@EngineActivity)
        sharedPreference = SharedPreference(this@EngineActivity)

        binding.back.setOnClickListener {
            finish()
        }


        binding.engineSearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                enginAdapter.filter.filter(newText)
            }
        })


        progressDisplay.show()

        getEngine()


        binding.submitEngine.setOnClickListener {
            if (validation()) {
                val resultIntent = Intent()
                resultIntent.putExtra(
                    "engineInfo",
                    binding.otherEngineName.text.toString() + "," + "0"+ "," + "other"
                )
                setResult(Activity.RESULT_OK, resultIntent)
                finish()
            }
        }


    }

    private fun getEngine() {
        var token = sharedPreference.getData("token").toString()
        val variantId = intent.getIntExtra("variantId", 0)


        val variantCall = RetrofitClient.apiService.getEngine("Bearer " + token, variantId)

        variantCall.enqueue(object : Callback<VariantModel> {
            override fun onResponse(call: Call<VariantModel>, response: Response<VariantModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        variantList = apiResponse.data as List<VariantItem>

                        val modifiedDataList = variantList.toMutableList()

                        // Add the additional item
                        val additionalBrand = VariantItem(id = -1, name = "Other")
                        modifiedDataList.add(additionalBrand)

                        enginAdapter = EngineAdapter(modifiedDataList, this@EngineActivity)
                        binding.engineRcy.adapter = enginAdapter

                    } else {
                        binding.engineRcy.visibility = View.GONE
                        binding.engineOther.visibility = View.VISIBLE
                    }
                } else {
                    binding.engineRcy.visibility = View.GONE
                    binding.engineOther.visibility = View.VISIBLE
                }

            }

            override fun onFailure(call: Call<VariantModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@EngineActivity, t.message.toString(), Color.RED)

            }
        })


    }

    override fun onEngineClick(variant: VariantItem) {
        if (variant.name.equals("Other")) {
            binding.engineRcy.visibility = View.GONE
            binding.engineOther.visibility = View.VISIBLE

        } else {
            val resultIntent = Intent()
            resultIntent.putExtra("engineInfo", variant.name + "," + variant.id+","+"")
            setResult(Activity.RESULT_OK, resultIntent)
            finish()
        }
    }
}