package codeflies.com.mcc.Activity

import android.Manifest
import android.app.Activity
import android.app.Dialog
import android.content.Intent
import android.content.pm.PackageManager
import android.graphics.Bitmap
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.media.MediaScannerConnection
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.os.Environment
import android.os.Handler
import android.os.Looper
import android.provider.DocumentsContract
import android.provider.MediaStore
import android.provider.OpenableColumns
import android.util.Log
import android.view.View
import android.view.ViewGroup
import android.view.WindowManager
import android.widget.TextView
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.documentfile.provider.DocumentFile
import androidx.recyclerview.widget.LinearLayoutManager
import codeflies.com.mcc.Adapter.CarImageAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Helper.getRealPathFromUri
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.ActivityFeedbackBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import okhttp3.MediaType.Companion.toMediaTypeOrNull
import okhttp3.MultipartBody
import okhttp3.RequestBody.Companion.asRequestBody
import okhttp3.RequestBody.Companion.toRequestBody
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.io.File
import java.io.FileOutputStream

class FeedbackActivity : AppCompatActivity() {

    private lateinit var binding: ActivityFeedbackBinding
    private val REQUEST_CODE_PERMISSION = 123
    val REQUEST_CODE = 200
    val REQUEST_CODE_CAMERA = 199
    private lateinit var adapter: CarImageAdapter
    private var imageUriList = mutableListOf<Uri>()
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        getWindow().setBackgroundDrawableResource(R.color.bg_back);
        binding = ActivityFeedbackBinding.inflate(layoutInflater)
        setContentView(binding.root)


        progressDisplay = ProgressDisplay(this@FeedbackActivity)

        sharedPreference = SharedPreference(this@FeedbackActivity)

        binding.feedbackSave.setOnClickListener {
            if (validation()) {
                progressDisplay.show()
                feedbackVehicle()
            }
        }


        binding.getImageFeedback.setOnClickListener {


            val permissionsToRequest = mutableListOf<String>()

            if (Build.VERSION.SDK_INT < Build.VERSION_CODES.TIRAMISU) {
                if (checkSelfPermission(Manifest.permission.READ_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
                    permissionsToRequest.add(Manifest.permission.READ_EXTERNAL_STORAGE)
                    requestPermissions(
                        permissionsToRequest.toTypedArray(),
                        REQUEST_CODE_PERMISSION
                    )
                } else {
                    chooseDialog()
                }
            } else {
                if (checkSelfPermission(Manifest.permission.READ_MEDIA_IMAGES) != PackageManager.PERMISSION_GRANTED) {
                    permissionsToRequest.add(Manifest.permission.READ_MEDIA_IMAGES)
                    requestPermissions(
                        permissionsToRequest.toTypedArray(),
                        REQUEST_CODE_PERMISSION
                    )
                } else {
                    chooseDialog()
                }
            }


        }
    }

    private fun validation(): Boolean {
        if (binding.feedback.text?.length == 0) {

            SnackBarUtils.showTopSnackbar(
                this@FeedbackActivity,
                "Please Enter Your Thoughts!",
                Color.RED
            )
            binding.feedback.requestFocus()
            return false
        }

        return true

    }

    fun back(view: View) {
        finish()
    }

    private fun openGalleryForImages() {
        val validImageTypes = arrayOf("image/jpeg", "image/jpg", "image/png")

        if (Build.VERSION.SDK_INT < 19) {
            // For earlier versions
            val intent = Intent()
            intent.type = "image/*"
            intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
            intent.action = Intent.ACTION_GET_CONTENT
            startActivityForResult(Intent.createChooser(intent, "Choose Pictures"), REQUEST_CODE)
        } else {
            // For API LEVEL 19 and above
            val intent = Intent(Intent.ACTION_OPEN_DOCUMENT)
            intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
            intent.addCategory(Intent.CATEGORY_OPENABLE)

            // Set the MIME type filter
            intent.type = "image/*"
            intent.putExtra(Intent.EXTRA_MIME_TYPES, validImageTypes)

            startActivityForResult(intent, REQUEST_CODE)
        }

    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        if (resultCode == Activity.RESULT_OK && requestCode == REQUEST_CODE) {

            // if multiple images are selected
            if (data?.clipData != null) {
                val count = data.clipData!!.itemCount
                imageUriList.clear()
                for (i in 0 until count) {
                    val imageUri: Uri = data.clipData!!.getItemAt(i).uri
                    //     val filePath = getPathFromUri(imageUri)
                    // Log.e("filePath","filePath = "+filePath)
                    // Now 'filePath' contains the file path corresponding to the Uri
                    imageUriList.add(imageUri)
                    // iv_image.setImageURI(imageUri) Here you can assign your Image URI to the ImageViews
                }

                binding.oneImageFrame.visibility = View.GONE
                binding.multiImage.visibility = View.VISIBLE

                binding.multiImage.layoutManager =
                    LinearLayoutManager(this, LinearLayoutManager.HORIZONTAL, false)
                adapter = CarImageAdapter(imageUriList) { clickedPosition ->
                    // Handle the delete button click event (remove the image at the clicked position)
                    adapter.removeImage(clickedPosition)
                    adapter.notifyDataSetChanged()
                }
                binding.multiImage.adapter = adapter
                adapter.notifyDataSetChanged()

            } else if (data?.data != null) {
                // if a single image is selected

                val imageUri: Uri = data.data!!
                // val filePath = getPathFromUri(imageUri)
                // Now 'filePath' contains the file path corresponding to the Uri
                imageUriList.add(imageUri)

                binding.oneImageFrame.visibility = View.GONE
                binding.multiImage.visibility = View.VISIBLE

                binding.multiImage.layoutManager =
                    LinearLayoutManager(this, LinearLayoutManager.HORIZONTAL, false)
                adapter = CarImageAdapter(imageUriList) { clickedPosition ->
                    // Handle the delete button click event (remove the image at the clicked position)
                    adapter.removeImage(clickedPosition)
                    adapter.notifyDataSetChanged()
                }
                binding.multiImage.adapter = adapter
                adapter.notifyDataSetChanged()
                // iv_image.setImageURI(imageUri) Here you can assign the picked image uri to your imageview
            }
        }else if (resultCode == Activity.RESULT_OK && requestCode == REQUEST_CODE_CAMERA) {
            val imageBitmap = data?.extras?.get("data") as Bitmap
            val imageUri = saveImageToGallery(imageBitmap) // Save the captured image to the gallery and get its Uri
            imageUriList.add(imageUri)
        }
        binding.oneImageFrame.visibility = View.GONE
        binding.multiImage.visibility = View.VISIBLE

        binding.multiImage.layoutManager =
            LinearLayoutManager(this@FeedbackActivity, LinearLayoutManager.HORIZONTAL, false)
        adapter = CarImageAdapter(imageUriList) { clickedPosition ->
            // Handle the delete button click event (remove the image at the clicked position)
            adapter.removeImage(clickedPosition)
            adapter.notifyDataSetChanged()
        }
        binding.multiImage.adapter = adapter
        adapter.notifyDataSetChanged()
    }


    private fun feedbackVehicle() {
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()


        val idRequestBody =
            user_id.toRequestBody("text/plain".toMediaTypeOrNull())
        val messageRequestBody =
            binding.feedback.text.toString().toRequestBody("text/plain".toMediaTypeOrNull())
        val typeRequestBody = "feedback".toRequestBody("text/plain".toMediaTypeOrNull())
        val iDRequestBody = "".toRequestBody("text/plain".toMediaTypeOrNull())


        val imageParts = mutableListOf<MultipartBody.Part>()

        for (uri in imageUriList) {
            val fileName = getFileNameFromUriWithoutPath(uri)
            // val fileName = "$fileNameWithoutExtension.jpg"

            Log.e("fileName", "fileName = $fileName")

            if (fileName != null) {

                val file = File(getRealPathFromUri(this@FeedbackActivity, uri))
                Log.e("fileName", "fileName = $file")

                val requestFile = file.asRequestBody("image/*".toMediaTypeOrNull())
                val imagePart = MultipartBody.Part.createFormData("images[]", fileName, requestFile)
                Log.e("fileName", "fileName = $fileName  , $requestFile")

                imageParts.add(imagePart)
            }
        }


// Make the API call
        val feedbackCall = RetrofitClient.apiService.uploadFeedback(
            "Bearer $token",
            idRequestBody,
            messageRequestBody,
            typeRequestBody, iDRequestBody, imageParts
        )

        feedbackCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            this@FeedbackActivity,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )
                        Handler(Looper.getMainLooper()).postDelayed({
                            finish()
                        }, 2000)


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@FeedbackActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@FeedbackActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@FeedbackActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@FeedbackActivity,
                    t.message.toString(),
                    Color.RED
                )
            }

        })
    }

    private fun getFileNameFromUriWithoutPath(uri: Uri): String? {
        // Get the last segment of the URI's path, which should be the file name
        return uri.lastPathSegment
    }

    private fun getFileNameFromUri(uri: Uri): String? {
        var fileName: String? = null

        if (DocumentsContract.isDocumentUri(this@FeedbackActivity, uri)) {
            // Handle document URI
            val document = DocumentFile.fromSingleUri(this@FeedbackActivity, uri)
            fileName = document?.name
        } else {
            // Handle other URI types
            val cursor = contentResolver.query(uri, null, null, null, null)

            cursor?.use {
                if (it.moveToFirst()) {
                    val displayName = it.getColumnIndex(OpenableColumns.DISPLAY_NAME)
                    fileName = it.getString(displayName)
                }
            }
        }

        return fileName
    }


    private fun chooseDialog() {

        // val mainActivity = AppManager.instance.getMainActivity()

        val dialog =  Dialog(this@FeedbackActivity)
        dialog.setContentView(R.layout.choose_dialog)
        dialog.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(true)
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))

        val gallery = dialog.findViewById<TextView>(R.id.gallery)
        val camera = dialog.findViewById<TextView>(R.id.camera)


        gallery.setOnClickListener {
            openGalleryForImages()
            dialog.dismiss()
        }

        camera.setOnClickListener {
            val captureIntent = Intent(MediaStore.ACTION_IMAGE_CAPTURE)

            // Check if there is a camera activity available to handle the intent
            if (captureIntent.resolveActivity(packageManager) != null) {
                // Start the camera activity
                startActivityForResult(captureIntent, REQUEST_CODE_CAMERA)
                dialog.dismiss()
            } else {
                // Handle the case where no camera activity is available
                Toast.makeText(this@FeedbackActivity, "No camera app found", Toast.LENGTH_SHORT).show()
                dialog.dismiss()
            }
        }

        dialog.show()
    }
    private fun saveImageToGallery(bitmap: Bitmap): Uri {
        val imagesDir = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES)
        val imageFile = File(imagesDir, "${System.currentTimeMillis()}.jpg")
        FileOutputStream(imageFile).use { outputStream ->
            bitmap.compress(Bitmap.CompressFormat.JPEG, 100, outputStream)
        }
        // Update the gallery so that the newly captured image is visible
        MediaScannerConnection.scanFile(this@FeedbackActivity, arrayOf(imageFile.absolutePath), arrayOf("image/jpeg"), null)
        return Uri.fromFile(imageFile)
    }


}