package codeflies.com.mcc.Activity

import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.databinding.ActivityForgotBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class ForgotActivity : AppCompatActivity() {

    private lateinit var binding: ActivityForgotBinding
    var emailPattern = ("^(([\\w-]+\\.)+[\\w-]+|([a-zA-Z]{1}|[\\w-]{2,}))@"
            + "((([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
            + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\."
            + "([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
            + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])){1}|"
            + "([a-zA-Z]+[\\w-]+\\.)+[a-zA-Z]{2,4})$")


    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityForgotBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@ForgotActivity)

        binding.sendMail.setOnClickListener {
            if (validation()) {
                if (binding.emailPS.text.toString().matches(emailPattern.toRegex())) {

                    progressDisplay.show()
                    forgotMethod()
                } else {
                    SnackBarUtils.showTopSnackbar(
                        this@ForgotActivity, "Enter valid email pattern",
                        Color.RED
                    )
                    binding.emailPS.requestFocus();
                }
            }
        }
    }

    private fun forgotMethod() {
        val forgotCall = RetrofitClient.apiService.forgot(binding.emailPS.text.toString())

        forgotCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            this@ForgotActivity,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )
                        Handler(Looper.getMainLooper()).postDelayed({
                            finish() // or navigate back to the login screen
                        }, 2000)

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@ForgotActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@ForgotActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@ForgotActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }


            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@ForgotActivity, t.message.toString(), Color.RED)
            }
        })
    }

    private fun validation(): Boolean {
        if (binding.emailPS.text?.length === 0) {
            SnackBarUtils.showTopSnackbar(this@ForgotActivity, "Enter the valid email!", Color.RED)
            binding.emailPS.requestFocus()
            return false
        }
        return true
    }

    fun back(view: View) {
        finish()
    }
}