package codeflies.com.mcc.Activity

import android.annotation.SuppressLint
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.method.HideReturnsTransformationMethod
import android.text.method.PasswordTransformationMethod
import android.util.Log
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.databinding.ActivityForgotPasswordBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class ForgotPasswordActivity : AppCompatActivity() {
    private lateinit var binding: ActivityForgotPasswordBinding

    var valueNew = 0
    var valueConfirm = 0
    private lateinit var progressDisplay: ProgressDisplay
    var confirmPs = ""
    var password = ""

    companion object {
        var token = ""
        var email = ""
    }

    private fun validation(): Boolean {

        if (binding.newPs.text.toString().length <= 5) {

            SnackBarUtils.showTopSnackbar(
                this@ForgotPasswordActivity,
                "Password length should be grater then 6 !",
                Color.RED
            )
            binding.newPs.requestFocus()
            return false
        } else if (binding.cnfmPs.text.toString().length <= 5) {
            SnackBarUtils.showTopSnackbar(
                this@ForgotPasswordActivity,
                "Password length should be grater then 6 !",
                Color.RED
            )

            binding.cnfmPs.requestFocus()
            return false
        } else if (!confirmPs.equals(password)) {
            SnackBarUtils.showTopSnackbar(
                this@ForgotPasswordActivity,
                "Password and Confirm password doesn't match",
                Color.RED
            )
            binding.cnfmPs.requestFocus()
            return false
        }


        return true
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityForgotPasswordBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@ForgotPasswordActivity)

        Log.e("email", email + "   " + token)
        binding.submitPS.setOnClickListener {

            confirmPs = binding.newPs.text.toString()
            password = binding.cnfmPs.text.toString()

            if (validation()) {
                progressDisplay.show()
                forgotPS()

            }
        }

        binding.newShowPassword.setOnClickListener {
            valueNew = 1
            changeNewType(valueNew)
        }
        binding.newHidePassword.setOnClickListener {
            valueNew = 2
            changeNewType(valueNew)
        }
        binding.cnfmShowPassword.setOnClickListener {
            valueConfirm = 1
            changeCnfmType(valueConfirm)
        }
        binding.cnfmHidePassword.setOnClickListener {
            valueConfirm = 2
            changeCnfmType(valueConfirm)
        }

    }


    fun back(view: View) {
        startActivity(Intent(this@ForgotPasswordActivity, LoginActivity::class.java))
        finishAffinity()
    }


    @SuppressLint("MissingSuperCall")
    override fun onBackPressed() {
        startActivity(Intent(this@ForgotPasswordActivity, LoginActivity::class.java))
        finishAffinity()
    }


    private fun forgotPS() {
        val resetPasswordCall = RetrofitClient.apiService.forgotPassword(
            email,
            token,
            binding.cnfmPs.text.toString()
        )

        resetPasswordCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            this@ForgotPasswordActivity,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )

                        Handler(Looper.getMainLooper()).postDelayed({
                            startActivity(
                                Intent(
                                    this@ForgotPasswordActivity,
                                    LoginActivity::class.java
                                )
                            )
                            finishAffinity()
                        }, 2000)


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@ForgotPasswordActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )

                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@ForgotPasswordActivity,
                            errorMessage.toString(),
                            Color.RED
                        )

                    } catch (e: Exception) {

                        SnackBarUtils.showTopSnackbar(
                            this@ForgotPasswordActivity,
                            e.message.toString(),
                            Color.RED
                        )

                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@ForgotPasswordActivity,
                    t.message.toString(),
                    Color.RED
                )
            }

        })
    }


    private fun changeCnfmType(value: Int) {
        if (value == 1) {
            binding.cnfmPs.transformationMethod = HideReturnsTransformationMethod.getInstance()
            binding.cnfmHidePassword.visibility = View.VISIBLE
            binding.cnfmShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding.cnfmPs.transformationMethod = PasswordTransformationMethod.getInstance()
            binding.cnfmHidePassword.visibility = View.GONE
            binding.cnfmShowPassword.visibility = View.VISIBLE
        }
    }

    private fun changeNewType(value: Int) {
        if (value == 1) {
            binding.newPs.transformationMethod = HideReturnsTransformationMethod.getInstance()
            binding.newHidePassword.visibility = View.VISIBLE
            binding.newShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding.newPs.transformationMethod = PasswordTransformationMethod.getInstance()
            binding.newHidePassword.visibility = View.GONE
            binding.newShowPassword.visibility = View.VISIBLE
        }
    }
}
