package codeflies.com.mcc.Activity

import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.FuelAdapter
import codeflies.com.mcc.Adapter.OnFuelClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.FuelModelData
import codeflies.com.mcc.Model.FuelModelPojo
import codeflies.com.mcc.databinding.ActivityFuelBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class FuelActivity : AppCompatActivity(), OnFuelClickListener {

    private lateinit var binding: ActivityFuelBinding
    private lateinit var sharedPreference: SharedPreference
    private lateinit var fuelAdapter: FuelAdapter
    private lateinit var fuellist: List<FuelModelPojo>
    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityFuelBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@FuelActivity)
        sharedPreference = SharedPreference(this@FuelActivity)

        binding.fuelSearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                fuelAdapter.filter.filter(newText)
            }
        })

        progressDisplay.show()
        getBrand()

        binding.back.setOnClickListener {
            finish()
        }

    }

    private fun getBrand() {
        var token = sharedPreference.getData("token").toString()

        val brandId = intent.getIntExtra("brandId", 0)

        val countryCall = RetrofitClient.apiService.fuelGet("Bearer $token")

        countryCall.enqueue(object : Callback<FuelModelData> {
            override fun onResponse(call: Call<FuelModelData>, response: Response<FuelModelData>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        fuellist = apiResponse.data
                        fuelAdapter = FuelAdapter(fuellist, this@FuelActivity)
                        binding.fuelRcy.adapter = fuelAdapter

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@FuelActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@FuelActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@FuelActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<FuelModelData>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@FuelActivity, t.message.toString(), Color.RED)
            }
        })

    }


    override fun onFuelClick(fuelModelPojo: FuelModelPojo) {
        val resultIntent = Intent()
        resultIntent.putExtra("fuelInfo", fuelModelPojo.name + "," + fuelModelPojo.id)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()    }
}