package codeflies.com.mcc.Activity

import android.app.Activity
import android.app.ProgressDialog
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.DistanceTypeAdapter
import codeflies.com.mcc.Adapter.OnTypeClickListener
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.DistanceTypeModel
import codeflies.com.mcc.Model.TypeItem
import codeflies.com.mcc.databinding.ActivityKmMileageBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class KM_MileageActivity : AppCompatActivity() ,OnTypeClickListener{

    private lateinit var binding: ActivityKmMileageBinding

    private lateinit var distanceTypeAdapter: DistanceTypeAdapter
    private lateinit var typeList: List<TypeItem>
    private lateinit var sharedPreference: SharedPreference
    private val progressDialog by lazy {
        ProgressDialog(this@KM_MileageActivity).apply {
            setMessage("Please wait...")
            setCancelable(false)
        }
    }
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityKmMileageBinding.inflate(layoutInflater)
        setContentView(binding.root)




        sharedPreference = SharedPreference(this@KM_MileageActivity)

        binding.back.setOnClickListener {
            finish()
        }

        binding.kmSearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                distanceTypeAdapter.filter.filter(newText)
            }
        })


        progressDialog.show()

        getType()
    }

    private fun getType() {
        var token = sharedPreference.getData("token").toString()


        val variantCall = RetrofitClient.apiService.getType("Bearer " + token)

        variantCall.enqueue(object : Callback<DistanceTypeModel> {
            override fun onResponse(call: Call<DistanceTypeModel>, response: Response<DistanceTypeModel>) {
                progressDialog.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        typeList = apiResponse.data as List<TypeItem>
                        distanceTypeAdapter = DistanceTypeAdapter(typeList, this@KM_MileageActivity)
                        binding.KMRcy.adapter = distanceTypeAdapter

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@KM_MileageActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@KM_MileageActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@KM_MileageActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }

            }

            override fun onFailure(call: Call<DistanceTypeModel>, t: Throwable) {
                progressDialog.dismiss()
                SnackBarUtils.showTopSnackbar(this@KM_MileageActivity, t.message.toString(), Color.RED)

            }
        })


    }

    override fun onTypeClick(typeItem: TypeItem) {
        val resultIntent = Intent()
        resultIntent.putExtra("typeInfo", typeItem.name + "," + typeItem.id)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()
    }

}