package codeflies.com.mcc.Activity

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.method.HideReturnsTransformationMethod
import android.text.method.PasswordTransformationMethod
import android.util.Log
import android.view.View
import android.view.inputmethod.InputMethodManager
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.Reminders
import codeflies.com.mcc.Model.SignUpModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.ActivityLoginBinding
import com.facebook.AccessToken
import com.facebook.CallbackManager
import com.facebook.FacebookCallback
import com.facebook.FacebookException
import com.facebook.FacebookSdk
import com.facebook.GraphRequest
import com.facebook.appevents.AppEventsLogger
import com.facebook.login.LoginManager
import com.facebook.login.LoginResult
import com.google.android.gms.auth.api.signin.GoogleSignIn
import com.google.android.gms.auth.api.signin.GoogleSignInClient
import com.google.android.gms.auth.api.signin.GoogleSignInOptions
import com.google.android.gms.common.api.ApiException
import com.google.firebase.Firebase
import com.google.firebase.auth.FacebookAuthProvider
import com.google.firebase.auth.FirebaseAuth
import com.google.firebase.auth.FirebaseUser
import com.google.firebase.auth.GoogleAuthProvider
import com.google.firebase.auth.auth
import com.google.firebase.messaging.FirebaseMessaging
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class LoginActivity : AppCompatActivity() {

    private val callbackManager = CallbackManager.Factory.create()
    private lateinit var binding: ActivityLoginBinding
    var valueConfirm = 0
    var Fcm_token = ""

    private lateinit var auth: FirebaseAuth
    private lateinit var googleSignInClient: GoogleSignInClient
    private var sharedPreference: SharedPreference? = null
    var emailPattern = ("^(([\\w-]+\\.)+[\\w-]+|([a-zA-Z]{1}|[\\w-]{2,}))@"
            + "((([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
            + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\."
            + "([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
            + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])){1}|"
            + "([a-zA-Z]+[\\w-]+\\.)+[a-zA-Z]{2,4})$")

    private lateinit var progressDisplay: ProgressDisplay


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityLoginBinding.inflate(layoutInflater)
        setContentView(binding.root)

        FirebaseMessaging.getInstance().token.addOnCompleteListener { task ->
            if (task.isSuccessful) {
                Fcm_token = task.result
                Log.e("FCM Token", "Token: $Fcm_token")
                // Now you can use the token as needed, such as sending it to your server for notifications
            } else {
                Log.e("FCM Token", "Failed to get token: ${task.exception}")
            }
        }

        progressDisplay = ProgressDisplay(this@LoginActivity)

        sharedPreference = SharedPreference(this@LoginActivity)

        if (sharedPreference?.getData("rememberStatus").equals("1")) {
            binding.emailLogin.setText(sharedPreference?.getData("email"))
            binding.passwordLogin.setText(sharedPreference?.getData("password"))
        }
        // Initialize Facebook SD
        FacebookSdk.setClientToken(getString(R.string.facebook_client_token))
        FacebookSdk.sdkInitialize(applicationContext)
        AppEventsLogger.activateApp(application)

        // [START config_signin]
        // Configure Google Sign In
        val gso = GoogleSignInOptions.Builder(GoogleSignInOptions.DEFAULT_SIGN_IN)
            .requestIdToken(getString(R.string.default_web_client_id))
            .requestEmail()
            .build()

        googleSignInClient = GoogleSignIn.getClient(this, gso)
        // [END config_signin]
        // [START initialize_auth]
        // Initialize Firebase Auth
        auth = Firebase.auth
        // [END initialize_auth]

        val currentUser = auth.currentUser
        // updateUI(currentUser)

        /*
                binding.facebookLogin.setOnClickListener {
                    LoginManager.getInstance().logInWithReadPermissions(this, listOf("public_profile", "email"))
                }
        */


// Register the callback
        LoginManager.getInstance().registerCallback(callbackManager,
            object : FacebookCallback<LoginResult> {
                override fun onSuccess(loginResult: LoginResult) {

                    // Log the entire LoginResult to see the data
                    Log.d("FacebookLogin", "LoginResult: $loginResult")

                    // Request user data with a GraphRequest
                    val graphRequest =
                        GraphRequest.newMeRequest(loginResult.accessToken) { jsonObject, response ->
                            if (jsonObject != null) {
                                // Log the user data
                                Log.d("FacebookLogin", "GraphRequest User Data: $jsonObject")

                                // Attempt to extract email from JSON
                                val email = jsonObject.optString("email")
                                Log.d("FacebookLogin", "User Email: $email")

                                // Handle Facebook access token
                                handleFacebookAccessToken(loginResult.accessToken)
                            } else {
                                Log.e("FacebookLogin", "GraphRequest failed. Response: $response")
                            }
                        }

                    // Define the parameters you want to request (including email)
                    val parameters = Bundle()
                    parameters.putString(
                        "fields",
                        "id,name,email"
                    ) // Include any other fields you need

                    // Set parameters to the GraphRequest
                    graphRequest.parameters = parameters

                    // Execute the GraphRequest
                    graphRequest.executeAsync()
                }

                override fun onCancel() {
                    // Login cancelled
                }

                override fun onError(error: FacebookException) {
                    // Handle error
                    Log.e("FacebookLogin", "Error: ${error.message}")
                }
            })

        binding.termsBtn.setOnClickListener {
            startActivity(Intent(this@LoginActivity, TermsActivity::class.java))
        }

        binding.cnfmShowPassword.setOnClickListener {
            valueConfirm = 1
            changeCnfmType(valueConfirm)
        }
        binding.cnfmHidePassword.setOnClickListener {
            valueConfirm = 2
            changeCnfmType(valueConfirm)
        }
    }


    fun terms(view: View) {
        val intent = Intent(this, TermsActivity::class.java)

        // Start the second activity
        startActivity(intent)
    }

    fun register(view: View) {
        val intent = Intent(this, RegisterActivity::class.java)
        // Start the second activity
        startActivity(intent)
    }

    fun forgot(view: View) {
        val intent = Intent(this, ForgotActivity::class.java)
        // Start the second activity
        startActivity(intent)
    }

    fun login(view: View) {
        hideKeyboard()
        if (binding.radioLogin.isChecked) {
            if (valdation()) {
                if (binding.emailLogin.text.toString().matches(emailPattern.toRegex())) {
                    progressDisplay.show()
                    LoginMethod()
                } else {
                    SnackBarUtils.showTopSnackbar(
                        this@LoginActivity,
                        "Enter valid email pattern",
                        Color.RED
                    )
                    binding.emailLogin.requestFocus()
                }
            }
        } else {
            SnackBarUtils.showTopSnackbar(
                this@LoginActivity,
                "Please select Terms & Conditions!",
                Color.RED
            )
        }
    }

    private fun LoginMethod() {
        val signCall = RetrofitClient.apiService.login(
            binding.emailLogin.text.toString(),
            binding.passwordLogin.text.toString(),
            Fcm_token,
            "normal", "android"
        )

        signCall.enqueue(object : Callback<SignUpModel> {
            override fun onResponse(call: Call<SignUpModel>, response: Response<SignUpModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )
                        sharedPreference?.saveData("token", apiResponse.data.token)
                        sharedPreference?.saveData("user_id", apiResponse.data.id)


                        val reminders: List<Reminders?>? = response.body()?.data?.reminders

                        if (!reminders.isNullOrEmpty()) {
                            for (reminder in reminders) {
                                reminder?.let {
                                    when (it.name) {
                                        "car" -> {
                                            sharedPreference?.saveData("car_value", it.name)
                                            sharedPreference?.saveData(
                                                "car_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "member" -> {
                                            sharedPreference?.saveData(
                                                "member_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "member_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "policy" -> {
                                            sharedPreference?.saveData(
                                                "policy_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "policy_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "repair" -> {
                                            sharedPreference?.saveData(
                                                "repair_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "repair_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "service" -> {
                                            sharedPreference?.saveData(
                                                "service_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "service_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        else -> {

                                        }
                                    }
                                }
                            }
                        }

                        if (binding.remember.isChecked) {
                            sharedPreference?.saveData("rememberStatus", "1")
                            sharedPreference?.saveData("email", binding.emailLogin.text.toString())
                            sharedPreference?.saveData(
                                "password",
                                binding.passwordLogin.text.toString()
                            )

                        } else {
                            sharedPreference?.saveData("rememberStatus", "0")
                            sharedPreference?.saveData("email", "")
                            sharedPreference?.saveData("password", "")
                        }

                        startActivity(Intent(this@LoginActivity, MainActivity::class.java))
                        finishAffinity()


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<SignUpModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@LoginActivity, t.message.toString(), Color.RED)
            }
        })

    }

    private fun valdation(): Boolean {
        if (binding.emailLogin.text?.length === 0) {
            SnackBarUtils.showTopSnackbar(this@LoginActivity, "Enter email", Color.RED)
            binding.emailLogin.requestFocus()
            return false
        } else if (binding.passwordLogin.text.toString().length <= 5) {
            SnackBarUtils.showTopSnackbar(
                this@LoginActivity,
                "Password length should be grater then 6 !",
                Color.RED
            )
            binding.passwordLogin.requestFocus()
            return false
        }
        return true
    }


    fun google_login(view: View) {
        signIn()
    }


    private fun handleFacebookAccessToken(token: AccessToken) {
        val credential = FacebookAuthProvider.getCredential(token.token)
        FirebaseAuth.getInstance().signInWithCredential(credential)
            .addOnCompleteListener(this) { task ->
                if (task.isSuccessful) {
                    // Sign in success
                    val user = FirebaseAuth.getInstance().currentUser
                    val facebookId = token.userId
                    val accessToken = token.token

                    Log.d("FacebookLogin", "User ID: ${user?.uid}")
                    Log.d("FacebookLogin", "Display Name: ${user?.displayName}")
                    Log.d("FacebookLogin", "Email: ${user?.email}")
                } else {
                    // If sign in fails, display a message to the user.
                    Log.e("FacebookLogin", "Authentication failed: ${task.exception}")
                }
            }
    }


    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        // Handle Facebook login result
        callbackManager.onActivityResult(requestCode, resultCode, data)


        if (requestCode == RC_SIGN_IN) {
            val task = GoogleSignIn.getSignedInAccountFromIntent(data)
            try {
                // Google Sign In was successful, authenticate with Firebase
                val account = task.getResult(ApiException::class.java)!!
                Log.d(TAG, "firebaseAuthWithGoogle:" + account.id)
                firebaseAuthWithGoogle(account.idToken!!)
            } catch (e: ApiException) {
                // Google Sign In failed, update UI appropriately
                Log.w(TAG, "Google sign in failed", e)
            }
        }
    }

    // [START auth_with_google]
    private fun firebaseAuthWithGoogle(idToken: String) {
        val credential = GoogleAuthProvider.getCredential(idToken, null)
        auth.signInWithCredential(credential)
            .addOnCompleteListener(this) { task ->
                if (task.isSuccessful) {
                    //  in success, update UI with the signed-in user's information
                    Log.d(TAG, "signInWithCredential:success")
                    val user = auth.currentUser
                    updateUI(user)
                } else {
                    // If sign in fails, display a message to the user.
                    Log.w(TAG, "signInWithCredential:failure", task.exception)
                    updateUI(null)
                }
            }
    }
    // [END auth_with_google]

    // [START signin]
    private fun signIn() {
        val signInIntent = googleSignInClient.signInIntent
        startActivityForResult(signInIntent, RC_SIGN_IN)
    }
    // [END signin]

    private fun updateUI(user: FirebaseUser?) {
        if (user != null) {
            // Signed in successfully, get user details from GoogleSignInAccount
            val googleSignInAccount = GoogleSignIn.getLastSignedInAccount(this)
            val displayName = googleSignInAccount?.displayName
            val email = googleSignInAccount?.email
            val photoUrl = googleSignInAccount?.photoUrl
            val googleId = googleSignInAccount?.id
            val googleToken = googleSignInAccount?.idToken

            // Now you can use these details as needed
            Log.d(TAG, "User Display Name: $displayName")
            Log.d(TAG, "User Email: $email")
            Log.d(TAG, "Profile Photo URL: $photoUrl")

            // Update UI with user details, for example:
            // UpdateTextView(displayName, email, photoUrl)
            googleLogin(displayName, email, googleId, googleToken)
        } else {
            // User is signed out, update UI accordingly
            // ClearTextViews()
        }
    }

    private fun googleLogin(
        displayName: String?,
        email: String?,
        googleId: String?,
        googleToken: String?
    ) {
        progressDisplay.show()
        val names = displayName?.split(" ")

        // Extract first and last names
        val firstName = names?.firstOrNull() ?: ""
        val lastName = names?.getOrNull(1) ?: "."

        val googleCall = RetrofitClient.apiService.googleLogin(
            googleId.toString(),
            googleToken.toString(),
            firstName, lastName, email.toString(), Fcm_token,
            "google",
            "android"
        )

        googleCall.enqueue(object : Callback<SignUpModel> {
            override fun onResponse(call: Call<SignUpModel>, response: Response<SignUpModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )
                        sharedPreference?.saveData("token", apiResponse.data.token)
                        sharedPreference?.saveData("user_id", apiResponse.data.id)


                        val reminders: List<Reminders?>? = response.body()?.data?.reminders

                        if (!reminders.isNullOrEmpty()) {
                            for (reminder in reminders) {
                                reminder?.let {
                                    when (it.name) {
                                        "car" -> {
                                            sharedPreference?.saveData("car_value", it.name)
                                            sharedPreference?.saveData(
                                                "car_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "member" -> {
                                            sharedPreference?.saveData(
                                                "member_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "member_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "policy" -> {
                                            sharedPreference?.saveData(
                                                "policy_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "policy_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "repair" -> {
                                            sharedPreference?.saveData(
                                                "repair_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "repair_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        "service" -> {
                                            sharedPreference?.saveData(
                                                "service_value",
                                                it.name
                                            )
                                            sharedPreference?.saveData(
                                                "service_status",
                                                it.is_enabled.toString()
                                            )
                                        }

                                        else -> {

                                        }
                                    }
                                }
                            }
                        }

                        if (binding.remember.isChecked) {
                            sharedPreference?.saveData("rememberStatus", "1")
                            sharedPreference?.saveData("email", binding.emailLogin.text.toString())
                            sharedPreference?.saveData(
                                "password",
                                binding.passwordLogin.text.toString()
                            )

                        } else {
                            sharedPreference?.saveData("rememberStatus", "0")
                            sharedPreference?.saveData("email", "")
                            sharedPreference?.saveData("password", "")
                        }

                        startActivity(Intent(this@LoginActivity, MainActivity::class.java))
                        finishAffinity()


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@LoginActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<SignUpModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@LoginActivity, t.message.toString(), Color.RED)
            }
        })
    }


    companion object {
        private const val TAG = "GoogleActivity"
        private const val RC_SIGN_IN = 9001
    }

    private fun hideKeyboard() {
        val imm = getSystemService(Context.INPUT_METHOD_SERVICE) as InputMethodManager
        imm.hideSoftInputFromWindow(currentFocus?.windowToken, 0)
    }


    private fun changeCnfmType(value: Int) {
        if (value == 1) {
            binding.passwordLogin.transformationMethod =
                HideReturnsTransformationMethod.getInstance()
            binding.cnfmHidePassword.visibility = View.VISIBLE
            binding.cnfmShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding.passwordLogin.transformationMethod = PasswordTransformationMethod.getInstance()
            binding.cnfmHidePassword.visibility = View.GONE
            binding.cnfmShowPassword.visibility = View.VISIBLE
        }
    }


}

