package codeflies.com.mcc.Activity

import android.annotation.SuppressLint
import android.app.Dialog
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.util.Log
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.PlanAdapter
import codeflies.com.mcc.Adapter.PlanAdapter.PlanItemClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.DataItem
import codeflies.com.mcc.Model.PlanModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.ActivityPlansBinding
import com.github.kittinunf.fuel.httpPost
import com.github.kittinunf.fuel.json.responseJson
import com.github.kittinunf.result.Result
import com.google.gson.Gson
import com.google.gson.JsonObject
import com.skydoves.elasticviews.ElasticButton
import com.stripe.android.PaymentConfiguration
import com.stripe.android.paymentsheet.PaymentSheet
import com.stripe.android.paymentsheet.PaymentSheetResult
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class PlansActivity : AppCompatActivity(), PlanItemClickListener {
    private lateinit var binding: ActivityPlansBinding
    private lateinit var progressDisplay: ProgressDisplay
    private lateinit var sharedPreference: SharedPreference
    private lateinit var planAdapter: PlanAdapter
    private lateinit var planList: List<DataItem>


    private lateinit var paymentSheet: PaymentSheet
    private lateinit var customerConfig: PaymentSheet.CustomerConfiguration
    private lateinit var paymentIntentClientSecret: String
    val endpoint = "https://carcoll.localserverpro.com/payment-sheet"

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityPlansBinding.inflate(layoutInflater)
        setContentView(binding.root)

        sharedPreference = SharedPreference(this@PlansActivity)
        progressDisplay = ProgressDisplay(this@PlansActivity)

       // progressDisplay.show()
        // Initialize PaymentSheet
        paymentSheet = PaymentSheet(this@PlansActivity, ::onPaymentSheetResult)

       // getPlans()

        binding.oneMonth.setOnClickListener {
            presentPaymentSheet()
        }

    }

    private fun getPlans() {
        var token = sharedPreference.getData("token").toString()

        val planCall = RetrofitClient.apiService.getPlans("Bearer $token")
        planCall.enqueue(object : Callback<PlanModel> {
            override fun onResponse(call: Call<PlanModel>, response: Response<PlanModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        planList = apiResponse.data as List<DataItem>
                        planAdapter =
                            PlanAdapter(planList, this@PlansActivity, this@PlansActivity)
                        binding.planRcy.adapter = planAdapter

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@PlansActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@PlansActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@PlansActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }

            }

            override fun onFailure(call: Call<PlanModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@PlansActivity, t.message.toString(), Color.RED)

            }
        })

    }

    fun back(view: View) {
        finish()
    }

    override fun onPlanItemClick(dataItem: DataItem) {

        val decimalValue = dataItem.price
        val intValue = decimalValue?.toDouble()?.toInt()
        // binding.descriptionPlan.text = dataItem.description
        val params = listOf("currency" to "eur", "amount" to intValue)

        endpoint.httpPost(params).responseJson { _, _, result ->
            if (result is Result.Success) {
                val responseJson = result.get().obj()
                paymentIntentClientSecret = responseJson.getString("paymentIntent")
                customerConfig = PaymentSheet.CustomerConfiguration(
                    responseJson.getString("customer"),
                    responseJson.getString("ephemeralKey")
                )
                val publishableKey = responseJson.getString("publishableKey")
                PaymentConfiguration.init(this, publishableKey)

                Log.e("MainStripePayment", "Successfully to fetch payment details")

                // After obtaining payment details, enable payment button or proceed with payment
                //enablePaymentButton()
            } else {
                // Handle HTTP request failure
                Log.e("MainStripePayment", "Failed to fetch payment details")
            }
        }
    }


    private fun paymentSuccessfully() {
        val dialog = Dialog(this@PlansActivity)
        dialog.setContentView(R.layout.payment_dialog)
        dialog.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(false)
        dialog.window!!.attributes.windowAnimations = R.style.animation
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        val yes = dialog.findViewById<ElasticButton>(R.id.yes)
        val no = dialog.findViewById<TextView>(R.id.no)

        yes.setOnClickListener {
            dialog.dismiss()
            finish()
        }
        no.setOnClickListener { dialog.dismiss() }
        dialog.show()
    }

    private fun paymentFailed() {
        val dialog = Dialog(this@PlansActivity)
        dialog.setContentView(R.layout.payment_failed_dialog)
        dialog.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(false)
        dialog.window!!.attributes.windowAnimations = R.style.animation
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        val yes = dialog.findViewById<ElasticButton>(R.id.tryAgain)
        val no = dialog.findViewById<TextView>(R.id.not_now)

        yes.setOnClickListener {
            dialog.dismiss()
            presentPaymentSheet()
        }
        no.setOnClickListener {
            dialog.dismiss()
            finish()
        }
        dialog.show()
    }

    @SuppressLint("MissingSuperCall")
    override fun onBackPressed() {
        finish()
    }



    private fun presentPaymentSheet() {
        // Ensure that paymentIntentClientSecret and customerConfig are initialized
        if (::paymentIntentClientSecret.isInitialized && ::customerConfig.isInitialized) {
            paymentSheet.presentWithPaymentIntent(
                paymentIntentClientSecret,
                PaymentSheet.Configuration(
                    merchantDisplayName = "My merchant name",
                    customer = customerConfig,
                    allowsDelayedPaymentMethods = true
                )
            )
        } else {
            // Handle case where payment details are not yet fetched
            SnackBarUtils.showTopSnackbar(
                this@PlansActivity,
                "Payment details are not yet fetched \n Please try again!",
                Color.RED
            )
            Log.e("MainStripePayment", "Payment details are not yet fetched")
        }
    }

    private fun onPaymentSheetResult(paymentSheetResult: PaymentSheetResult) {
        // Handle payment sheet result
        // This function will be called after the payment is completed or canceled
        when (paymentSheetResult) {
            is PaymentSheetResult.Canceled -> {
                paymentFailed()
                Log.d("MainStripePayment", "Payment canceled")
            }

            is PaymentSheetResult.Failed -> {
                paymentFailed()
                Log.e("MainStripePayment", "Payment failed: ${paymentSheetResult.error}")
            }

            is PaymentSheetResult.Completed -> {
                Log.d("MainStripePayment", "Payment completed")
                // You can navigate to the order confirmation screen or perform other actions here
                paymentSuccessfully()
            }
        }
    }
}
