package codeflies.com.mcc.Activity

import android.app.Activity
import android.app.ProgressDialog
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.PriceAdapter
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.PriceData
import codeflies.com.mcc.Model.PriceModel
import codeflies.com.mcc.databinding.ActivityPriceBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class PriceActivity : AppCompatActivity(),PriceAdapter.PriceItemClickListener {

    private lateinit var binding: ActivityPriceBinding
    private lateinit var sharedPreference: SharedPreference
    private lateinit var priceAdapter: PriceAdapter
    private lateinit var priceList: List<PriceData>

    private val progressDialog by lazy {
        ProgressDialog(this@PriceActivity).apply {
            setMessage("Please wait...")
            setCancelable(false)
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityPriceBinding.inflate(layoutInflater)
        setContentView(binding.root)

        sharedPreference = SharedPreference(this@PriceActivity)

        progressDialog.show()

        binding.back.setOnClickListener {
            finish()
        }
        getPrice()

    }

    private fun getPrice() {
            var token = sharedPreference.getData("token").toString()

            val countryCall = RetrofitClient.apiService.getPriceData("Bearer " + token)

            countryCall.enqueue(object : Callback<PriceModel> {
                override fun onResponse(call: Call<PriceModel>, response: Response<PriceModel>) {
                    progressDialog.dismiss()
                    if (response.isSuccessful) {
                        val apiResponse = response.body()
                        if (apiResponse != null && apiResponse.status) {
                            priceList = apiResponse.data
                            priceAdapter = PriceAdapter(priceList, this@PriceActivity,this@PriceActivity)
                            binding.priceRcy.adapter = priceAdapter

                        } else {
                            SnackBarUtils.showTopSnackbar(
                                this@PriceActivity,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    } else {
                        val errorResponse = response.errorBody()?.string()
                        val gson = Gson()
                        try {
                            val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                            val errorMessage = errorJson.get("message").asString
                            SnackBarUtils.showTopSnackbar(
                                this@PriceActivity,
                                errorMessage.toString(),
                                Color.RED
                            )
                        } catch (e: Exception) {
                            SnackBarUtils.showTopSnackbar(
                                this@PriceActivity,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }

                }

                override fun onFailure(call: Call<PriceModel>, t: Throwable) {
                    progressDialog.dismiss()
                    SnackBarUtils.showTopSnackbar(this@PriceActivity, t.message.toString(), Color.RED)

                }
            })



    }

    override fun onPriceItemClick(priceData: PriceData) {

        val resultIntent = Intent()
        resultIntent.putExtra("priceInfo", priceData.name + "," + priceData.id)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()
    }
}