package codeflies.com.mcc.Activity

import android.app.Activity
import android.app.ProgressDialog
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.RatingAdapter
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.RatingData
import codeflies.com.mcc.Model.RatingModel
import codeflies.com.mcc.databinding.ActivityRatingBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class RatingActivity : AppCompatActivity() ,RatingAdapter.RatingItemClickListener{
    private lateinit var binding: ActivityRatingBinding
    private lateinit var sharedPreference: SharedPreference
    private lateinit var ratingAdapter: RatingAdapter
    private lateinit var ratingList: List<RatingData>

    private val progressDialog by lazy {
        ProgressDialog(this@RatingActivity).apply {
            setMessage("Please wait...")
            setCancelable(false)
        }
    }
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityRatingBinding.inflate(layoutInflater)
        setContentView(binding.root)

        sharedPreference = SharedPreference(this@RatingActivity)

        progressDialog.show()

        binding.back.setOnClickListener {
            finish()
        }
        getRating()

    }

    private fun getRating() {
        val token = sharedPreference.getData("token").toString()

        val countryCall = RetrofitClient.apiService.getRatingData("Bearer " + token)

        countryCall.enqueue(object : Callback<RatingModel> {
            override fun onResponse(call: Call<RatingModel>, response: Response<RatingModel>) {
                progressDialog.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        ratingList = apiResponse.data
                        ratingAdapter = RatingAdapter(ratingList, this@RatingActivity,this@RatingActivity)
                        binding.countryRcy.adapter = ratingAdapter

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@RatingActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@RatingActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@RatingActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }

            }

            override fun onFailure(call: Call<RatingModel>, t: Throwable) {
                progressDialog.dismiss()
                SnackBarUtils.showTopSnackbar(this@RatingActivity, t.message.toString(), Color.RED)

            }
        })


    }

    override fun onRatingItemClick(ratingItem: RatingData) {
        val resultIntent = Intent()
        resultIntent.putExtra("ratingInfo", ratingItem.name + "," + ratingItem.id)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()    }
}