package codeflies.com.mcc.Activity

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.method.HideReturnsTransformationMethod
import android.text.method.PasswordTransformationMethod
import android.util.Log
import android.view.View
import android.view.inputmethod.InputMethodManager
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.Reminders
import codeflies.com.mcc.Model.SignUpModel
import codeflies.com.mcc.Model.SubscribersUser
import codeflies.com.mcc.databinding.ActivityRegisterBinding
import com.google.firebase.messaging.FirebaseMessaging
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class RegisterActivity : AppCompatActivity() {

    private lateinit var binding: ActivityRegisterBinding
    var confirmPs = ""
    var password = ""
    var Fcm_token = ""
    var valueNew = 0
    var valueConfirm = 0

    var emailPattern = ("^(([\\w-]+\\.)+[\\w-]+|([a-zA-Z]{1}|[\\w-]{2,}))@"
            + "((([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
            + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\."
            + "([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
            + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])){1}|"
            + "([a-zA-Z]+[\\w-]+\\.)+[a-zA-Z]{2,4})$")

    var sharedPreference: SharedPreference? = null


    private lateinit var progressDisplay: ProgressDisplay


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityRegisterBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@RegisterActivity)
        sharedPreference = SharedPreference(this@RegisterActivity)


        binding.registerBtn.setOnClickListener {

            hideKeyboard()

            confirmPs = binding.cnfmPassword.getText().toString();
            password = binding.password.getText().toString();

            if (regiValidation()) {
                if (binding.email.getText().toString().matches(emailPattern.toRegex())) {
                    if (binding.radioTerms.isChecked) {
                        userEmailRegistration()
                        progressDisplay.show()
                    } else {
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Please select Terms & Conditions!",Color.RED)
                    }
                } else {
                    SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Enter valid email pattern",Color.RED)
                    binding.email.requestFocus();
                }
            }
        }

        binding.termsBtn.setOnClickListener {
            startActivity(Intent(this@RegisterActivity,TermsActivity::class.java))
        }


        binding.newShowPassword.setOnClickListener {
            valueNew = 1
            changeNewType(valueNew)
        }
        binding.newHidePassword.setOnClickListener {
            valueNew = 2
            changeNewType(valueNew)
        }
        binding.cnfmShowPassword.setOnClickListener {
            valueConfirm = 1
            changeCnfmType(valueConfirm)
        }
        binding.cnfmHidePassword.setOnClickListener {
            valueConfirm = 2
            changeCnfmType(valueConfirm)
        }
        getUsers()


        FirebaseMessaging.getInstance().token.addOnCompleteListener { task ->
            if (task.isSuccessful) {
                Fcm_token = task.result
                Log.d("FCM Token", "Token: $Fcm_token")
                // Now you can use the token as needed, such as sending it to your server for notifications
            } else {
                Log.e("FCM Token", "Failed to get token: ${task.exception}")
            }
        }
    }

    private fun getUsers() {
        val userCall = RetrofitClient.apiService.getUserAnalytics()

        userCall.enqueue(object : Callback<SubscribersUser>{
            override fun onResponse(
                call: Call<SubscribersUser>,
                response: Response<SubscribersUser>
            ) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        binding.subscribeID.text = apiResponse.data?.totalUsers.toString()

                    } else {
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,apiResponse?.message.toString(),Color.RED)
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,errorMessage.toString(),Color.RED)
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,e.message.toString(),Color.RED)
                    }
                }
            }

            override fun onFailure(call: Call<SubscribersUser>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@RegisterActivity, t.message.toString(),Color.RED)
            }

        })
    }

    private fun userEmailRegistration() {
        val signCall = RetrofitClient.apiService.signUp(
            binding.firstName.text.toString(),
            binding.lastName.text.toString(),
            binding.email.text.toString(),
            binding.password.text.toString(),
            binding.cnfmPassword.text.toString(),
            Fcm_token,
            "",
            "","android"
        )

        signCall.enqueue(object : Callback<SignUpModel> {
            override fun onResponse(call: Call<SignUpModel>, response: Response<SignUpModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,apiResponse.message.toString(),
                            Color.parseColor("#ca9730"))
                        sharedPreference?.saveData("token",apiResponse.data.token)
                        sharedPreference?.saveData("user_id",apiResponse.data.id)
                        saveCarData(response.body()?.data?.reminders)
                        startActivity(Intent(this@RegisterActivity,MainActivity::class.java))
                        finishAffinity()

                    } else {
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,apiResponse?.message.toString(),Color.RED)
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,errorMessage.toString(),Color.RED)
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(this@RegisterActivity,e.message.toString(),Color.RED)
                    }
                }
            }

            override fun onFailure(call: Call<SignUpModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@RegisterActivity, t.message.toString(),Color.RED)
            }
        })
    }

    fun have_account(view: View) {
        startActivity(Intent(this@RegisterActivity, LoginActivity::class.java))
        finishAffinity()
    }

    fun back(view: View) {
        finish()
    }


    private fun regiValidation(): Boolean {
        if (binding.firstName.text.toString().trim().isEmpty()) {
            SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Invalid first name",Color.RED)
            binding.firstName.requestFocus()
            return false
        } else if (binding.lastName.text.toString().trim().isEmpty()) {
            SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Invalid last name",Color.RED)
            binding.lastName.requestFocus()
            return false
        } else if (binding.email.text.toString().trim().isEmpty()) {
            SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Invalid email",Color.RED)
            binding.email.requestFocus()
            return false
        } else if (binding.password.text.toString().trim().length <= 5) {
            SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Password length should be grater then 6 !",Color.RED)
            binding.password.requestFocus()
            return false
        } else if (binding.cnfmPassword.text.toString().trim().length <= 5) {
            SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Confirm Password length should be grater then 6 !",Color.RED)
            binding.cnfmPassword.requestFocus()
            return false
        } else if (!confirmPs.equals(password)) {
            SnackBarUtils.showTopSnackbar(this@RegisterActivity,"Password and confirm password does not match",Color.RED)
            binding.cnfmPassword.requestFocus()
            return false
        }
        return true
    }
    private fun hideKeyboard() {
        val imm = getSystemService(Context.INPUT_METHOD_SERVICE) as InputMethodManager
        imm.hideSoftInputFromWindow(currentFocus?.windowToken, 0)
    }


    private fun changeCnfmType(value: Int) {
        if (value == 1) {
            binding.cnfmPassword.transformationMethod = HideReturnsTransformationMethod.getInstance()
            binding.cnfmHidePassword.visibility = View.VISIBLE
            binding.cnfmShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding.cnfmPassword.transformationMethod = PasswordTransformationMethod.getInstance()
            binding.cnfmHidePassword.visibility = View.GONE
            binding.cnfmShowPassword.visibility = View.VISIBLE
        }
    }

    private fun changeNewType(value: Int) {
        if (value == 1) {
            binding.password.transformationMethod = HideReturnsTransformationMethod.getInstance()
            binding.newHidePassword.visibility = View.VISIBLE
            binding.newShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding.password.transformationMethod = PasswordTransformationMethod.getInstance()
            binding.newHidePassword.visibility = View.GONE
            binding.newShowPassword.visibility = View.VISIBLE
        }
    }

    fun saveCarData(reminders: List<Reminders?>?) {
        if (reminders != null && reminders.isNotEmpty()) {
            for (reminder in reminders) {
                if (reminder?.name == "car") {
                    sharedPreference?.saveData("car_value", reminder.name)
                    sharedPreference?.saveData("car_status", reminder.is_enabled.toString())
                } else if (reminder?.name == "member") {
                    sharedPreference?.saveData("member_value", reminder.name)
                    sharedPreference?.saveData("member_status", reminder.is_enabled.toString())
                } else if (reminder?.name == "policy") {
                    sharedPreference?.saveData("policy_value", reminder.name)
                    sharedPreference?.saveData("policy_status", reminder.is_enabled.toString())
                } else if (reminder?.name == "repair") {
                    sharedPreference?.saveData("repair_value", reminder.name)
                    sharedPreference?.saveData("repair_status", reminder.is_enabled.toString())
                } else if (reminder?.name == "service") {
                    sharedPreference?.saveData("service_value", reminder.name)
                    sharedPreference?.saveData("service_status", reminder.is_enabled.toString())
                }
            }
        }
    }

}