package codeflies.com.mcc.Activity

import android.graphics.Color
import android.os.Bundle
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.databinding.ActivityReminderBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class ReminderActivity : AppCompatActivity() {

    private lateinit var binding: ActivityReminderBinding

    var carStatus = 0
    var memberStatus = 0
    var policyStatus = 0
    var repairStatus = 0
    var serviceStatus = 0

    private lateinit var sharedPreference: SharedPreference

    var carValue = "car"
    var memberValue = "member"
    var policyValue = "policy"
    var repairValue = "repair"
    var serviceValue = "service"
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityReminderBinding.inflate(layoutInflater)
        setContentView(binding.root)

        sharedPreference = SharedPreference(this@ReminderActivity)


        if (!sharedPreference.getData("car_status").equals("")) {
            carStatus = sharedPreference.getData("car_status")!!.toInt()
        }
        if (!sharedPreference.getData("member_status").equals("")) {
            memberStatus = sharedPreference.getData("member_status")!!.toInt()
        }
        if (!sharedPreference.getData("policy_status").equals("")) {
            policyStatus = sharedPreference.getData("policy_status")!!.toInt()
        }
        if (!sharedPreference.getData("repair_status").equals("")) {
            repairStatus = sharedPreference.getData("repair_status")!!.toInt()
        }
        if (!sharedPreference.getData("service_status").equals("")) {
            serviceStatus = sharedPreference.getData("service_status")!!.toInt()
        }


        if (carStatus == 0) {
            binding.carTextStatus.text = "OFF"
        } else {
            binding.carTextStatus.text = "ON"
            binding.carSwitchMaterial.isChecked = true
        }
        if (memberStatus == 0) {
            binding.memberTextStatus.text = "OFF"
        } else {
            binding.memberTextStatus.text = "ON"
            binding.memberSwitchMaterial.isChecked = true
        }
        if (policyStatus == 0) {
            binding.policyTextStatus.text = "OFF"
        } else {
            binding.policyTextStatus.text = "ON"
            binding.policySwitchMaterial.isChecked = true
        }
        if (repairStatus == 0) {
            binding.repairTextStatus.text = "OFF"
        } else {
            binding.repairTextStatus.text = "ON"
            binding.repairSwitchMaterial.isChecked = true
        }
        if (serviceStatus == 0) {
            binding.serviceTextStatus.text = "OFF"
        } else {
            binding.serviceTextStatus.text = "ON"
            binding.serviceSwitchMaterial.isChecked = true
        }


        binding.carSwitchMaterial.setOnCheckedChangeListener { _, isChecked ->
            binding.carTextStatus.text = if (isChecked) "ON" else "OFF"

            if (isChecked) {
                changeStatus(1, carValue)
            } else {
                changeStatus(0, carValue)
            }
        }
        binding.memberSwitchMaterial.setOnCheckedChangeListener { _, isChecked ->
            binding.memberTextStatus.text = if (isChecked) "ON" else "OFF"

            if (isChecked) {
                changeStatus(1, memberValue)
            } else {
                changeStatus(0, memberValue)
            }
        }
        binding.policySwitchMaterial.setOnCheckedChangeListener { _, isChecked ->
            binding.policyTextStatus.text = if (isChecked) "ON" else "OFF"

            if (isChecked) {
                changeStatus(1, policyValue)
            } else {
                changeStatus(0, policyValue)
            }
        }
        binding.repairSwitchMaterial.setOnCheckedChangeListener { _, isChecked ->
            binding.repairTextStatus.text = if (isChecked) "ON" else "OFF"

            if (isChecked) {
                changeStatus(1, repairValue)
            } else {
                changeStatus(0, repairValue)
            }
        }
        binding.serviceSwitchMaterial.setOnCheckedChangeListener { _, isChecked ->
            binding.serviceTextStatus.text = if (isChecked) "ON" else "OFF"

            if (isChecked) {
                changeStatus(1, serviceValue)
            } else {
                changeStatus(0, serviceValue)
            }
        }


    }

    private fun changeStatus(status: Int, value: String) {
        var token = sharedPreference.getData("token").toString()

        val statusCall = RetrofitClient.apiService.reminderStatusChange(
            "Bearer $token",
            value, status
        )
        statusCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            this@ReminderActivity,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )

                        if (value.equals("car")) {
                            sharedPreference.saveData("car_status", status.toString())
                        } else if (value.equals("member")) {
                            sharedPreference.saveData("member_status", status.toString())
                        } else if (value.equals("policy")) {
                            sharedPreference.saveData("policy_status", status.toString())
                        } else if (value.equals("repair")) {
                            sharedPreference.saveData("repair_status", status.toString())
                        } else if (value.equals("service")) {
                            sharedPreference.saveData("service_status", status.toString())
                        }


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@ReminderActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@ReminderActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@ReminderActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                SnackBarUtils.showTopSnackbar(
                    this@ReminderActivity,
                    t.message.toString(),
                    Color.RED
                )

            }

        })

    }

    fun back(view: View) {
        finish()
    }
}