package codeflies.com.mcc.Activity

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Adapter.RepairImageAdapter
import codeflies.com.mcc.Adapter.RepairViewAdapter
import codeflies.com.mcc.Fragment.AddCarServicesFragment
import codeflies.com.mcc.Fragment.AddRepairsFragment
import codeflies.com.mcc.Fragment.HomeFragment
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.Image
import codeflies.com.mcc.Model.UpcomingRepairsResponse
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.ActivityRepairDetailsBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.text.ParseException
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Timer
import java.util.TimerTask

class RepairDetailsActivity : AppCompatActivity() {

    private lateinit var binding: ActivityRepairDetailsBinding
    var homeViewPAdapter: RepairViewAdapter? = null
    var count = 0
    var banner: ArrayList<Image> = ArrayList<Image>()
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay
    var planStatus = 0


    companion object {
        lateinit var vehicleId: String
    }


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityRepairDetailsBinding.inflate(layoutInflater)
        setContentView(binding.root)


        progressDisplay = ProgressDisplay(this@RepairDetailsActivity)
        sharedPreference = SharedPreference(this@RepairDetailsActivity)

        getListRepairs()
        progressDisplay.show()

        if (planStatus != 0) {
            binding.repairImageRcy.visibility = View.VISIBLE
        }

    }

    fun back(view: View) {
        finish()
    }


    private fun getListRepairs() {
        var token = sharedPreference.getData("token").toString()

        val repairsCall = RetrofitClient.apiService.getRepairDetails("Bearer $token", vehicleId)

        repairsCall.enqueue(object : Callback<UpcomingRepairsResponse> {
            override fun onResponse(
                call: Call<UpcomingRepairsResponse>,
                response: Response<UpcomingRepairsResponse>
            ) {
                progressDisplay.dismiss()
                MainActivity.status = true
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        if (apiResponse.data?.isNotEmpty() == true) {

                            binding.commonTitleTop.text = apiResponse.data.get(0)!!.vehicle!!.name
                            binding.carModel.text = apiResponse.data.get(0)!!.vehicle!!.brandName
                            binding.carNames.text = apiResponse.data.get(0)!!.vehicle!!.modelName
                            binding.CarNumber.text = apiResponse.data.get(0)!!.vehicle!!.regPlateNumber
                            binding.serviceName.text = apiResponse.data.get(0)!!.repairCenter
                            binding.serviceType.text = apiResponse.data.get(0)!!.notes
                            binding.kmValue.text = apiResponse.data.get(0)!!.mileage
                            binding.captionDetails.text = apiResponse.data.get(0)!!.serviceCaption


                            try {
                                val inputFormat = SimpleDateFormat("yyyy-MM-dd HH:mm:ss")
                                val outputFormat = SimpleDateFormat("yyyy-MM-dd")

                                val date: Date =
                                    inputFormat.parse(apiResponse.data.get(0)!!.repairDate)
                                val outputDate: String = outputFormat.format(date)
                                binding.date.text = outputDate

                            } catch (e: ParseException) {
                                e.printStackTrace()
                            }

                            binding.editRepair.setOnClickListener {
                                AddRepairsFragment.dataItemDetails = apiResponse.data[0]

                                startActivity(Intent(this@RepairDetailsActivity, CommonActivity::class.java))
                                // Start the fragment
                                CommonActivity.replaceFragment = AddRepairsFragment()
                                CommonActivity.titleTop = getString(R.string.add_repair)
                            }

                            homeViewPAdapter = RepairViewAdapter(
                                this@RepairDetailsActivity,
                                apiResponse.data.get(0)!!.vehicle!!.images
                            )
                            binding.serviceViewPager.adapter = homeViewPAdapter
                            binding.serviceViewPagerDots.attachTo(binding.serviceViewPager)

                            val handler = Handler()
                            val update = object : Runnable {
                                override fun run() {
                                    // Check if binding is not null before accessing it
                                    if (binding != null && count < banner.size) {
                                        binding.serviceViewPager.setCurrentItem(count++, true)
                                    }
                                }
                            }

                            val timer = Timer()
                            timer.schedule(object : TimerTask() {
                                override fun run() {
                                    handler.post(update)
                                }
                            }, 5000, 3000)

                            if (apiResponse.data.get(0)!!.vehicleRepairImages?.isNotEmpty() == true) {

                                if (HomeFragment.isTablet) {
                                    binding.repairImageRcy.layoutManager =
                                        GridLayoutManager(this@RepairDetailsActivity, 4)

                                } else {
                                    binding.repairImageRcy.layoutManager =
                                        GridLayoutManager(this@RepairDetailsActivity, 2)

                                }

                                val repairImageAdapter = RepairImageAdapter(
                                    this@RepairDetailsActivity,
                                    apiResponse.data.get(0)!!.vehicleRepairImages
                                )
                                binding.repairImageRcy.adapter =
                                    repairImageAdapter as RecyclerView.Adapter<RecyclerView.ViewHolder>?

                            }
                        }
                    } else {

                        SnackBarUtils.showTopSnackbar(
                            this@RepairDetailsActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString

                        SnackBarUtils.showTopSnackbar(
                            this@RepairDetailsActivity,
                            errorMessage.toString(),
                            Color.RED
                        )

                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@RepairDetailsActivity,
                            e.message.toString(),
                            Color.RED
                        )

                    }
                }


            }

            override fun onFailure(call: Call<UpcomingRepairsResponse>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                SnackBarUtils.showTopSnackbar(
                    this@RepairDetailsActivity,
                    t.message.toString(),
                    Color.RED
                )


            }
        })


    }


}