package codeflies.com.mcc.Activity

import android.graphics.Color
import android.os.Bundle
import android.util.Log
import android.view.View
import android.widget.AdapterView
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Adapter.CustomExportCarAdapter
import codeflies.com.mcc.Adapter.ExportMainAdapter
import codeflies.com.mcc.Helper.Constants
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CarItem
import codeflies.com.mcc.Model.CarListModel
import codeflies.com.mcc.Model.ExportResponse
import codeflies.com.mcc.Model.PDFResponse
import codeflies.com.mcc.databinding.ActivityReportExportBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class ReportExportActivity : AppCompatActivity() {

    var carID = ""
    var selectedValue = ""
    var selectedId = ""
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay
    private lateinit var carItem: List<CarItem>
    private lateinit var customExportCarAdapter: CustomExportCarAdapter


    private lateinit var binding: ActivityReportExportBinding
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityReportExportBinding.inflate(layoutInflater)
        setContentView(binding.root)


        sharedPreference = SharedPreference(this@ReportExportActivity)
        progressDisplay = ProgressDisplay(this@ReportExportActivity)



     //   getExportDetails()
      //  progressDisplay.show()

       // getCarList()

        binding.downImage.setOnClickListener {
            binding.serviceCarName.performClick()
        }


        binding.serviceCarName.onItemSelectedListener =
            object : AdapterView.OnItemSelectedListener {
                override fun onItemSelected(
                    parent: AdapterView<*>?,
                    view: View?,
                    position: Int,
                    id: Long
                ) {
                    val selectedItem = parent?.getItemAtPosition(position) as? CarItem
                    selectedItem?.let {
                        selectedValue = it.name.toString()
                        selectedId = it.id.toString()

                        if (selectedId.equals("0")) {
                            carID = ""
                            getExportDetails()
                            progressDisplay.show()
                        } else {
                            carID = selectedId
                            getExportDetails()
                            progressDisplay.show()
                        }
                        // Now you can use the selectedValue and selectedId as needed
                    }
                }

                override fun onNothingSelected(parent: AdapterView<*>?) {
                    // Handle case where nothing is selected
                }
            }


        binding.downloadPdf.setOnClickListener {
            progressDisplay.show()
            getPDFUrl()
        }
    }

    private fun getPDFUrl() {

        val token = sharedPreference.getData("token").toString()
        val user_id = sharedPreference.getData("user_id").toString()

        val reportCall = RetrofitClient.apiService.getPDFData("Bearer $token", user_id, carID)

        reportCall.enqueue(object : Callback<PDFResponse> {
            override fun onResponse(
                call: Call<PDFResponse>,
                response: Response<PDFResponse>
            ) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {

                        Log.e("dakvkd", "jadkvnadjkvsd")
                        Constants.downloadPDF(
                            this@ReportExportActivity,
                            apiResponse.pdfUrl.toString().substringAfterLast('/'),
                            apiResponse.pdfUrl
                        )

                    } else {
                        // Handle unsuccessful response with message

                        SnackBarUtils.showTopSnackbar(
                            this@ReportExportActivity,
                            apiResponse?.message ?: "Unknown error",
                            Color.RED
                        )

                    }
                } else {
                    // Handle unsuccessful response
                    val errorMessage = response.errorBody()?.string() ?: "Unknown error"

                    SnackBarUtils.showTopSnackbar(
                        this@ReportExportActivity,
                        errorMessage,
                        Color.RED
                    )

                }
            }

            override fun onFailure(call: Call<PDFResponse>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@ReportExportActivity,
                    t.message ?: "Unknown error",
                    Color.RED
                )
            }
        })


    }

    private fun getExportDetails() {
        val token = sharedPreference.getData("token").toString()
        val user_id = sharedPreference.getData("user_id").toString()

        val reportCall = RetrofitClient.apiService.getReportData("Bearer $token", user_id, carID)

        reportCall.enqueue(object : Callback<ExportResponse> {
            override fun onResponse(
                call: Call<ExportResponse>,
                response: Response<ExportResponse>
            ) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        if (apiResponse.data?.isNotEmpty() == true) {

                            binding.exportRcy.visibility = View.VISIBLE
                            val adapter =
                                ExportMainAdapter(
                                    this@ReportExportActivity,
                                    apiResponse.data
                                )

                            binding.exportRcy.adapter =
                                adapter as RecyclerView.Adapter<RecyclerView.ViewHolder>?

                        }


                    } else {
                        // Handle unsuccessful response with message

                        SnackBarUtils.showTopSnackbar(
                            this@ReportExportActivity,
                            apiResponse?.message ?: "Unknown error",
                            Color.RED
                        )

                    }
                } else {
                    // Handle unsuccessful response
                    val errorMessage = response.errorBody()?.string() ?: "Unknown error"

                    SnackBarUtils.showTopSnackbar(
                        this@ReportExportActivity,
                        errorMessage,
                        Color.RED
                    )

                }
            }

            override fun onFailure(call: Call<ExportResponse>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@ReportExportActivity,
                    t.message ?: "Unknown error",
                    Color.RED
                )
            }
        })

    }


    fun back(view: View) {
        finish()
    }


    private fun getCarList() {
        progressDisplay.show()
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()


        val countryCall = RetrofitClient.apiService.getCarListData("Bearer $token", user_id)

        countryCall.enqueue(object : Callback<CarListModel> {
            override fun onResponse(call: Call<CarListModel>, response: Response<CarListModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        carItem = apiResponse.data as List<CarItem>

                        Log.e("carItem.size", carItem.size.toString())
                        if (carItem.isNotEmpty()) {
                            val staticValue = CarItem(name = "Select a car", id = "0")
                            val modifiedList = mutableListOf<CarItem?>()
                            modifiedList.add(staticValue)
                            modifiedList.addAll(carItem)

                            customExportCarAdapter =
                                CustomExportCarAdapter(modifiedList, this@ReportExportActivity)
                            binding.serviceCarName.adapter = customExportCarAdapter
                        } else {
                            SnackBarUtils.showTopSnackbar(
                                this@ReportExportActivity,
                                "Please add a car first!",
                                Color.RED
                            )
                        }

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@ReportExportActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@ReportExportActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@ReportExportActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<CarListModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@ReportExportActivity,
                    t.message.toString(),
                    Color.RED
                )
            }
        })

    }


}