package codeflies.com.mcc.Activity

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Adapter.ServiceImageAdapter
import codeflies.com.mcc.Adapter.ServiceViewPAdapter
import codeflies.com.mcc.Fragment.AddCarServicesFragment
import codeflies.com.mcc.Fragment.AddServicesFragment
import codeflies.com.mcc.Fragment.HomeFragment
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.Image
import codeflies.com.mcc.Model.ImagesItemDetails
import codeflies.com.mcc.Model.ServiceDetailsResponse
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.ActivityServiceDetailsBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.io.Serializable
import java.text.ParseException
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Timer
import java.util.TimerTask

class ServiceDetailsActivity : AppCompatActivity(), ServiceViewPAdapter.ServiceViewBanner {

    private lateinit var binding: ActivityServiceDetailsBinding
    private lateinit var progressDisplay: ProgressDisplay
    private lateinit var sharedPreference: SharedPreference
    var banner: ArrayList<Image> = ArrayList<Image>()
    var homeViewPAdapter: ServiceViewPAdapter? = null
    var count = 0
    var planStatus = 0

    companion object {
        var serviceId = ""

    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityServiceDetailsBinding.inflate(layoutInflater)
        setContentView(binding.root)
        progressDisplay = ProgressDisplay(this@ServiceDetailsActivity)
        sharedPreference = SharedPreference(this@ServiceDetailsActivity)



        progressDisplay.show()
        getCarServiceDetails()

        if (planStatus != 0) {
            binding.serviceImageRcy.visibility = View.VISIBLE
        }

    }

    private fun getCarServiceDetails() {
        var token = sharedPreference.getData("token").toString()

        val servicesDetailsCall =
            RetrofitClient.apiService.getServiceData("Bearer $token", serviceId)

        servicesDetailsCall.enqueue(object : Callback<ServiceDetailsResponse> {
            override fun onResponse(
                call: Call<ServiceDetailsResponse>,
                response: Response<ServiceDetailsResponse>
            ) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        if (apiResponse.data?.isNotEmpty() == true) {

                            binding.commonTitleTop.text = apiResponse.data[0]!!.vehicle!!.name
                            binding.carModel.text = apiResponse.data[0]!!.vehicle!!.brandName
                            binding.carNames.text = apiResponse.data[0]!!.vehicle!!.modelName
                            binding.CarNumber.text = apiResponse.data[0]!!.vehicle!!.regPlateNumber
                            binding.serviceName.text = apiResponse.data[0]!!.centerName
                            binding.serviceType.text = apiResponse.data[0]!!.serviceType!!.name
                            binding.kmValue.text = apiResponse.data[0]!!.performedAt

                            try {
                                val inputFormat = SimpleDateFormat("yyyy-MM-dd HH:mm:ss")
                                val outputFormat = SimpleDateFormat("yyyy-MM-dd")

                                val date: Date = inputFormat.parse(apiResponse.data[0]!!.performedDate)
                                val outputDate: String = outputFormat.format(date)
                                binding.date.text = outputDate

                            } catch (e: ParseException) {
                                e.printStackTrace()
                            }

                            binding.editService.setOnClickListener {

                                AddCarServicesFragment.dataItemDetails = apiResponse.data[0]

                                startActivity(Intent(this@ServiceDetailsActivity, CommonActivity::class.java))
                                // Start the fragment
                                CommonActivity.replaceFragment = AddCarServicesFragment()
                                CommonActivity.titleTop = getString(R.string.add_car_services)


                            }

                            if (apiResponse.data[0]!!.vehicle!!.checkRegExpiry == true){
                                binding.regGreenFlag.visibility = View.VISIBLE
                                binding.regRedFlag.visibility = View.GONE
                            }else {
                                binding.regGreenFlag.visibility = View.GONE
                                binding.regRedFlag.visibility = View.VISIBLE
                            }


                            homeViewPAdapter = ServiceViewPAdapter(
                                this@ServiceDetailsActivity,
                                apiResponse.data[0]!!.vehicle!!.images, this@ServiceDetailsActivity
                            )
                            binding.serviceViewPager.adapter = homeViewPAdapter
                            binding.serviceViewPagerDots.attachTo(binding.serviceViewPager)

                            val handler = Handler()
                            val update = object : Runnable {
                                override fun run() {
                                    // Check if binding is not null before accessing it
                                    if (binding != null && count < banner.size) {
                                        binding.serviceViewPager.setCurrentItem(count++, true)
                                    }
                                }
                            }

                            val timer = Timer()
                            timer.schedule(object : TimerTask() {
                                override fun run() {
                                    handler.post(update)
                                }
                            }, 5000, 3000)

                            if (apiResponse.data.get(0)!!.vehicleServiceImages?.isNotEmpty() == true) {

                                if (HomeFragment.isTablet) {
                                    binding.serviceImageRcy.layoutManager =
                                        GridLayoutManager(this@ServiceDetailsActivity, 4)

                                } else {
                                    binding.serviceImageRcy.layoutManager =
                                        GridLayoutManager(this@ServiceDetailsActivity, 2)

                                }

                                val serviceImageAdapter = ServiceImageAdapter(
                                    this@ServiceDetailsActivity,
                                    apiResponse.data.get(0)!!.vehicleServiceImages
                                )
                                binding.serviceImageRcy.adapter =
                                    serviceImageAdapter as RecyclerView.Adapter<RecyclerView.ViewHolder>?

                            }


                        }
                    } else {

                        SnackBarUtils.showTopSnackbar(
                            this@ServiceDetailsActivity, apiResponse?.message.toString(),
                            Color.RED
                        )

                    }
                } else {
                    // Handle error response
                }


            }

            override fun onFailure(call: Call<ServiceDetailsResponse>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                SnackBarUtils.showTopSnackbar(
                    this@ServiceDetailsActivity,
                    t.message.toString(),
                    Color.RED
                )
            }

        })

    }

    override fun homebannerdata(data: List<ImagesItemDetails?>?, position: Int) {

    }

    fun back(view: View) {
        finish()
    }
}
