package codeflies.com.mcc.Activity

import android.annotation.SuppressLint
import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.util.Log
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.CarListAdapter
import codeflies.com.mcc.Adapter.OnCarClickListener
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CarItem
import codeflies.com.mcc.Model.CarListModel
import codeflies.com.mcc.databinding.ActivityServiceTypeBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class ServiceTypeActivity : AppCompatActivity(), OnCarClickListener {

    private lateinit var binging: ActivityServiceTypeBinding
    private lateinit var carItem: List<CarItem>
    private lateinit var sharedPreference: SharedPreference

    private lateinit var progressDisplay: ProgressDisplay
    private lateinit var carListAdapter: CarListAdapter


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binging = ActivityServiceTypeBinding.inflate(layoutInflater)
        setContentView(binging.root)

        progressDisplay = ProgressDisplay(this)
        sharedPreference = SharedPreference(this@ServiceTypeActivity)

        binging.back.setOnClickListener {
            finish()
        }


        binging.serviceSearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                carListAdapter.filter.filter(newText)
            }
        })



        progressDisplay.show()
        getCarServiceList()


    }

    private fun getCarServiceList() {
        var token = sharedPreference.getData("token").toString()


        val countryCall = RetrofitClient.apiService.getServiceTypeData("Bearer $token")

        countryCall.enqueue(object : Callback<CarListModel> {
            override fun onResponse(call: Call<CarListModel>, response: Response<CarListModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        carItem = apiResponse.data as List<CarItem>

                        Log.e("carItem.size", carItem.size.toString())

                        carListAdapter = CarListAdapter(carItem, this@ServiceTypeActivity)
                        binging.serviceRcy.adapter = carListAdapter


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@ServiceTypeActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@ServiceTypeActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@ServiceTypeActivity,
                            e.message.toString(),
                            Color.RED
                        )
                    }
                }
            }

            override fun onFailure(call: Call<CarListModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@ServiceTypeActivity,
                    t.message.toString(),
                    Color.RED
                )
            }
        })


    }


    @SuppressLint("MissingSuperCall")
    override fun onBackPressed() {
        finish()
    }

    override fun onTypeClick(carItem: CarItem) {
        val resultIntent = Intent()
        resultIntent.putExtra("serviceInfo", carItem.name + "," + carItem.id)
        setResult(Activity.RESULT_OK, resultIntent)
        finish()
    }
}