package codeflies.com.mcc.Activity



import android.graphics.Color
import android.os.Bundle
import android.text.Html
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.TermsModel
import codeflies.com.mcc.databinding.ActivityTermsBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class TermsActivity : AppCompatActivity() {

    private lateinit var binding: ActivityTermsBinding
    private var sharedPreference: SharedPreference? = null
    private lateinit var progressDisplay: ProgressDisplay
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityTermsBinding.inflate(layoutInflater)
        setContentView(binding.root)


        progressDisplay = ProgressDisplay(this@TermsActivity)

        sharedPreference = SharedPreference(this@TermsActivity)

        progressDisplay.show()
        getTerms()

        binding.back.setOnClickListener {
            finish()
        }
    }

    private fun getTerms() {

        val termsCall = RetrofitClient.apiService.terms("term-condition")
        termsCall.enqueue(object : Callback<TermsModel> {
            override fun onResponse(call: Call<TermsModel>, response: Response<TermsModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        binding.termsData.text = Html.fromHtml(apiResponse.data.content)

                    } else {
                        SnackBarUtils.showTopSnackbar(
                            this@TermsActivity,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            this@TermsActivity,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            this@TermsActivity,
                            e.message.toString().toString(),
                            Color.RED
                        )

                    }
                }

            }

            override fun onFailure(call: Call<TermsModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(
                    this@TermsActivity,
                    "" + t.message.toString(),
                    Color.RED
                )
            }
        })
    }

    fun back(view: View) {
        finish()
    }
}