package codeflies.com.mcc.Activity

import android.app.Activity
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Adapter.OnVariantClickListener
import codeflies.com.mcc.Adapter.VariantAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.VariantItem
import codeflies.com.mcc.Model.VariantModel
import codeflies.com.mcc.databinding.ActivityVariantBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class VariantActivity : AppCompatActivity(), OnVariantClickListener {

    private lateinit var binding: ActivityVariantBinding
    private lateinit var variantAdapter: VariantAdapter
    private lateinit var variantList: List<VariantItem>
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityVariantBinding.inflate(layoutInflater)
        setContentView(binding.root)

        progressDisplay = ProgressDisplay(this@VariantActivity)
        sharedPreference = SharedPreference(this@VariantActivity)

        binding.back.setOnClickListener {
            finish()
        }

        binding.variantSearch.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
                // This method is called before the text is changed
            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                // This method is called when the text is changed
                val newText = s.toString()
                // Perform any actions based on the new text here
            }

            override fun afterTextChanged(newText: Editable?) {
                variantAdapter.filter.filter(newText)
            }
        })


        progressDisplay.show()

        getVariant()


        binding.submitVariant.setOnClickListener {
            if (validation()) {
                val resultIntent = Intent()
                resultIntent.putExtra(
                    "variantInfo",
                    binding.otherVariantName.text.toString() + "," + "0"+ "," + "other"
                )
                setResult(Activity.RESULT_OK, resultIntent)
                finish()
            }
        }

    }

    private fun validation(): Boolean {
        if (binding.otherVariantName.text.length == 0) {
            SnackBarUtils.showTopSnackbar(
                this@VariantActivity,
                "Please Enter Car Variant!",
                Color.RED
            )
            binding.otherVariantName.requestFocus()
            return false
        }
        return true
    }


    private fun getVariant() {
        var token = sharedPreference.getData("token").toString()
        val modelId = intent.getIntExtra("modelId", 0)


        val variantCall = RetrofitClient.apiService.getVariant("Bearer " + token, modelId)

        variantCall.enqueue(object : Callback<VariantModel> {
            override fun onResponse(call: Call<VariantModel>, response: Response<VariantModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        variantList = apiResponse.data as List<VariantItem>

                        // Create a mutable copy of the original list
                        val modifiedDataList = variantList.toMutableList()

                        // Add the additional item
                        val additionalBrand = VariantItem(id = -1, name = "Other")
                        modifiedDataList.add(additionalBrand)


                        variantAdapter = VariantAdapter(modifiedDataList, this@VariantActivity)
                        binding.variantRcy.adapter = variantAdapter

                    } else {
                        binding.variantRcy.visibility = View.GONE
                        binding.variantOther.visibility = View.VISIBLE
                    }
                } else {
                    binding.variantRcy.visibility = View.GONE
                    binding.variantOther.visibility = View.VISIBLE
                }

            }

            override fun onFailure(call: Call<VariantModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(this@VariantActivity, t.message.toString(), Color.RED)

            }
        })


    }

    override fun onVariantClick(variant: VariantItem) {
        if (variant.name.equals("Other")) {
            binding.variantRcy.visibility = View.GONE
            binding.variantOther.visibility = View.VISIBLE

        } else {
            val resultIntent = Intent()
            resultIntent.putExtra("variantInfo", variant.name + "," + variant.id+ "," + "")
            setResult(Activity.RESULT_OK, resultIntent)
            finish()
        }
    }
}