package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.Filter
import android.widget.Filterable
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.BrandPojo
import codeflies.com.mcc.databinding.CustomBrandBinding
import java.util.Locale

class BrandAdapter(
    private val originalList: List<BrandPojo>,
    private val clickListener: OnBrandClickListener
) : RecyclerView.Adapter<BrandAdapter.CityViewHolder>(), Filterable {

    private var filteredList: List<BrandPojo> = originalList

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): BrandAdapter.CityViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CustomBrandBinding.inflate(inflater, parent, false)
        return CityViewHolder(binding)
    }

    override fun onBindViewHolder(holder: BrandAdapter.CityViewHolder, position: Int) {
        val brand = filteredList[position]
        holder.bind(brand)
    }

    override fun getItemCount(): Int = filteredList.size

    override fun getFilter(): Filter {
        return object : Filter() {
            override fun performFiltering(constraint: CharSequence?): FilterResults {
                val filterResults = FilterResults()
                val query = constraint?.toString()?.toLowerCase(Locale.getDefault())

                val filteredCities = if (query.isNullOrBlank()) {
                    originalList
                } else {
                    originalList.filter { brand ->
                        brand.name.toLowerCase(Locale.getDefault()).contains(query)
                    }
                }

                filterResults.values = filteredCities
                return filterResults
            }

            @Suppress("UNCHECKED_CAST")
            override fun publishResults(constraint: CharSequence?, results: FilterResults?) {
                filteredList = results?.values as? List<BrandPojo> ?: emptyList()
                notifyDataSetChanged()
            }
        }
    }

    inner class CityViewHolder(private val binding: CustomBrandBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(brandPojo: BrandPojo) {
            binding.brandName.text = brandPojo.name

            itemView.setOnClickListener {
                clickListener.onBrandClick(brandPojo)
            }
        }
    }
}

interface OnBrandClickListener {
    fun onBrandClick(brandPojo: BrandPojo)
}
