package codeflies.com.mcc.Adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.VehicleDetailsPojo
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.CarLayoutBinding
import com.bumptech.glide.Glide


class CarCollectionAdapter(
    private val context: Context,
    private val data: List<VehicleDetailsPojo>,
    private val onItemClickListener: OnItemClickListener? = null,
    private val onItemDeleteListener: OnItemDeleteListener? = null

) : RecyclerView.Adapter<CarCollectionAdapter.ViewHolder>() {

    inner class ViewHolder(private val binding: CarLayoutBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(item: VehicleDetailsPojo) {
            // Example: Change indicator color based on the data
            if (item.check_reg_expiry && item.check_mem_expiry
                && item.check_policy_expiry) {
                binding.indicatorGreenFlag.visibility = View.VISIBLE
                binding.indicatorRedFlag.visibility = View.GONE
            } else {
                // Set default color or handle other cases
                binding.indicatorGreenFlag.visibility = View.GONE
                binding.indicatorRedFlag.visibility = View.VISIBLE
            }
            binding.CarName.text = item.name
            Glide.with(context).load(item.image).placeholder(R.drawable.car).into(binding.carImage)
            // Set item click listener
            binding.addVehicle1.setOnClickListener {
                onItemClickListener?.onItemClick(item, adapterPosition)
            }
            binding.delete.setOnClickListener {
                onItemDeleteListener?.onItemDelete(item,adapterPosition)
            }
            binding.carBrand.text = item.brand_name
            binding.carPrice.text = item.model_name
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CarLayoutBinding.inflate(inflater, parent, false)
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val item = data[position]
        holder.bind(item)
    }

    override fun getItemCount(): Int = data.size

    interface OnItemClickListener {
        fun onItemClick(item: VehicleDetailsPojo, position: Int)
    }
    interface OnItemDeleteListener {
        fun onItemDelete(item: VehicleDetailsPojo, position: Int)
    }
}
