package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.Filter
import android.widget.Filterable
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.CityData
import codeflies.com.mcc.databinding.CustomCityBinding
import java.util.Locale

class CityAdapter(
    private val originalList: List<CityData>,
    private val clickListener: OnCityClickListener
) : RecyclerView.Adapter<CityAdapter.CityViewHolder>(), Filterable {

    private var filteredList: List<CityData> = originalList

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): CityAdapter.CityViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CustomCityBinding.inflate(inflater, parent, false)
        return CityViewHolder(binding)
    }

    override fun onBindViewHolder(holder: CityAdapter.CityViewHolder, position: Int) {
        val city = filteredList[position]
        holder.bind(city)
    }

    override fun getItemCount(): Int = filteredList.size

    override fun getFilter(): Filter {
        return object : Filter() {
            override fun performFiltering(constraint: CharSequence?): FilterResults {
                val filterResults = FilterResults()
                val query = constraint?.toString()?.toLowerCase(Locale.getDefault())

                val filteredCities = if (query.isNullOrBlank()) {
                    originalList
                } else {
                    originalList.filter { city ->
                        city.name.toLowerCase(Locale.getDefault()).contains(query)
                    }
                }

                filterResults.values = filteredCities
                return filterResults
            }

            @Suppress("UNCHECKED_CAST")
            override fun publishResults(constraint: CharSequence?, results: FilterResults?) {
                filteredList = results?.values as? List<CityData> ?: emptyList()
                notifyDataSetChanged()
            }
        }
    }

    inner class CityViewHolder(private val binding: CustomCityBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(city: CityData) {
            binding.cityName.text = city.name

            itemView.setOnClickListener {
                clickListener.onCityClick(city)
            }
        }
    }
}

interface OnCityClickListener {
    fun onCityClick(city: CityData)
}
