package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.Filter
import android.widget.Filterable
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.CountryData
import codeflies.com.mcc.databinding.CountryItemBinding
import java.util.Locale

class CountryAdapter(
    private val originalList: List<CountryData>,
    private val clickListener: OnCountryClickListener
) : RecyclerView.Adapter<CountryAdapter.CountryViewHolder>(), Filterable {

    private var filteredList: List<CountryData> = originalList

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): CountryViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CountryItemBinding.inflate(inflater, parent, false)
        return CountryViewHolder(binding)
    }

    override fun onBindViewHolder(holder: CountryViewHolder, position: Int) {
        val country = filteredList[position]
        holder.bind(country)
    }

    override fun getItemCount(): Int = filteredList.size

    override fun getFilter(): Filter {
        return object : Filter() {
            override fun performFiltering(constraint: CharSequence?): FilterResults {
                val filterResults = FilterResults()
                val query = constraint?.toString()?.toLowerCase(Locale.getDefault())

                val filteredCountries = if (query.isNullOrBlank()) {
                    originalList
                } else {
                    originalList.filter { country ->
                        country.name.toLowerCase(Locale.getDefault()).contains(query)
                    }
                }

                filterResults.values = filteredCountries
                return filterResults
            }

            @Suppress("UNCHECKED_CAST")
            override fun publishResults(constraint: CharSequence?, results: FilterResults?) {
                filteredList = results?.values as? List<CountryData> ?: emptyList()
                notifyDataSetChanged()
            }
        }
    }

    inner class CountryViewHolder(private val binding: CountryItemBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(country: CountryData) {
            binding.countryName.text = country.name

            itemView.setOnClickListener {
                clickListener.onCountryClick(country)
            }
        }
    }
}

interface OnCountryClickListener {
    fun onCountryClick(country: CountryData)
}
