package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.Filter
import android.widget.Filterable
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.TypeItem
import codeflies.com.mcc.databinding.CountryItemBinding
import java.util.Locale

class DistanceTypeAdapter(
    private val originalList: List<TypeItem>,
    private val clickListener: OnTypeClickListener
) : RecyclerView.Adapter<DistanceTypeAdapter.CountryViewHolder>(), Filterable {

    private var filteredList: List<TypeItem> = originalList

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): CountryViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CountryItemBinding.inflate(inflater, parent, false)
        return CountryViewHolder(binding)
    }

    override fun onBindViewHolder(holder: CountryViewHolder, position: Int) {
        val country = filteredList[position]
        holder.bind(country)
    }

    override fun getItemCount(): Int = filteredList.size

    override fun getFilter(): Filter {
        return object : Filter() {
            override fun performFiltering(constraint: CharSequence?): FilterResults {
                val filterResults = FilterResults()
                val query = constraint?.toString()?.toLowerCase(Locale.getDefault())

                val filteredCountries = if (query.isNullOrBlank()) {
                    originalList
                } else {
                    originalList.filter { country ->
                        country.name?.toLowerCase(Locale.getDefault())?.contains(query) == true
                    }
                }

                filterResults.values = filteredCountries
                return filterResults
            }

            @Suppress("UNCHECKED_CAST")
            override fun publishResults(constraint: CharSequence?, results: FilterResults?) {
                filteredList = results?.values as? List<TypeItem> ?: emptyList()
                notifyDataSetChanged()
            }
        }
    }

    inner class CountryViewHolder(private val binding: CountryItemBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(typeItem: TypeItem) {
            binding.countryName.text = typeItem.name

            itemView.setOnClickListener {
                clickListener.onTypeClick(typeItem)
            }
        }
    }
}

interface OnTypeClickListener {
    fun onTypeClick(typeItem: TypeItem)
}
