package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Activity.ReportExportActivity
import codeflies.com.mcc.Model.DataItemExport
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.ExportMainLayoutBinding
import com.bumptech.glide.Glide

class ExportMainAdapter(
    private val reportExportActivity: ReportExportActivity,
    private val data: List<DataItemExport?>
) : RecyclerView.Adapter<ExportMainAdapter.ExportMainViewHolder>() {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ExportMainViewHolder {
        val binding =
            ExportMainLayoutBinding.inflate(LayoutInflater.from(parent.context), parent, false)
        return ExportMainViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ExportMainViewHolder, position: Int) {
        val currentItem = data[position]
        // Bind data to views using currentItem and holder.binding
        holder.bind(currentItem)
    }

    override fun getItemCount() = data.size

    inner class ExportMainViewHolder(val binding: ExportMainLayoutBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(item: DataItemExport?) {

            Glide.with(reportExportActivity).load(item?.image).placeholder(R.drawable.car)
                .into(binding.carImage)


            binding.registerExpire.text = item?.regExpiryDate
            binding.CarPolicy.text = item?.policyNumber
            binding.carNumber.text = item?.regPlateNumber
            binding.CarName.text = item?.name
            binding.carNames.text = item?.modelName
            binding.carModel.text = item?.brandName
            binding.CarPolicyName.text = item?.vinNumber
            binding.carFuelType.text = item?.fuelName
            binding.clubDetails.text = item?.membershipDetail


            if (item?.vehicleRepairs?.isNotEmpty() == true){
                binding.repairLayout.visibility = View.VISIBLE
                val adapter =
                    ExportRepairAdapter(
                        reportExportActivity,
                        item.vehicleRepairs
                    )

                binding.exportRepairRcy.adapter =
                    adapter as RecyclerView.Adapter<RecyclerView.ViewHolder>?


            }
            if (item?.vehicleServices?.isNotEmpty() == true){
                binding.serviceLayout.visibility = View.VISIBLE
                val adapter =
                    ExportServiceAdapter(
                        item.vehicleServices
                    )

                binding.exportServiceRcy.adapter =
                    adapter as RecyclerView.Adapter<RecyclerView.ViewHolder>?


            }
        }
    }
}
