package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.Filter
import android.widget.Filterable
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.FuelModelPojo
import codeflies.com.mcc.databinding.CustomFuelBinding
import java.util.Locale

class FuelAdapter(
    private val originalList: List<FuelModelPojo>,
    private val clickListener: OnFuelClickListener
) : RecyclerView.Adapter<FuelAdapter.FuelViewHolder>(), Filterable {

    private var filteredList: List<FuelModelPojo> = originalList

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): FuelAdapter.FuelViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CustomFuelBinding.inflate(inflater, parent, false)
        return FuelViewHolder(binding)
    }

    override fun onBindViewHolder(holder: FuelAdapter.FuelViewHolder, position: Int) {
        val model = filteredList[position]
        holder.bind(model)
    }

    override fun getItemCount(): Int = filteredList.size

    override fun getFilter(): Filter {
        return object : Filter() {
            override fun performFiltering(constraint: CharSequence?): FilterResults {
                val filterResults = FilterResults()
                val query = constraint?.toString()?.toLowerCase(Locale.getDefault())

                val filteredCities = if (query.isNullOrBlank()) {
                    originalList
                } else {
                    originalList.filter { brand ->
                        brand.name.toLowerCase(Locale.getDefault()).contains(query)
                    }
                }

                filterResults.values = filteredCities
                return filterResults
            }

            @Suppress("UNCHECKED_CAST")
            override fun publishResults(constraint: CharSequence?, results: FilterResults?) {
                filteredList = results?.values as? List<FuelModelPojo> ?: emptyList()
                notifyDataSetChanged()
            }
        }
    }

    inner class FuelViewHolder(private val binding: CustomFuelBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(fuelModelPojo: FuelModelPojo) {
            binding.fuelName.text = fuelModelPojo.name

            itemView.setOnClickListener {
                clickListener.onFuelClick(fuelModelPojo)
            }
        }
    }
}

interface OnFuelClickListener {
    fun onFuelClick(fuelModelPojo: FuelModelPojo)
}
