package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import android.widget.Filter
import android.widget.Filterable
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.BrandModelPojo
import codeflies.com.mcc.databinding.CustomModelBinding
import java.util.Locale

class ModelAdapter(
    private val originalList: List<BrandModelPojo>,
    private val clickListener: OnModelClickListener
) : RecyclerView.Adapter<ModelAdapter.CityViewHolder>(), Filterable {

    private var filteredList: List<BrandModelPojo> = originalList

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ModelAdapter.CityViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CustomModelBinding.inflate(inflater, parent, false)
        return CityViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ModelAdapter.CityViewHolder, position: Int) {
        val model = filteredList[position]
        holder.bind(model)
    }

    override fun getItemCount(): Int = filteredList.size

    override fun getFilter(): Filter {
        return object : Filter() {
            override fun performFiltering(constraint: CharSequence?): FilterResults {
                val filterResults = FilterResults()
                val query = constraint?.toString()?.toLowerCase(Locale.getDefault())

                val filteredCities = if (query.isNullOrBlank()) {
                    originalList
                } else {
                    originalList.filter { brand ->
                        brand.name.toLowerCase(Locale.getDefault()).contains(query)
                    }
                }

                filterResults.values = filteredCities
                return filterResults
            }

            @Suppress("UNCHECKED_CAST")
            override fun publishResults(constraint: CharSequence?, results: FilterResults?) {
                filteredList = results?.values as? List<BrandModelPojo> ?: emptyList()
                notifyDataSetChanged()
            }
        }
    }

    inner class CityViewHolder(private val binding: CustomModelBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind(brandModelPojo: BrandModelPojo) {
            binding.modelName.text = brandModelPojo.name

            itemView.setOnClickListener {
                clickListener.onModelClick(brandModelPojo)
            }
        }
    }
}

interface OnModelClickListener {
    fun onModelClick(brandModelPojo: BrandModelPojo)
}
