package codeflies.com.mcc.Adapter

import android.annotation.SuppressLint
import android.content.Context
import android.content.res.ColorStateList
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.DataItem
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.PlanCustomBinding
import org.json.JSONArray
import org.json.JSONObject

class PlanAdapter(
    private val planlist: List<DataItem>,
    private val context: Context,
    private val itemClickListener: PlanItemClickListener? = null
) :
    RecyclerView.Adapter<PlanAdapter.ViewHolder>() {
    var row_index = 1
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): PlanAdapter.ViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = PlanCustomBinding.inflate(inflater, parent, false)
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: PlanAdapter.ViewHolder, position: Int) {
        val dataItem = planlist[position]
        holder.bind(dataItem)
    }

    override fun getItemCount(): Int {
        return planlist.size
    }

    inner class ViewHolder(private val binding: PlanCustomBinding) :
        RecyclerView.ViewHolder(binding.root) {

        @SuppressLint("SetTextI18n")
        fun bind(dataItem: DataItem) {
            binding.actualPrice.text = "$" + dataItem.price.toString()
            binding.planName.text = dataItem.name.toString()
            binding.descriptionPlan.text = dataItem.description.toString()
            binding.carValue.text =dataItem.maxLimit.toString()

            if (row_index == position) {
                binding.addVehicle1.setCardBackgroundColor(context.getColor(R.color.golden))
                binding.planName.setTextColor(context.getColor(R.color.main_black))
                binding.actualPrice.setTextColor(context.getColor(R.color.main_black))
                binding.carValue.setTextColor(context.getColor(R.color.golden))
                binding.carValue.backgroundTintList= ColorStateList.valueOf(context.getColor(R.color.main_black))
                binding.checkPlan.visibility= View.VISIBLE
                itemClickListener?.onPlanItemClick(dataItem)

            } else {
                binding.addVehicle1.setCardBackgroundColor(context.getColor(R.color.main_black))
                binding.planName.setTextColor(context.getColor(R.color.golden))
                binding.actualPrice.setTextColor(context.getColor(R.color.golden))
                binding.carValue.setTextColor(context.getColor(R.color.main_black))
                binding.carValue.backgroundTintList= ColorStateList.valueOf(context.getColor(R.color.golden))
                binding.checkPlan.visibility= View.GONE

            }


            val featuresArray = JSONArray()

            dataItem.features?.forEach { feature ->
                val featureObject = JSONObject()
                featureObject.put("id", feature?.id)
                featureObject.put("title", feature?.title)
                featuresArray.put(featureObject)
            }

// Initialize an empty string to hold concatenated titles
            var concatenatedTitles = ""

// Access each feature object and concatenate the titles
            for (i in 0 until featuresArray.length()) {
                val featureObject = featuresArray.getJSONObject(i)
                val title = featureObject.getString("title")

                if(i==0){
                    concatenatedTitles="* "+title.capitalize()+"\n"
                }else if(i==featuresArray.length()){
                    concatenatedTitles="* "+title.capitalize()
                }else{
                    concatenatedTitles=concatenatedTitles+"* "+title.capitalize()+"\n"
                }

            }

            binding.featuresPlan.text = concatenatedTitles

            // Set click listeners or other interactions if necessary
            binding.root.setOnClickListener {
                // Handle item click
                // You can navigate to another activity or fragment, etc.
                row_index = position
                notifyDataSetChanged()
                itemClickListener?.onPlanItemClick(dataItem)
            }
        }
    }

    interface PlanItemClickListener {
        fun onPlanItemClick(dataItem: DataItem)
    }
}