package codeflies.com.mcc.Adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.DataItemUpcoming
import codeflies.com.mcc.databinding.RepaireLayoutBinding
import com.bumptech.glide.Glide
import java.text.ParseException
import java.text.SimpleDateFormat
import java.util.Date


class RepairsAdapter(
    private val context: Context,
    private val data: List<DataItemUpcoming?>?,
    private val repairDetails : RepairDetails
) : RecyclerView.Adapter<RepairsAdapter.ViewHolder>() {

    inner class ViewHolder(val binding: RepaireLayoutBinding) :
        RecyclerView.ViewHolder(binding.root) {

        fun bind() {
            // Example: Change indicator color based on the data

        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = RepaireLayoutBinding.inflate(inflater, parent, false)
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val item = data?.get(position)
        holder.bind()

        holder.binding.name.text = item?.vehicle!!.name
        holder.binding.upcomingRepair.setOnClickListener {
            repairDetails.onRepairClick(item)
        }
        try {
            val inputFormat = SimpleDateFormat("yyyy-MM-dd HH:mm:ss")
            val outputFormat = SimpleDateFormat("yyyy-MM-dd")

            val date: Date = inputFormat.parse(item.repairDate)
            val outputDate: String = outputFormat.format(date)
            holder.binding.date.text = outputDate

        } catch (e: ParseException) {
            e.printStackTrace()
        }

        holder.binding.serviceCaptionDes.text =
            item.serviceCaption + " (" + item.vehicle.name + ")"
        holder.binding.centreName.text = item.repairCenter
        holder.binding.costPrice.text = "$" + item.repairCost
        holder.binding.kmValue.text = item.mileage
        if (!item.notes.equals("")) {
            holder.binding.note.visibility = View.VISIBLE
            holder.binding.note.text = item.notes
        }
        Glide.with(context).load(item.vehicle.image).into(holder.binding.carImage)
    }

    override fun getItemCount(): Int = data?.size!!


    interface RepairDetails {
        fun onRepairClick(dataItemUpcoming: DataItemUpcoming?)
    }

}
