package codeflies.com.mcc.Adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import codeflies.com.mcc.Model.ServicesData
import codeflies.com.mcc.databinding.CustomServicesBinding

class ServicesAdapter(
    private val serviceList: List<ServicesData>,
    private val onItemClickListener: OnServicesClickListener
) :
    RecyclerView.Adapter<ServicesAdapter.ServicesViewHolder>() {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ServicesViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = CustomServicesBinding.inflate(inflater, parent, false)
        return ServicesViewHolder(binding,onItemClickListener)
    }

    override fun onBindViewHolder(holder: ServicesViewHolder, position: Int) {
        val serviceData = serviceList[position]
        holder.bind(serviceData)
    }

    override fun getItemCount(): Int {
        return serviceList.size
    }

    class ServicesViewHolder(
        private val binding: CustomServicesBinding,
        private val onItemClickListener: OnServicesClickListener
        ) : RecyclerView.ViewHolder(binding.root) {

        fun bind(serviceData: ServicesData) {
            binding.servicesTitle.text = serviceData.name
            binding.servicesAddress.text = serviceData.address

            itemView.setOnClickListener {
                onItemClickListener.onItemClick(position,serviceData)
            }

            // Set rating stars based on the rating value (assuming rating is an integer)
              val rating = serviceData.average_ratings // Replace with the actual field from your model
              setRatingStars(binding, rating)
        }

        private fun setRatingStars(binding: CustomServicesBinding, rating: Int) {
            val ratingImageViews = listOf(
                binding.ratingOne,
                binding.ratingTwo,
                binding.ratingThree,
                binding.ratingFour,
                binding.ratingFive
            )

            for (i in 0 until ratingImageViews.size) {
                if (i < rating) {
                    ratingImageViews[i].setImageResource(android.R.drawable.btn_star_big_on)
                } else {
                    ratingImageViews[i].setImageResource(android.R.drawable.btn_star_big_off)
                }
            }
        }
    }

    interface OnServicesClickListener {
        fun onItemClick(position: Int, serviceData: ServicesData)
    }

}
