package codeflies.com.mcc.Fragment

import android.Manifest
import android.app.Activity
import android.app.DatePickerDialog
import android.content.ContentResolver
import android.content.ContentValues
import android.content.Intent
import android.content.pm.PackageManager
import android.graphics.Color
import android.os.Build
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.provider.CalendarContract
import android.text.Editable
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.CarListActivity
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Activity.KM_MileageActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Activity.PlansActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.DataItemDetails
import codeflies.com.mcc.Model.DataItemUpcoming
import codeflies.com.mcc.Model.VehicleModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentAddRepairsBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.text.ParseException
import java.text.SimpleDateFormat
import java.util.Calendar
import java.util.Date
import java.util.Locale
import java.util.TimeZone

class AddRepairsFragment : Fragment() {

    private var binding: FragmentAddRepairsBinding? = null
    private lateinit var selectedDate: String
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay
    var typeId = 1
    var carId = 0
    var repairId = 0
    var planStatus = 0
    private val REQUEST_CODE_PERMISSION = 123

    companion object {
        var dataItemDetails: DataItemUpcoming? = null
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentAddRepairsBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    private fun validation(): Boolean {
        if (carId == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Select Car!",
                    Color.RED
                )
            }
            return false
        } else if (binding!!.serviceCaption.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please enter service caption!",
                    Color.RED
                )
            }
            binding!!.serviceCaption.requestFocus()
            return false
        } else if (binding!!.centreName.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please enter repair center details!",
                    Color.RED
                )
            }
            binding!!.centreName.requestFocus()
            return false
        } else if (binding!!.repairsCost.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please enter repair cost!",
                    Color.RED
                )
            }
            binding!!.repairsCost.requestFocus()
            return false
        } else if (binding!!.repairDate.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please select repair date!",
                    Color.RED
                )
            }
            return false
        } else if (binding!!.valueKM.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please enter Km/Mileage value!",
                    Color.RED
                )
            }
            binding!!.valueKM.requestFocus()
            return false
        }
        return true

    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)


        if (isAdded) {

            sharedPreference = context?.let { SharedPreference(it) }!!
            progressDisplay = context?.let { ProgressDisplay(it) }!!


            if (dataItemDetails != null) {
                binding!!.addRepairsServices.text = "Update"
                binding!!.vehicleList.setText(dataItemDetails!!.vehicle!!.name.toString())
                carId = dataItemDetails!!.vehicleId!!.toInt()
                binding!!.serviceCaption.setText(dataItemDetails!!.serviceCaption)
                binding!!.centreName.setText(dataItemDetails!!.repairCenter)
                binding!!.noteTxt.setText(dataItemDetails!!.notes)
                val repairCostString = dataItemDetails?.repairCost.toString()
                val repairCostDouble = repairCostString.toDouble()
                val repairCostInt = repairCostDouble.toInt()
                binding!!.repairsCost.setText(repairCostInt.toString())
                try {
                    val inputFormat = SimpleDateFormat("yyyy-MM-dd HH:mm:ss")
                    val outputFormat = SimpleDateFormat("yyyy-MM-dd")

                    val date: Date =
                        inputFormat.parse(dataItemDetails!!.repairDate)
                    val outputDate: String = outputFormat.format(date)
                    binding!!.repairDate.setText(outputDate)

                } catch (e: ParseException) {
                    e.printStackTrace()
                }

                binding!!.valueKM.setText(dataItemDetails!!.mileage)
                typeId = dataItemDetails!!.distanceTypeId!!.toInt()
                repairId = dataItemDetails!!.id!!.toInt()
                if (typeId == 1) {
                    binding!!.unitTypeValue.setText("Km")
                } else if (typeId == 2) {
                    binding!!.unitTypeValue.setText("Mileage")
                }

            }

            if (planStatus != 0) {
                binding!!.planIDStatus.visibility = View.VISIBLE
                binding!!.planGet.visibility = View.GONE
                binding!!.addRepairsServices.text = "NEXT"
            }

            binding!!.addRepairsServices.setOnClickListener {
                if (binding!!.addRepairsServices.text.toString().equals("Update")) {
                    updateUpcomingRepairs()
                    progressDisplay.show()
                } else {
                    if (validation()) {
                        uploadUpcomingRepairs()
                        progressDisplay.show()
                    }
                }
            }
            binding!!.vehicleList.setOnClickListener {

            }

            MainActivity.status = true

            binding!!.planGet.setOnClickListener {
                startActivity(Intent(context, PlansActivity::class.java))
            }

            binding!!.repairDate.setOnClickListener {
                showDatePicker()
            }

            binding!!.unitTypeValue.setOnClickListener {
                val intent = Intent(context, KM_MileageActivity::class.java)
                startActivityForResult(intent, 1)

            }

            binding!!.vehicleList.setOnClickListener {
                val intent = Intent(context, CarListActivity::class.java)
                startActivityForResult(intent, 2)
            }
        }

        requestCalendarPermissions()

    }

    private fun updateUpcomingRepairs() {
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()

        val repairCall = RetrofitClient.apiService.updateUpcomingRepairs(
            "Bearer $token",
            "1", user_id, carId.toString(), binding!!.serviceCaption.text.toString(),
            binding!!.centreName.text.toString(),
            binding!!.noteTxt.text.toString(), binding!!.repairsCost.text.toString(),
            binding!!.repairDate.text.toString(), binding!!.valueKM.text.toString(),
            typeId.toString(), repairId.toString()
        )

        repairCall.enqueue(object : Callback<VehicleModel> {
            override fun onResponse(call: Call<VehicleModel>, response: Response<VehicleModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message,
                                Color.parseColor("#ca9730")
                            )
                        }
                        Handler(Looper.getMainLooper()).postDelayed({
                            if (planStatus == 0) {
                                startActivity(Intent(requireActivity(), MainActivity::class.java))
                            } else {
                                replaceFrame(apiResponse.data[0].id)
                            }
                        }, 2000)


                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<VehicleModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }

        })

    }

    private fun uploadUpcomingRepairs() {
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()

        val repairCall = RetrofitClient.apiService.uploadUpcomingRepairs(
            "Bearer $token",
            "1", user_id, carId.toString(), binding!!.serviceCaption.text.toString(),
            binding!!.centreName.text.toString(),
            binding!!.noteTxt.text.toString(), binding!!.repairsCost.text.toString(),
            binding!!.repairDate.text.toString(), binding!!.valueKM.text.toString(),
            typeId.toString()
        )

        repairCall.enqueue(object : Callback<VehicleModel> {
            override fun onResponse(call: Call<VehicleModel>, response: Response<VehicleModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message,
                                Color.parseColor("#ca9730")
                            )
                        }
                        Handler(Looper.getMainLooper()).postDelayed({
                            if (::selectedDate.isInitialized) {
                                if (sharedPreference.getData("repair_status").equals("1")) {
                                    addReminderToCalendar(
                                        binding!!.vehicleList.text.toString() + " Upcoming repair",
                                        "Don't forget your upcoming repair today!",
                                        selectedDate
                                    )

                                }
                            } else {
                                Toast.makeText(
                                    context,
                                    "Please select a date first",
                                    Toast.LENGTH_SHORT
                                )
                                    .show()
                            }

                            if (planStatus == 0) {
                                activity?.finish()
                            } else {
                                replaceFrame(apiResponse.data[0].id)
                            }
                        }, 2000)


                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<VehicleModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }

        })

    }


    private fun showDatePicker() {
        val calendar = Calendar.getInstance()
        val year = calendar.get(Calendar.YEAR)
        val month = calendar.get(Calendar.MONTH)
        val day = calendar.get(Calendar.DAY_OF_MONTH)

        val datePickerDialog = context?.let {
            DatePickerDialog(
                it,
                DatePickerDialog.OnDateSetListener { _, selectedYear, selectedMonth, selectedDay ->
                    // Handle the selected date
                    onDateSet(selectedYear, selectedMonth, selectedDay)
                },
                year,
                month,
                day
            )
        }
        //  datePickerDialog.datePicker.minDate = System.currentTimeMillis() - 1000

        datePickerDialog?.show()
    }


    private fun onDateSet(selectedYear: Int, selectedMonth: Int, selectedDay: Int) {
        val formattedMonth = selectedMonth + 1
        val formattedDate = "$selectedYear-$formattedMonth-$selectedDay"
        selectedDate = "$selectedYear-$formattedMonth-$selectedDay"

        binding!!.repairDate.setText(formattedDate)

    }


    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        if (requestCode == 1 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("typeInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val typeName = countryInfoArray[0] // The first part before the comma
                typeId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.unitTypeValue.text = Editable.Factory.getInstance().newEditable(typeName)
            }
        }
        if (requestCode == 2 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("carInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val typeName = countryInfoArray[0] // The first part before the comma
                carId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.vehicleList.text = Editable.Factory.getInstance().newEditable(typeName)
            }
        }
    }


    private fun replaceFrame(vehicleId: Int) {
        // Create a new instance of the next fragment
        val nextFragment = UpcomingImageFragment()

        // Pass the id value to the next fragment using arguments
        val bundle = Bundle()
        bundle.putInt("vehicleId", vehicleId)
        nextFragment.arguments = bundle

        // Replace the current fragment with the next fragment

        CommonActivity.replaceFragment = nextFragment
        CommonActivity.titleTop = getString(R.string.add_repair)
        startActivity(Intent(context, CommonActivity::class.java))
    }

    private fun requestCalendarPermissions() {
        val permissionsToRequest = mutableListOf<String>()

        // Check if the device is running Android 6.0 (API level 23) or higher
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            // Check if the app has permission to read the calendar
            if (ContextCompat.checkSelfPermission(
                    requireContext(),
                    Manifest.permission.READ_CALENDAR
                ) != PackageManager.PERMISSION_GRANTED
            ) {
                // Permission is not granted, request the permission
                permissionsToRequest.add(Manifest.permission.READ_CALENDAR)
            }
            // Check if the app has permission to write to the calendar
            if (ContextCompat.checkSelfPermission(
                    requireContext(),
                    Manifest.permission.WRITE_CALENDAR
                ) != PackageManager.PERMISSION_GRANTED
            ) {
                // Permission is not granted, request the permission
                permissionsToRequest.add(Manifest.permission.WRITE_CALENDAR)
            }
        }

        // Request permissions if there are any
        if (permissionsToRequest.isNotEmpty()) {
            requestPermissions(
                permissionsToRequest.toTypedArray(),
                REQUEST_CODE_PERMISSION
            )
        } else {
            // Permissions are already granted, perform your calendar-related tasks here
            // For example, add an event to the calendar
            // addEventToCalendar()
        }
    }

    private fun addReminderToCalendar(title: String, description: String, selectedDate: String) {
        val cr: ContentResolver = context?.contentResolver!!
        val selectedDateTime =
            SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()).parse(selectedDate)?.time ?: return

        val values = ContentValues().apply {
            put(CalendarContract.Events.TITLE, title)
            put(CalendarContract.Events.DESCRIPTION, description)
            put(CalendarContract.Events.DTSTART, selectedDateTime)
            put(
                CalendarContract.Events.DTEND,
                selectedDateTime + (60 * 60 * 1000)
            ) // 1 hour duration
            put(CalendarContract.Events.CALENDAR_ID, 1) // Use 1 as default calendar
            put(CalendarContract.Events.EVENT_TIMEZONE, TimeZone.getDefault().id)
            put(CalendarContract.Events.HAS_ALARM, 1) // 1 for true, 0 for false
            put(CalendarContract.Events.CUSTOM_APP_URI, selectedDate) // Store selected date
        }

        val uri = cr.insert(CalendarContract.Events.CONTENT_URI, values)
        val eventId = uri?.lastPathSegment?.toLongOrNull()

        if (eventId != null) {
            // Add a reminder for the event
            val reminderValues = ContentValues().apply {
                put(CalendarContract.Reminders.EVENT_ID, eventId)
                put(CalendarContract.Reminders.METHOD, CalendarContract.Reminders.METHOD_ALERT)
                put(CalendarContract.Reminders.MINUTES, 15) // 15 minutes before the event
            }
            cr.insert(CalendarContract.Reminders.CONTENT_URI, reminderValues)

        } else {
//            Toast.makeText(context, "Failed to add reminder", Toast.LENGTH_SHORT).show()
        }
    }


}