package codeflies.com.mcc.Fragment

import android.app.Activity
import android.app.ProgressDialog
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.Editable
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Activity.PriceActivity
import codeflies.com.mcc.Activity.RatingActivity
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.Model.reviewsPojo
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentAddReviewBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class AddReviewFragment : Fragment() {

    private var binding: FragmentAddReviewBinding? = null
    var ratingId = 0
    var priceId = 0
    var serviceId = ""
    private lateinit var sharedPreference: SharedPreference
    private val progressDialog by lazy {
        ProgressDialog(context).apply {
            setMessage("Please wait...")
            setCancelable(false)
        }
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentAddReviewBinding.inflate(layoutInflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            sharedPreference = context?.let { SharedPreference(it) }!!

            val userReview: reviewsPojo? = arguments?.getParcelable("userReview")
            // Now you can use the selectedReview in your fragment
            serviceId = arguments?.getString("serviceId").toString()

            if (userReview != null) {
                binding!!.reviewContent.setText(userReview.content)
                serviceId = userReview.service_id
                ratingId = userReview.review_rating
                priceId = userReview.review_price
                if (userReview.review_rating == 1) {
                    binding!!.reviewRating.setText(getString(R.string.perfect))
                } else if (userReview.review_rating == 2) {
                    binding!!.reviewRating.setText(getString(R.string.good))
                } else if (userReview.review_rating == 3) {
                    binding!!.reviewRating.setText(getString(R.string.its_okay))
                } else if (userReview.review_rating == 4) {
                    binding!!.reviewRating.setText(getString(R.string.bad))
                } else if (userReview.review_rating == 5) {
                    binding!!.reviewRating.setText(getString(R.string.very_bad))
                }

                if (userReview.review_price == 1) {
                    binding!!.reviewPrice.setText(getString(R.string.cheap))
                } else if (userReview.review_price == 2) {
                    binding!!.reviewPrice.setText(getString(R.string.normal))
                } else if (userReview.review_price == 3) {
                    binding!!.reviewPrice.setText(getString(R.string.expensive))
                }
                binding!!.reviewContent.setText(userReview.content)
            }

            binding!!.reviewRating.setOnClickListener {
                if (isAdded) {
                    getRating()
                }
            }

            binding!!.reviewPrice.setOnClickListener {
                if (isAdded) {
                    if (ratingId == 0) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it, "Please Select Rating First!",
                                Color.RED
                            )
                        }
                    } else {
                        val intent = Intent(context, PriceActivity::class.java)
                        startActivityForResult(intent, 2)
                    }

                }
            }

            binding!!.sendReview.setOnClickListener {
                if (isAdded) {
                    if (validation()) {
                        progressDialog.show()
                        uploadReview()
                    }

                }
            }

        }

    }

    private fun validation(): Boolean {
        if (binding!!.reviewContent.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Enter Review!", Color.RED
                )
                binding!!.reviewContent.requestFocus()
            }
            return false
        } else if (ratingId == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Select Rating!", Color.RED
                )
            }
            return false
        } else if (priceId == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Select Price!", Color.RED
                )

            }
            return false
        }

        return true
    }

    private fun uploadReview() {

        val authorizationToken = "Bearer " + sharedPreference.getData("token")
        val userId = "" + sharedPreference.getData("user_id")

        val uploaderCall = RetrofitClient.apiService.uploadReview(
            authorizationToken,
            userId,
            binding!!.reviewContent.text.toString(),
            serviceId,
            ratingId.toString(),
            priceId.toString()
        )

        uploaderCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDialog.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {

                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message.toString(),
                                Color.parseColor("#ca9730")
                            )
                        }

                        Handler(Looper.getMainLooper()).postDelayed({
                            startActivity(Intent(context, MainActivity::class.java))
                            activity?.finishAffinity()
                        }, 2000)

                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }


            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDialog.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }

        })


    }

    private fun getRating() {
        val intent = Intent(context, RatingActivity::class.java)
        startActivityForResult(intent, 1)

    }


    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        if (requestCode == 1 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("ratingInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val countryName = countryInfoArray[0] // The first part before the comma
                ratingId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.reviewRating.text =
                    Editable.Factory.getInstance().newEditable(countryName)
            }
        }
        if (requestCode == 2 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("priceInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val cityName = countryInfoArray[0] // The first part before the comma
                priceId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.reviewPrice.text = Editable.Factory.getInstance().newEditable(cityName)
            }
        }

    }

}