package codeflies.com.mcc.Fragment

import android.app.Activity
import android.app.ProgressDialog
import android.content.Intent
import android.graphics.Color
import android.location.Address
import android.location.Geocoder
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.Editable
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.CityActivity
import codeflies.com.mcc.Activity.CountryActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.databinding.FragmentAddServicesBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.io.IOException
import java.util.Locale


class AddServicesFragment : Fragment() {

    private var binding: FragmentAddServicesBinding? = null
    private val REQUEST_COUNTRY = 1

    var countryId = 0
    var cityId = 0
    private lateinit var sharedPreference: SharedPreference
    private val progressDialog by lazy {
        ProgressDialog(context).apply {
            setMessage("Please wait...")
            setCancelable(false)
        }
    }

    companion object {
        lateinit var arguments: Bundle
    }


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentAddServicesBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    private fun validation(): Boolean {
        if (binding!!.serviceName.text?.length == 0) {
            context?.let { SnackBarUtils.showTopSnackbar(it,"Enter Service Center Name!",Color.RED) }
            binding!!.serviceName.requestFocus()
            return false
        }  else if (binding!!.serviceDes.text?.length == 0) {
            context?.let { SnackBarUtils.showTopSnackbar(it,"Enter Service Center Description!",Color.RED) }
            binding!!.serviceDes.requestFocus()
            return false
        }else if (countryId == 0){
            context?.let { SnackBarUtils.showTopSnackbar(it,"Please Select Country Name!",Color.RED) }
            return false
        }else if (cityId ==0){
            context?.let { SnackBarUtils.showTopSnackbar(it,"Please Select City Name!",Color.RED) }
            return false
        }else if (binding!!.serviceAddress.text?.length ==0){
            context?.let { SnackBarUtils.showTopSnackbar(it,"Enter Service Center Address!",Color.RED) }
            binding!!.serviceAddress.requestFocus()
            return false
        }

        return true
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

      if (isAdded){
          sharedPreference = context?.let { SharedPreference(it) }!!

          MainActivity.status = true

          binding!!.addSend.setOnClickListener {

              if (validation()){
                  progressDialog.show()
                  getAddress(binding!!.serviceAddress.text.toString(),binding!!.serviceCity.text.toString(),
                      binding!!.serviceCounty.text.toString())

              }

          }

          binding!!.serviceCounty.setOnClickListener {
            if (isAdded){
                getCountry()
            }
          }

          binding!!.serviceCity.setOnClickListener {
              if (isAdded){
                  getCity()
              }
          }
      }
    }

    private fun getAddress(address: String, city: String, country: String) {
        // Example address
        val address = address+","+city+","+country

        val geocoder = context?.let { Geocoder(it) }
        try {
            val addresses: List<Address> = geocoder?.getFromLocationName(address, 1)!!

            if (addresses.isNotEmpty()) {
                val latitude = addresses[0].latitude
                val longitude = addresses[0].longitude

                // Print or use the latitude and longitude
                Log.d("Location", "Latitude: $latitude, Longitude: $longitude")
              //  getAddressLL(latitude,longitude)
                uploadServices(latitude,longitude)
            } else {
                progressDialog.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it,"Please Provide Valid Address!",Color.RED) }
                Log.e("Location", "No results found")
            }

        } catch (e: IOException) {
            e.printStackTrace()
        }
    }

    private fun getAddressLL(latitude: Double, longitude: Double) {
        val latitude = latitude // Replace with your latitude
        val longitude = longitude // Replace with your longitude

        val geocoder = context?.let { Geocoder(it, Locale.getDefault()) }
        try {
            val addresses: List<Address> = geocoder?.getFromLocation(latitude, longitude, 1)!!

            if (addresses.isNotEmpty()) {
                val address: String = addresses[0].getAddressLine(0)

                // Print or use the address
                Log.d("Location", "Address: $address")
            } else {
                Log.e("Location", "No results found")
            }

        } catch (e: IOException) {
            e.printStackTrace()
        }

    }

    private fun uploadServices(latitude: Double, longitude: Double) {
        val authorizationToken = "Bearer "+sharedPreference.getData("token")
        val userId = ""+sharedPreference.getData("user_id")

        val uploaderCall = RetrofitClient.apiService.uploadServices(authorizationToken,userId.toString(),
            binding!!.serviceName.text.toString(),binding!!.serviceDes.text.toString(),
            countryId.toString(),cityId.toString(),binding!!.serviceAddress.text.toString(),
            latitude.toString(),longitude.toString())

        uploaderCall.enqueue(object : Callback<CommonModel>{
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDialog.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {

                        context?.let { SnackBarUtils.showTopSnackbar(it,apiResponse.message.toString(),Color.parseColor("#ca9730")) }

                        Handler(Looper.getMainLooper()).postDelayed({
                            startActivity(Intent(context, MainActivity::class.java))
                            activity?.finishAffinity()
                        }, 2000)

                    } else {
                        context?.let { SnackBarUtils.showTopSnackbar(it,apiResponse?.message.toString(),Color.RED) }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let { SnackBarUtils.showTopSnackbar(it,errorMessage.toString(),Color.RED) }
                    } catch (e: Exception) {
                        context?.let { SnackBarUtils.showTopSnackbar(it,e.message.toString(),Color.RED) }
                    }
                }


            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDialog.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it,t.message.toString(),Color.RED) }
            }

        })

    }

    private fun getCity() {
        if (countryId==0){
            context?.let { SnackBarUtils.showTopSnackbar(it,"Please Select Country First!",Color.RED) }
        }else{
            val intent = Intent(context, CityActivity::class.java)
            intent.putExtra("countryId",countryId)
            startActivityForResult(intent, 2)
        }
    }


    private fun getCountry() {
        val intent = Intent(context, CountryActivity::class.java)
        startActivityForResult(intent, 1)
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        if (requestCode == 1 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("countryInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val countryName = countryInfoArray[0] // The first part before the comma
                countryId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.serviceCounty.text = Editable.Factory.getInstance().newEditable(countryName)
            }
        }
        if (requestCode == 2 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("cityInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val cityName = countryInfoArray[0] // The first part before the comma
                cityId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.serviceCity.text = Editable.Factory.getInstance().newEditable(cityName)
            }
        }
    }


}
