package codeflies.com.mcc.Fragment

import android.app.Activity
import android.app.DatePickerDialog
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.Editable
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.BrandActivity
import codeflies.com.mcc.Activity.BrandModelActivity
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Activity.EngineActivity
import codeflies.com.mcc.Activity.FuelActivity
import codeflies.com.mcc.Activity.KM_MileageActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Activity.VariantActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.VehicleModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentAddVehicleBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.util.Calendar

class AddVehicleFragment : Fragment() {

    private var binding: FragmentAddVehicleBinding? = null
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay
    private lateinit var selectedDate: String

    var brandId = 0
    var modelId = 0
    var variantId = 0
    var engineId = 0
    var typeSlug = ""
    var fuelId = 0

    var brand_type = ""
    var model_type = ""
    var variant_type = ""
    var engine_type = ""

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?
    ): View {
        binding = FragmentAddVehicleBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    private fun validation(): Boolean {
        if (binding!!.carName.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Enter Car Name!",
                    Color.RED
                )
            }
            binding!!.carName.requestFocus()
            return false
        } else if (binding!!.brandTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Select Car Brand!",
                    Color.RED
                )
            }
            return false
        } else if (binding!!.modelTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Select Car Model!",
                    Color.RED
                )
            }
            return false
        } else if (binding!!.variantTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Enter Car Variant!",
                    Color.RED
                )
            }
            binding!!.variantTxt.requestFocus()
            return false
        } else if (binding!!.engineTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Enter Car Engine Details!",
                    Color.RED
                )
            }
            binding!!.engineTxt.requestFocus()
            return false
        } else if (fuelId == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it, "Please Select Car Fuel Type!",
                    Color.RED
                )
            }
            return false
        } else if (binding!!.purchaseTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Enter Purchase Amount!",
                    Color.RED
                )
            }
            binding!!.purchaseTxt.requestFocus()
            return false
        } else if (binding!!.purchaseDateTxt.text?.length!! <=3) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Select Purchase Date!",
                    Color.RED
                )
            }
            return false
        }

        return true
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {

            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }!!

            MainActivity.status = true

            binding!!.addVehicleUpdate.setOnClickListener {
                if (validation()) {
                    progressDisplay.show()
                    uploadVehicle()
                }
//                replaceFrame(1)
            }

            binding!!.brandTxt.setOnClickListener {
                val intent = Intent(context, BrandActivity::class.java)
                startActivityForResult(intent, 1)
            }
            binding!!.modelTxt.setOnClickListener {
                if (binding!!.brandTxt.text.length == 0) {
                    context?.let {
                        SnackBarUtils.showTopSnackbar(
                            it, "Please Select Brand First!",
                            Color.RED
                        )
                    }

                } else {
                    val intent = Intent(context, BrandModelActivity::class.java)
                    intent.putExtra("brandId", brandId)
                    startActivityForResult(intent, 2)
                }
            }
            binding!!.variantTxt.setOnClickListener {
                if (binding!!.modelTxt.text.length == 0) {
                    context?.let {
                        SnackBarUtils.showTopSnackbar(
                            it, "Please Select Model First!",
                            Color.RED
                        )
                    }

                } else {
                    val intent = Intent(context, VariantActivity::class.java)
                    intent.putExtra("modelId", modelId)
                    startActivityForResult(intent, 4)
                }
            }

            binding!!.purchaseDateTxt.setOnClickListener {
                showDatePicker()
            }

            binding!!.engineTxt.setOnClickListener {
                if (binding!!.variantTxt.text.length == 0) {
                    context?.let {
                        SnackBarUtils.showTopSnackbar(
                            it, "Please Select Variant First!",
                            Color.RED
                        )
                    }
                } else {
                    val intent = Intent(context, EngineActivity::class.java)
                    intent.putExtra("variantId", variantId)
                    startActivityForResult(intent, 5)
                }
            }
            binding!!.mileageGet.setOnClickListener {
                val intent = Intent(context, KM_MileageActivity::class.java)
                startActivityForResult(intent, 6)
            }
            binding!!.fuelId.setOnClickListener {
                if (binding!!.engineTxt.text?.length == 0) {
                    context?.let {
                        SnackBarUtils.showTopSnackbar(
                            it, "Please Enter Engine Details!",
                            Color.RED
                        )
                    }
                } else {
                    val intent = Intent(context, FuelActivity::class.java)
                    startActivityForResult(intent, 3)
                }

            }

        }
    }

    private fun uploadVehicle() {
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()



        var brandValue = ""
        var modelValue = ""
        var variantValue = ""
        var engineValue = ""

        if (brandId == 0) {
            brandValue = binding!!.brandTxt.text.toString()
        } else {
            brandValue = brandId.toString()
        }


        if (modelId == 0) {
            modelValue = binding!!.modelTxt.text.toString()
        } else {
            modelValue = modelId.toString()

        }

        if (variantId == 0) {
            variantValue = binding!!.variantTxt.text.toString()
        } else {
            variantValue = variantId.toString()
        }

        if (engineId==0){
            engineValue=binding!!.engineTxt.text.toString()
        }else{
            engineValue = engineId.toString()
        }

        val vehicleCall = RetrofitClient.apiService.uploadVehicle(
            "Bearer $token",
            "1",
            user_id,
            "1",
            binding!!.carName.text.toString(),
            brandValue, modelValue, variantValue, engineValue , fuelId.toString(),
            binding!!.purchaseTxt.text.toString(),
            binding!!.purchaseDateTxt.text.toString(),brand_type,model_type,variant_type,engine_type
        )

        vehicleCall.enqueue(object : Callback<VehicleModel> {
            override fun onResponse(call: Call<VehicleModel>, response: Response<VehicleModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        replaceFrame(apiResponse.data[0].id)
                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<VehicleModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }

        })
    }

    private fun replaceFrame(id: Int) {
        // Create a new instance of the next fragment
        val nextFragment = VehicleSecondStepFragment()

        // Pass the id value to the next fragment using arguments
        val bundle = Bundle()
        bundle.putInt("vehicleId", id)
        nextFragment.arguments = bundle

        CommonActivity.replaceFragment = nextFragment
        CommonActivity.titleTop = getString(R.string.add_vehicle)
        startActivity(Intent(context, CommonActivity::class.java))

    }


    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        if (requestCode == 1 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("brandInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val brandName = countryInfoArray[0] // The first part before the comma
                brandId = countryInfoArray[1].toInt()   // The second part after the comma
                brand_type = countryInfoArray[2]   // The third part after the comma

                // Now you can use the countryInfo as needed
                binding!!.brandTxt.text = Editable.Factory.getInstance().newEditable(brandName)
            }
        }
        if (requestCode == 2 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("modelInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val modelName = countryInfoArray[0] // The first part before the comma
                modelId = countryInfoArray[1].toInt()   // The second part after the comma
                model_type = countryInfoArray[2]   // The third part after the comma

                // Now you can use the countryInfo as needed
                binding!!.modelTxt.text = Editable.Factory.getInstance().newEditable(modelName)
            }
        }
        if (requestCode == 3 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("fuelInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val fuelName = countryInfoArray[0] // The first part before the comma
                fuelId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.fuelId.text = Editable.Factory.getInstance().newEditable(fuelName)
            }
        }
        if (requestCode == 4 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("variantInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val variantName = countryInfoArray[0] // The first part before the comma
                variantId = countryInfoArray[1].toInt()   // The second part after the comma
                variant_type = countryInfoArray[2]   // The third part after the comma

                // Now you can use the countryInfo as needed
                binding!!.variantTxt.text = Editable.Factory.getInstance().newEditable(variantName)
            }
        }
        if (requestCode == 5 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("engineInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val engineName = countryInfoArray[0] // The first part before the comma
                engineId = countryInfoArray[1].toInt()   // The second part after the comma
                engine_type = countryInfoArray[2]   // The third part after the comma

                // Now you can use the countryInfo as needed
                binding!!.engineTxt.text = Editable.Factory.getInstance().newEditable(engineName)
            }
        }
        if (requestCode == 6 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("typeInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val typeName = countryInfoArray[0] // The first part before the comma
                typeSlug = countryInfoArray[1].toString()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.mileageGet.text = Editable.Factory.getInstance().newEditable(typeName)
            }
        }
    }

    private fun showDatePicker() {
        val calendar = Calendar.getInstance()
        val year = calendar.get(Calendar.YEAR)
        val month = calendar.get(Calendar.MONTH)
        val day = calendar.get(Calendar.DAY_OF_MONTH)

        val datePickerDialog = context?.let {
            DatePickerDialog(
                it,
                DatePickerDialog.OnDateSetListener { _, selectedYear, selectedMonth, selectedDay ->
                    // Handle the selected date
                    onDateSet(selectedYear, selectedMonth, selectedDay)
                },
                year,
                month,
                day
            )
        }
        //  datePickerDialog.datePicker.minDate = System.currentTimeMillis() - 1000
        datePickerDialog?.datePicker?.maxDate = System.currentTimeMillis()
        datePickerDialog?.show()
    }

    private fun onDateSet(selectedYear: Int, selectedMonth: Int, selectedDay: Int) {
        val formattedMonth = selectedMonth + 1
        val formattedDate = "$selectedYear-$formattedMonth-$selectedDay"
        selectedDate = "$selectedYear-$formattedMonth-$selectedDay"

        binding!!.purchaseDateTxt.setText(formattedDate)

    }

}
