package codeflies.com.mcc.Fragment

import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.method.HideReturnsTransformationMethod
import android.text.method.PasswordTransformationMethod
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.databinding.FragmentChangePasswordBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class ChangePasswordFragment : Fragment() {

    private var binding: FragmentChangePasswordBinding? = null

    var confirmPs = ""
    var valueOld = 0
    var valueNew = 0
    var valueConfirm = 0
    var password = ""
    private var sharedPreference: SharedPreference? = null
    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentChangePasswordBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }
            MainActivity.status = true


            binding!!.changePassword.setOnClickListener {

                confirmPs = binding!!.newPs.text.toString()
                password = binding!!.cnfmPs.text.toString()

                if (validation()) {
                    progressDisplay.show()
                    changePS()
                }
            }

            binding!!.oldShowPassword.setOnClickListener {
                valueOld = 1
                changeTextType(valueOld)

            }
            binding!!.oldHidePassword.setOnClickListener {
                valueOld = 2
                changeTextType(valueOld)
            }
            binding!!.newShowPassword.setOnClickListener {
                valueNew = 1
                changeNewType(valueNew)
            }
            binding!!.newHidePassword.setOnClickListener {
                valueNew = 2
                changeNewType(valueNew)
            }
            binding!!.cnfmShowPassword.setOnClickListener {
                valueConfirm = 1
                changeCnfmType(valueConfirm)
            }
            binding!!.cnfmHidePassword.setOnClickListener {
                valueConfirm = 2
                changeCnfmType(valueConfirm)
            }
        }

    }

    private fun changeCnfmType(value: Int) {
        if (value == 1) {
            binding!!.cnfmPs.transformationMethod = HideReturnsTransformationMethod.getInstance()
            binding!!.cnfmHidePassword.visibility = View.VISIBLE
            binding!!.cnfmShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding!!.cnfmPs.transformationMethod = PasswordTransformationMethod.getInstance()
            binding!!.cnfmHidePassword.visibility = View.GONE
            binding!!.cnfmShowPassword.visibility = View.VISIBLE
        }
    }

    private fun changeNewType(value: Int) {
        if (value == 1) {
            binding!!.newPs.transformationMethod = HideReturnsTransformationMethod.getInstance()
            binding!!.newHidePassword.visibility = View.VISIBLE
            binding!!.newShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding!!.newPs.transformationMethod = PasswordTransformationMethod.getInstance()
            binding!!.newHidePassword.visibility = View.GONE
            binding!!.newShowPassword.visibility = View.VISIBLE
        }
    }

    private fun changeTextType(value: Int) {
        if (value == 1) {
            binding!!.oldPs.transformationMethod = HideReturnsTransformationMethod.getInstance()
            binding!!.oldHidePassword.visibility = View.VISIBLE
            binding!!.oldShowPassword.visibility = View.GONE
        }
        if (value == 2) {
            binding!!.oldPs.transformationMethod = PasswordTransformationMethod.getInstance()
            binding!!.oldHidePassword.visibility = View.GONE
            binding!!.oldShowPassword.visibility = View.VISIBLE
        }
    }

    private fun validation(): Boolean {
        if (binding!!.oldPs.text.toString().length <= 5) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Old Password length should be grater then 6 !",
                    Color.RED
                )
            }
            binding!!.oldPs.requestFocus()
            return false
        } else if (binding!!.newPs.text.toString().length <= 5) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Password length should be grater then 6 !",
                    Color.RED
                )
            }
            binding!!.newPs.requestFocus()
            return false
        } else if (binding!!.cnfmPs.text.toString().length <= 5) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Confirm Password length should be grater then 6 !",
                    Color.RED
                )
            }
            binding!!.cnfmPs.requestFocus()
            return false
        } else if (!confirmPs.equals(password)) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Password and confirm password does not match",
                    Color.RED
                )
            }
            binding!!.cnfmPs.requestFocus()
            return false
        }

        return true
    }

    private fun changePS() {
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = "" + sharedPreference?.getData("user_id")
        val resetPasswordCall = RetrofitClient.apiService.resetPassword(
            authorizationToken,
            userId,
            binding!!.oldPs.text.toString(),
            binding!!.newPs.text.toString(),
            binding!!.cnfmPs.text.toString()
        )

        resetPasswordCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message.toString(),
                                Color.parseColor("#ca9730")
                            )
                        }
                        Handler(Looper.getMainLooper()).postDelayed({
                            requireActivity().finish()
                        }, 2000)

                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }
        })
    }
}