package codeflies.com.mcc.Fragment

import android.graphics.Color
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.Model.SignUpModel
import codeflies.com.mcc.databinding.FragmentContactUSBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class Contact_USFragment : Fragment() {

    private var binding: FragmentContactUSBinding? = null

    private var sharedPreference: SharedPreference? = null

    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentContactUSBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }
            MainActivity.status = true

            progressDisplay.show()
            getuserData()

            binding!!.contactUs.setOnClickListener {

                if (validation()) {
                    contextUs()
                    progressDisplay.show()

                }

            }
        }
    }

    private fun validation(): Boolean {
        if (binding!!.mobile.text.toString().length <= 8) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please enter valid mobile number",
                    Color.RED
                )
            }
            binding!!.mobile.requestFocus()
            return false
        } else if (binding!!.content.text.toString().length == 0) {
                context?.let {
                    SnackBarUtils.showTopSnackbar(
                        it,
                        "The message field is required",
                        Color.RED
                    )
                }
                binding!!.content.requestFocus()
                return false
            }
        return true
    }

    private fun contextUs() {
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = "" + sharedPreference?.getData("user_id")


        val contactCall = RetrofitClient.apiService.contactUs(
            authorizationToken,
            userId,
            binding!!.content.text.toString(),
            binding!!.mobile.text.toString()
        )

        contactCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {

                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message.toString(),
                                Color.parseColor("#ca9730")
                            )
                        }

                        Handler(Looper.getMainLooper()).postDelayed({
                            requireActivity().finish()
                        }, 2000)

                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }
        })


    }


    private fun getuserData() {
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = sharedPreference?.getData("user_id")!!.toInt()

        val getUserCall = RetrofitClient.apiService.userData(authorizationToken, userId)

        getUserCall.enqueue(object : Callback<SignUpModel> {
            override fun onResponse(call: Call<SignUpModel>, response: Response<SignUpModel>) {
                progressDisplay.dismiss()
                MainActivity.status = true
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        binding!!.name.setText(apiResponse.data.first_name + " " + apiResponse.data.last_name)
                        binding!!.email.setText(apiResponse.data.email)


                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let { SnackBarUtils.showTopSnackbar(it, errorMessage, Color.RED) }
                    } catch (e: Exception) {

                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<SignUpModel>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }
        })
    }

}