package codeflies.com.mcc.Fragment

import android.app.Dialog
import android.content.Intent
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.LoginActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentDeleteBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class DeleteFragment : Fragment() {

    private var binding: FragmentDeleteBinding? = null
    private var sharedPreference: SharedPreference? = null

    private lateinit var progressDisplay: ProgressDisplay


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentDeleteBinding.inflate(inflater, container, false)
        return binding!!.root
    }


    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }

            binding!!.deleteAccountButton.setOnClickListener {
                if (validation()) {
                    exitActivity()
                }
            }
        }

    }

    private fun validation(): Boolean {
        if (binding!!.reason.text.toString().length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please enter valid reason",
                    Color.RED
                )
            }
            binding!!.reason.requestFocus()
            return false
        }
        return true
    }


    private fun exitActivity() {

       // val mainActivity = AppManager.instance.getMainActivity()

        val dialog = activity?.let { Dialog(it) }
        dialog?.setContentView(R.layout.delete_dialog)
        dialog?.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(true)
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        val yes = dialog.findViewById<TextView>(R.id.yes)
        val no = dialog.findViewById<TextView>(R.id.no)
        val title = dialog.findViewById<TextView>(R.id.title)
        yes.setOnClickListener {
            progressDisplay.show()
            deleteFunction()
        }
        no.setOnClickListener {
            dialog.dismiss()
        }
        dialog.show()
    }

    private fun deleteFunction() {
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = "" + sharedPreference?.getData("user_id")


        val deleteCall = RetrofitClient.apiService.deleteProfile(
            authorizationToken,
            userId,
            binding!!.reason.text.toString()
        )

        deleteCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {

                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message.toString(),
                                Color.parseColor("#ca9730")
                            )
                        }

                        Handler(Looper.getMainLooper()).postDelayed({
                            startActivity(Intent(context, LoginActivity::class.java))
                            activity?.finishAffinity()
                        }, 2000)

                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }
        })

    }

}