package codeflies.com.mcc.Fragment

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.GridLayoutManager
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Activity.RepairDetailsActivity
import codeflies.com.mcc.Activity.ServiceDetailsActivity
import codeflies.com.mcc.Adapter.DigitalDocsAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.DigidocsItem
import codeflies.com.mcc.Model.ResponseDigiDocs
import codeflies.com.mcc.databinding.FragmentDigitalDocsBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class   DigitalDocsFragment : Fragment(), DigitalDocsAdapter.OnClickListener {

    private var binding: FragmentDigitalDocsBinding? = null


    private lateinit var sharedPreference: SharedPreference

    private lateinit var progressDisplay: ProgressDisplay


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment

        binding = FragmentDigitalDocsBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        MainActivity.status = true

        if (isAdded) {
            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }!!

//            binding!!.dataNot.visibility = View.VISIBLE
            //getDocuments()

        }

    }

    private fun getDocuments() {
        progressDisplay.show()
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()

        val servicesCall = RetrofitClient.apiService.getDocuments("Bearer $token",user_id)
        servicesCall.enqueue(object : Callback<ResponseDigiDocs> {
            override fun onResponse(call: Call<ResponseDigiDocs>, response: Response<ResponseDigiDocs>) {
                progressDisplay.dismiss()
                MainActivity.status = true
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse?.status!!) {
                        if (apiResponse.digidocs?.isNotEmpty() == true) {
                            binding!!.dataNot.visibility = View.GONE
                            binding!!.documents.visibility = View.VISIBLE

                            val adapter =
                                DigitalDocsAdapter(response.body()?.digidocs!!, requireContext(),this@DigitalDocsFragment)
                            binding!!.documents.layoutManager =
                                GridLayoutManager(requireContext(), 2)
                            binding!!.documents.setHasFixedSize(true)
                            binding!!.documents.adapter = adapter
                        }else{
                            binding!!.dataNot.visibility = View.VISIBLE
                            binding!!.documents.visibility = View.GONE
                        }
                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message.toString(),
                                Color.RED
                            )
                        }
                        binding!!.dataNot.visibility = View.VISIBLE
                        binding!!.documents.visibility = View.GONE
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                    binding!!.dataNot.visibility = View.VISIBLE
                    binding!!.documents.visibility = View.GONE
                }


                Log.d("ERROR_CODE",response.code().toString())
            }

            override fun onFailure(call: Call<ResponseDigiDocs>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                binding!!.dataNot.visibility = View.VISIBLE
                binding!!.documents.visibility = View.GONE
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
                Log.d("ERROR_CODE",t.message.toString())

            }
        })


    }

    override fun onClicked(item: DigidocsItem) {
        Log.e("type",item.type.toString()+item.vehicleId)
        if (item.type.equals("vehicle")){
            startActivity(Intent(context, CommonActivity::class.java))
            CommonActivity.titleTop = item.name.toString()

            val carDetailsFragment = Car_DetailsFragment()

            val bundle = Bundle()
            bundle.putString(
                "vehicleId",
                item.vehicleId.toString()
            ) // replace "vehicleId" with the actual key and item data
            carDetailsFragment.arguments = bundle


            CommonActivity.replaceFragment = carDetailsFragment
        }else if (item.type.equals("repair")){
            startActivity(Intent(context, RepairDetailsActivity::class.java))
            RepairDetailsActivity.vehicleId = item.vehicleId.toString()

        }else if (item.type.equals("service")){
            startActivity(Intent(context, ServiceDetailsActivity::class.java))
            ServiceDetailsActivity.serviceId = item.vehicleId.toString()
        }
    }


}