package codeflies.com.mcc.Fragment

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.GridLayoutManager
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Activity.LoginActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Adapter.CarCollectionAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.Model.VehicleDetailsModel
import codeflies.com.mcc.Model.VehicleDetailsPojo
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentHomeBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class HomeFragment : Fragment(), CarCollectionAdapter.OnItemClickListener,CarCollectionAdapter.OnItemDeleteListener {


    var binding: FragmentHomeBinding? = null

    private lateinit var sharedPreference: SharedPreference
    private  var progressDisplay: ProgressDisplay? =null

    companion object{
        var isTablet=false
    }
    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentHomeBinding.inflate(inflater, container, false)


        if (isAdded) {
            MainActivity.titleTop.text = getString(R.string.app_name)

            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }!!

            getVehicle()
            MainActivity.status = true

            binding!!.addCarHome.setOnClickListener {
                startActivity(Intent(context, CommonActivity::class.java))
                CommonActivity.replaceFragment = AddVehicleFragment()
                CommonActivity.titleTop = getString(R.string.add_vehicle)
            }

            binding!!.refreshLayout.setOnRefreshListener {
                getVehicle()
                MainActivity.status = true

                binding!!.refreshLayout.isRefreshing = false
            }
        }


        return binding!!.root
    }

    private fun getVehicle() {
        if (isAdded) {
            progressDisplay?.show()
            var token = sharedPreference.getData("token").toString()
            Log.e("token", token)
            var user_id = sharedPreference.getData("user_id").toString()

            Log.e("user_id", user_id)
            val servicesCall = RetrofitClient.apiService.getVehicleData("Bearer $token", user_id)

            servicesCall.enqueue(object : Callback<VehicleDetailsModel> {
                override fun onResponse(
                    call: Call<VehicleDetailsModel>,
                    response: Response<VehicleDetailsModel>
                ) {
                    dismissProgressDialog()
                    if (response.isSuccessful) {
                        val apiResponse = response.body()
                        if (apiResponse != null && apiResponse.status) {
                            if (apiResponse.data.isNotEmpty()) {
                                binding!!.dataNot.visibility = View.GONE
                                binding!!.carCollection.visibility = View.VISIBLE


                                if (isTablet) {
                                    binding!!.carCollection.layoutManager =
                                        GridLayoutManager(context, 4)

                                } else {
                                    binding!!.carCollection.layoutManager =
                                        GridLayoutManager(context, 2)

                                }
                                val adapter =
                                    context?.let {
                                        CarCollectionAdapter(
                                            it,
                                            apiResponse.data,
                                            this@HomeFragment,
                                            this@HomeFragment
                                        )
                                    }
                                binding!!.carCollection.adapter = adapter


                            } else {
                                binding!!.dataNot.visibility = View.VISIBLE
                                binding!!.carCollection.visibility = View.GONE


                            }
                        } else {
                            context?.let {
                                SnackBarUtils.showTopSnackbar(
                                    it,
                                    apiResponse?.message.toString(),
                                    Color.RED
                                )
                            }
                        }
                    } else {
                        val errorResponse = response.errorBody()?.string()
                        val gson = Gson()
                        try {
                            val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                            val errorMessage = errorJson.get("message").asString
                            if (errorMessage.equals("Unauthenticated.")) {
                                sharedPreference.saveModeValues("mode", false)
                                sharedPreference.saveData("token", "")
                                sharedPreference.saveData("user_id", "")
                                startActivity(Intent(context, LoginActivity::class.java))
                                activity?.finishAffinity()
                            } else {
                                context?.let {
                                    SnackBarUtils.showTopSnackbar(
                                        it,
                                        errorMessage.toString(),
                                        Color.RED
                                    )
                                }

                            }
                        } catch (e: Exception) {
                            context?.let {
                                SnackBarUtils.showTopSnackbar(
                                    it,
                                    e.message.toString(),
                                    Color.RED
                                )
                            }
                        }
                    }


                }

                override fun onFailure(call: Call<VehicleDetailsModel>, t: Throwable) {
                    dismissProgressDialog()
                    MainActivity.status = true
                    context?.let {
                        SnackBarUtils.showTopSnackbar(
                            it,
                            t.message.toString(),
                            Color.RED
                        )
                    }

                }
            })

        }
    }


    override fun onItemClick(item: VehicleDetailsPojo, position: Int) {


        startActivity(Intent(context, CommonActivity::class.java))
        CommonActivity.titleTop = item.name

        val carDetailsFragment = Car_DetailsFragment()

        val bundle = Bundle()
        bundle.putString(
            "vehicleId",
            item.id.toString()
        ) // replace "vehicleId" with the actual key and item data
        carDetailsFragment.arguments = bundle


        CommonActivity.replaceFragment = carDetailsFragment

    }

    private fun dismissProgressDialog() {
        if (progressDisplay != null && progressDisplay!!.isShowing) {
            progressDisplay!!.dismiss()
        }
    }

    override fun onDestroy() {
        dismissProgressDialog()
        super.onDestroy()
    }

    override fun onItemDelete(item: VehicleDetailsPojo, position: Int) {

        val authorizationToken = "Bearer " + sharedPreference.getData("token")

        val uploaderCall = RetrofitClient.apiService.deleteCar(
            authorizationToken,item.id.toString()
        )

        uploaderCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                Log.d("EERRROOCC",response.code().toString())
                getVehicle()
            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                Log.d("EERRROOCC",t.message.toString())
                progressDisplay?.dismiss()


            }

        })

    }

}
