package codeflies.com.mcc.Fragment

import android.graphics.Color
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Adapter.NotificationAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.Model.NotificationModel
import codeflies.com.mcc.databinding.FragmentNotificationBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class NotificationFragment : Fragment() {

    private var binding: FragmentNotificationBinding? = null


    private lateinit var sharedPreference: SharedPreference

    private lateinit var progressDisplay: ProgressDisplay


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentNotificationBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }!!

            progressDisplay.show()
            getNotification()

            binding?.status?.setOnClickListener {
                readNotification()
                progressDisplay.show()
            }
        }


//        val adapter = NotificationAdapter(requireContext(), cars)
//        binding.notificationRcy.adapter = adapter
//        binding.notificationRcy.layoutManager = LinearLayoutManager(requireContext())
    }


    private fun getNotification() {
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()


        val servicesCall = RetrofitClient.apiService.getNotificationData("Bearer $token", user_id)

        servicesCall.enqueue(object : Callback<NotificationModel> {
            override fun onResponse(
                call: Call<NotificationModel>,
                response: Response<NotificationModel>
            ) {
                progressDisplay.dismiss()
                MainActivity.status = true
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        if (apiResponse.data.isNotEmpty()) {
                            binding!!.dataNot.visibility = View.GONE
                            binding!!.notificationRcy.visibility = View.VISIBLE
                            val adapter = context?.let {
                                NotificationAdapter(
                                    it,
                                    apiResponse.data
                                )
                            }
                            binding!!.notificationRcy.adapter = adapter

                        } else {
                            binding!!.dataNot.visibility = View.VISIBLE
                            binding!!.notificationRcy.visibility = View.GONE
                            binding!!.status.visibility = View.GONE

                        }
                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }
                //readNotification()


            }

            override fun onFailure(call: Call<NotificationModel>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }

            }
        })


    }



    private fun readNotification() {

        val authorizationToken = "Bearer " + sharedPreference.getData("token")

        val uploaderCall = RetrofitClient.apiService.readAllNotification(
            authorizationToken
        )

        uploaderCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                Log.d("EERRROOCC",response.code().toString())
                getNotification()
            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                Log.d("EERRROOCC",t.message.toString())
                progressDisplay.dismiss()


            }

        })


    }



}