package codeflies.com.mcc.Fragment

import android.app.Activity
import android.app.Dialog
import android.content.Intent
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.Editable
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.CityActivity
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Activity.CountryActivity
import codeflies.com.mcc.Activity.LoginActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.Model.SignUpModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentProfileBinding
import com.google.android.gms.auth.api.signin.GoogleSignIn
import com.google.android.gms.auth.api.signin.GoogleSignInClient
import com.google.android.gms.auth.api.signin.GoogleSignInOptions
import com.google.firebase.auth.FirebaseAuth
import com.google.gson.Gson
import com.google.gson.JsonObject
import com.skydoves.elasticviews.ElasticButton
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class ProfileFragment : Fragment() {

    private var binding: FragmentProfileBinding? = null

    private var sharedPreference: SharedPreference? = null

    private lateinit var progressDisplay: ProgressDisplay
    var countryId = 0
    var cityId = 0

    private lateinit var googleSignInClient: GoogleSignInClient

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?
    ): View {
        binding = FragmentProfileBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }

            progressDisplay.show()
            getuserData()

            // Configure Google Sign-In
            val gso = GoogleSignInOptions.Builder(GoogleSignInOptions.DEFAULT_SIGN_IN)
                .requestEmail()
                .build()

            googleSignInClient = GoogleSignIn.getClient(requireActivity(), gso)

            binding!!.updateProfile.setOnClickListener {
                if (binding!!.updateProfile.text.toString().equals("EDIT")) {
                    binding!!.updateProfile.text = "Update"

                    binding!!.firstNameP.isCursorVisible = true
                    binding!!.firstNameP.isFocusable = true
                    binding!!.firstNameP.isFocusableInTouchMode = true
                    binding!!.firstNameP.requestFocus()
                    binding!!.firstNameP.setSelection(binding!!.firstNameP.text!!.length)

                    binding!!.lastNameP.isCursorVisible = true
                    binding!!.lastNameP.isFocusable = true
                    binding!!.lastNameP.isFocusableInTouchMode = true


                    binding!!.countrySelect.visibility = View.VISIBLE


                    binding!!.citySelect.visibility = View.VISIBLE


                    binding!!.countryName.setOnClickListener {
                        getCountry()
                    }

                    binding!!.cityName.setOnClickListener {

                        getCity()
                    }


                } else {
                    if (validation()) {
                        progressDisplay.show()
                        updateProfile()
                    }
                }
            }

            // Access views using binding
            binding!!.delete.setOnClickListener {

                startActivity(Intent(context, CommonActivity::class.java))
                CommonActivity.replaceFragment = DeleteFragment()
                CommonActivity.titleTop = getString(R.string.delete_my_account)

            }

            binding!!.changePassword.setOnClickListener {
                startActivity(Intent(context, CommonActivity::class.java))
                CommonActivity.replaceFragment = ChangePasswordFragment()
                CommonActivity.titleTop = getString(R.string.change_password)
            }

            binding!!.logout.setOnClickListener {
                logoutApp()
            }
        }
    }

    private fun validation(): Boolean {
        val firstName = binding?.firstNameP?.text?.toString()?.trim()
        val lastName = binding?.lastNameP?.text?.toString()?.trim()
        val countryName = binding?.countryName?.text?.toString()?.trim()
        val cityName = binding?.cityName?.text?.toString()?.trim()

        if (firstName.isNullOrBlank() || firstName.length < 3) {
            context?.let { SnackBarUtils.showTopSnackbar(it, "Enter a valid First Name", Color.RED) }
            binding?.firstNameP?.requestFocus()
            return false
        } else if (lastName.isNullOrBlank() || lastName.length < 3) {
            context?.let { SnackBarUtils.showTopSnackbar(it, "Enter a valid Last Name", Color.RED) }
            binding?.lastNameP?.requestFocus()
            return false
        } else if (countryName.isNullOrBlank() || countryName.length < 3) {
            context?.let { SnackBarUtils.showTopSnackbar(it, "Enter a valid Country Name", Color.RED) }
            binding?.countryName?.requestFocus()
            return false
        } else if (cityName.isNullOrBlank() || cityName.length < 3) {
            context?.let { SnackBarUtils.showTopSnackbar(it, "Enter a valid City Name", Color.RED) }
            binding?.cityName?.requestFocus()
            return false
        }

        return true
    }

    private fun updateProfile() {
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = "" + sharedPreference?.getData("user_id")

        val resetPasswordCall = RetrofitClient.apiService.updateProfile(
            authorizationToken,
            userId,
            binding!!.firstNameP.text.toString(),
            binding!!.lastNameP.text.toString(),
            countryId.toString(),
            cityId.toString()
        )

        resetPasswordCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {

                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse.message.toString(),
                                Color.parseColor("#ca9730")
                            )
                        }

                        binding!!.updateProfile.text = "EDIT"
                        binding!!.firstNameP.isCursorVisible = false
                        binding!!.firstNameP.isFocusable = false
                        binding!!.firstNameP.isFocusableInTouchMode = false

                        binding!!.lastNameP.isCursorVisible = false
                        binding!!.lastNameP.isFocusable = false
                        binding!!.lastNameP.isFocusableInTouchMode = false

                        binding!!.countryName.isCursorVisible = false
                        binding!!.countryName.isFocusable = false
                        binding!!.countryName.isFocusableInTouchMode = false

                        binding!!.cityName.isCursorVisible = false
                        binding!!.cityName.isFocusable = false
                        binding!!.cityName.isFocusableInTouchMode = false

                        binding!!.countrySelect.visibility = View.GONE

                        binding!!.citySelect.visibility = View.GONE

                        getuserData()
                        progressDisplay.show()
                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }
        })

    }

    private fun getuserData() {
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = sharedPreference?.getData("user_id")!!.toInt()

        val getUserCall = RetrofitClient.apiService.userData(authorizationToken, userId)

        getUserCall.enqueue(object : Callback<SignUpModel> {
            override fun onResponse(call: Call<SignUpModel>, response: Response<SignUpModel>) {
                progressDisplay.dismiss()
                MainActivity.status = true
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        binding!!.firstNameP.setText(apiResponse.data.first_name.toString())
                        binding!!.lastNameP.setText(apiResponse.data.last_name.toString())
                        binding!!.email.text = apiResponse.data.email.toString()


                        if (apiResponse.data.userDetail.country != null){
                            countryId = apiResponse.data.userDetail.country.id.toInt()
                        }
                        if (apiResponse.data.userDetail.city != null){
                            cityId = apiResponse.data.userDetail.city.id.toInt()

                        }

                        if (apiResponse.data.userDetail.country != null) {
                            binding!!.countryName.setText(apiResponse.data.userDetail.country.name)
                        }
                        if (apiResponse.data.userDetail.city != null) {
                            binding!!.cityName.setText(apiResponse.data.userDetail.city.name)
                        }


                        binding!!.updateProfile.text = "EDIT"

                        binding!!.firstNameP.isCursorVisible = false
                        binding!!.firstNameP.isFocusable = false
                        binding!!.firstNameP.isFocusableInTouchMode = false

                        binding!!.lastNameP.isCursorVisible = false
                        binding!!.lastNameP.isFocusable = false
                        binding!!.lastNameP.isFocusableInTouchMode = false

                        binding!!.countryName.isCursorVisible = false
                        binding!!.countryName.isFocusable = false
                        binding!!.countryName.isFocusableInTouchMode = false

                        binding!!.cityName.isCursorVisible = false
                        binding!!.cityName.isFocusable = false
                        binding!!.cityName.isFocusableInTouchMode = false

                        if (apiResponse.data.facebook_token != null) {
                            binding!!.loginBy.text = "Facebook"
                        } else if (apiResponse.data.google_token != null) {
                            binding!!.loginBy.text = "Google"
                        } else {
                            binding!!.loginBy.text = "Email"
                        }

                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let { SnackBarUtils.showTopSnackbar(it, errorMessage, Color.RED) }
                    } catch (e: Exception) {

                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<SignUpModel>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }
        })
    }

    private fun logoutApp() {
        val dialog = Dialog(requireContext())
        dialog.setContentView(R.layout.logout_layout)
        dialog.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(true)
        dialog.window!!.attributes.windowAnimations = R.style.animation
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        val yes = dialog.findViewById<ElasticButton>(R.id.yes)
        val no = dialog.findViewById<ElasticButton>(R.id.no)
        val title = dialog.findViewById<TextView>(R.id.title)
        val desc = dialog.findViewById<TextView>(R.id.desc)

        yes.text = "Logout"
        no.text = "Cancel"
        title.text = "Logout"
        desc.text = "Are you sure to want logout from MYCC?"
        yes.setOnClickListener {
            if(binding!!.loginBy.text.equals("Google")){
                signOut()
            }
            logoutMethod()
            dialog.dismiss()
        }
        no.setOnClickListener { dialog.dismiss() }
        dialog.show()
    }

    private fun logoutMethod() {
        progressDisplay.show()
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = "" + sharedPreference?.getData("user_id")

        val callLogout = RetrofitClient.apiService.logout(authorizationToken, userId)

        callLogout.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )
                        sharedPreference?.saveModeValues("mode", false)
                        sharedPreference?.saveData("token", "")
                        sharedPreference?.saveData("user_id", "")

                        sharedPreference?.saveData("car_value", "")
                        sharedPreference?.saveData("member_value", "")
                        sharedPreference?.saveData("policy_value", "")
                        sharedPreference?.saveData("repair_value", "")
                        sharedPreference?.saveData("service_value", "")

                        sharedPreference?.saveData("car_status", "")
                        sharedPreference?.saveData("member_status", "")
                        sharedPreference?.saveData("policy_status", "")
                        sharedPreference?.saveData("repair_status", "")
                        sharedPreference?.saveData("service_status", "")



                        startActivity(Intent(requireActivity(), LoginActivity::class.java))
                        activity?.finishAffinity()


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            e.message.toString().toString(),
                            Color.RED
                        )

                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(context!!, t.message.toString(), Color.RED)
            }
        })
    }


    private fun getCountry() {
        val intent = Intent(context, CountryActivity::class.java)
        startActivityForResult(intent, 1)
    }


    private fun getCity() {
        if (countryId == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Select Country First!",
                    Color.RED
                )
            }
        } else {
            val intent = Intent(context, CityActivity::class.java)
            intent.putExtra("countryId", countryId)
            startActivityForResult(intent, 2)
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        if (requestCode == 1 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("countryInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val countryName = countryInfoArray[0] // The first part before the comma
                countryId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.countryName.text = Editable.Factory.getInstance().newEditable(countryName)
            }
        }
        if (requestCode == 2 && resultCode == Activity.RESULT_OK) {
            val countryInfo = data?.getStringExtra("cityInfo")
            val countryInfoArray = countryInfo?.split(",")
            if (countryInfoArray != null) {
                val cityName = countryInfoArray[0] // The first part before the comma
                cityId = countryInfoArray[1].toInt()   // The second part after the comma

                // Now you can use the countryInfo as needed
                binding!!.cityName.text = Editable.Factory.getInstance().newEditable(cityName)
            }
        }
    }

    private fun signOut() {
        val auth = FirebaseAuth.getInstance()

        // Firebase sign out
        auth.signOut()

        // Google sign out
        googleSignInClient.signOut().addOnCompleteListener(requireActivity()) {
            // Update UI after sign out, for example, navigate to sign-in screen
        }
    }
}