package codeflies.com.mcc.Fragment

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Activity.RepairDetailsActivity
import codeflies.com.mcc.Adapter.RepairsAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.DataItemUpcoming
import codeflies.com.mcc.Model.UpcomingRepairsResponse
import codeflies.com.mcc.databinding.FragmentRepairsBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class RepairsFragment : Fragment() ,RepairsAdapter.RepairDetails{

    private var binding: FragmentRepairsBinding? = null
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentRepairsBinding.inflate(inflater, container, false)



        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        MainActivity.status = true



        progressDisplay = context?.let { ProgressDisplay(it) }!!
        sharedPreference = context?.let { SharedPreference(it) }!!

        getListRepairs()
        progressDisplay.show()
    }

    private fun getListRepairs() {
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()

        val repairsCall = RetrofitClient.apiService.getUpcomingList("Bearer $token", user_id)

        repairsCall.enqueue(object : Callback<UpcomingRepairsResponse> {
            override fun onResponse(
                call: Call<UpcomingRepairsResponse>,
                response: Response<UpcomingRepairsResponse>
            ) {
                progressDisplay.dismiss()
                MainActivity.status = true
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        if (apiResponse.data?.isNotEmpty() == true) {
                            binding!!.dataNot.visibility = View.GONE
                            binding!!.repairs.visibility = View.VISIBLE

                            binding!!.repairs.layoutManager = LinearLayoutManager(context)
                            val adapter =
                                context?.let {
                                    RepairsAdapter(
                                        it,
                                        apiResponse.data,
                                        this@RepairsFragment
                                    )
                                }
                            binding!!.repairs.adapter = adapter


                        } else {
                            binding!!.dataNot.visibility = View.VISIBLE
                            binding!!.repairs.visibility = View.GONE


                        }
                        //SnackBarUtils.showTopSnackbar(context,apiResponse.data.toString(),Color.parseColor("#ca9730"))
                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }


            }

            override fun onFailure(call: Call<UpcomingRepairsResponse>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                context?.let {
                    SnackBarUtils.showTopSnackbar(
                        it,
                        t.message.toString(),
                        Color.RED
                    )
                }

            }
        })


    }

    override fun onRepairClick(dataItemUpcoming: DataItemUpcoming?) {
        startActivity(Intent(context,RepairDetailsActivity::class.java))
        RepairDetailsActivity.vehicleId = dataItemUpcoming!!.id.toString()

    }

}