package codeflies.com.mcc.Fragment

import android.graphics.Color
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Adapter.ServiceListAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.ServiceListResponse
import codeflies.com.mcc.databinding.FragmentServiceListBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class ServiceListFragment : Fragment() {

    private var binding:FragmentServiceListBinding?= null
    private lateinit var sharedPreference: SharedPreference

    private lateinit var progressDisplay: ProgressDisplay

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentServiceListBinding.inflate(layoutInflater)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        MainActivity.status = true



        progressDisplay = context?.let { ProgressDisplay(it) }!!
        sharedPreference = context?.let { SharedPreference(it) }!!


        getServiceList()
        progressDisplay.show()
    }

    private fun getServiceList() {

        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()

        val serviceCall = RetrofitClient.apiService.getServiceList("Bearer $token", user_id)

        serviceCall.enqueue(object : Callback<ServiceListResponse> {
            override fun onResponse(
                call: Call<ServiceListResponse>,
                response: Response<ServiceListResponse>
            ) {
                progressDisplay.dismiss()
                MainActivity.status = true
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status == true) {
                        if (apiResponse.data?.isNotEmpty() == true) {
                              binding!!.dataNot.visibility = View.GONE
                            binding!!.service.visibility = View.VISIBLE

                            binding!!.service.layoutManager = LinearLayoutManager(context)
                            val adapter =
                                context?.let {
                                    ServiceListAdapter(
                                        it,
                                        apiResponse.data,

                                        )
                                }
                            binding!!.service.adapter = adapter


                        } else {
                             binding!!.dataNot.visibility = View.VISIBLE
                            binding!!.service.visibility = View.GONE


                        }
                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }


            }

            override fun onFailure(call: Call<ServiceListResponse>, t: Throwable) {
                progressDisplay.dismiss()
                MainActivity.status = true
                context?.let {
                    SnackBarUtils.showTopSnackbar(
                        it,
                        t.message.toString(),
                        Color.RED
                    )
                }

            }
        })

    }
}