package codeflies.com.mcc.Fragment


import android.annotation.SuppressLint
import android.app.ProgressDialog
import android.content.Intent
import android.graphics.Color
import android.net.Uri
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.appcompat.app.AlertDialog
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Adapter.ReviewsAdapter
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.ServicesModel
import codeflies.com.mcc.Model.reviewsPojo
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentServiceReviewBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class ServiceReviewFragment : Fragment() {

    private var dataValue = "0"
    private var binding: FragmentServiceReviewBinding? = null
    private lateinit var sharedPreference: SharedPreference
    private val progressDialog by lazy {
        ProgressDialog(context).apply {
            setMessage("Please wait...")
            setCancelable(false)
        }
    }
    var latitude = 0.0 // Replace with your destination's latitude
    var longitude = 0.0 // Replace with your destination's longitude

    private lateinit var reviewsList: List<reviewsPojo>


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentServiceReviewBinding.inflate(layoutInflater, container, false)
        return binding!!.root
    }

    @SuppressLint("MissingPermission")
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            sharedPreference = context?.let { SharedPreference(it) }!!

            // Retrieve data from arguments
            dataValue = arguments?.getString("service_id").toString()

            // Use the data as needed
            if (dataValue != null) {
                // Do something with dataValue

                progressDialog.show()
                getReviewWithDetails(dataValue)
            }

            binding!!.addReview.setOnClickListener {
                if (binding!!.addReview.text.toString().equals(getString(R.string.add_review))) {
                    addReview(1, reviewsList)
                } else if (binding!!.addReview.text.toString()
                        .equals(getString(R.string.edit_review))
                ) {
                    addReview(2, reviewsList)
                }
            }

            binding!!.map.setOnClickListener {

                maplocate()

            }

        }
    }


    private fun getReviewWithDetails(dataValue: String) {
        val authorizationToken = "Bearer " + sharedPreference.getData("token")
        val reviewCall = RetrofitClient.apiService.getServicesData(authorizationToken, dataValue)

        reviewCall.enqueue(object : Callback<ServicesModel> {
            override fun onResponse(call: Call<ServicesModel>, response: Response<ServicesModel>) {
                progressDialog.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {

                        binding!!.serviceNameTitle.text = apiResponse.data[0].name.toString()
                        binding!!.servicesAddress.text =
                            apiResponse.data[0].address + "," + apiResponse.data[0].city.name + "," + apiResponse.data[0].country.name
                        binding!!.servicesDes.text = apiResponse.data[0].description

                        if (apiResponse.data[0].average_ratings == 1) {
                            binding!!.ratingOne.setImageResource(android.R.drawable.btn_star_big_on)
                        } else if (apiResponse.data[0].average_ratings == 2) {
                            binding!!.ratingOne.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingTwo.setImageResource(android.R.drawable.btn_star_big_on)
                        } else if (apiResponse.data[0].average_ratings == 3) {
                            binding!!.ratingOne.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingTwo.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingThree.setImageResource(android.R.drawable.btn_star_big_on)
                        } else if (apiResponse.data[0].average_ratings == 4) {
                            binding!!.ratingOne.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingTwo.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingThree.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingFour .setImageResource(android.R.drawable.btn_star_big_on)
                        } else if (apiResponse.data[0].average_ratings == 5) {
                            binding!!.ratingOne.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingTwo.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingThree.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingFour.setImageResource(android.R.drawable.btn_star_big_on)
                            binding!!.ratingFive.setImageResource(android.R.drawable.btn_star_big_on)
                        }

                        changeReviewName(
                            sharedPreference.getData("user_id")!!.toInt(),
                            apiResponse.data[0].reviews
                        )

                        latitude = apiResponse.data[0].latitude.toDouble()
                        longitude = apiResponse.data[0].longitude.toDouble()
                        reviewsList = apiResponse.data[0].reviews

                        val reviewsCount = apiResponse.data[0].reviews.size
                        if (reviewsCount > 0) {
                            binding?.reviewCount?.text = "("+reviewsCount.toString()+")"
                        } else {
                            binding?.reviewCount?.text = "(0)"

                        }
                        val adapter = ReviewsAdapter(apiResponse.data[0].reviews)
                        binding!!.reviewRcy.adapter = adapter

                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<ServicesModel>, t: Throwable) {
                progressDialog.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }
        })
    }

    private fun changeReviewName(data: Int?, reviews: List<reviewsPojo>) {
        val userId = data
        val reviewsList: List<reviewsPojo> = reviews

        val isUserReview = reviewsList.any { it.user_id == userId }

        binding!!.addReview.text = if (isUserReview) {
            getString(R.string.edit_review)
        } else {
            getString(R.string.add_review)
        }

    }


    fun addReview(i: Int, reviews: List<reviewsPojo>) {
        val fragmentManager = activity?.supportFragmentManager
        val fragmentTransaction = fragmentManager?.beginTransaction()

        if (reviews.isNotEmpty()) {
            if (i == 1) {
                // If i is 1, create and add the fragment without passing any data
                val serviceId = reviews[0].service_id// get your serviceId here
                val bundle = Bundle().apply {
                    putString("serviceId", serviceId)
                }
                val fragment = AddReviewFragment().apply {
                    arguments = bundle
                }
                fragmentTransaction?.replace(R.id.frameHome, fragment)
            } else if (i == 2) {
                // If i is 2, find the position where the user ID matches
                val userId = sharedPreference.getData("user_id")?.toInt()
                val position = reviews.indexOfFirst { it.user_id == userId }

                // If a match is found, create a bundle with the specific review and pass it to the fragment
                if (position != -1) {
                    val bundle = Bundle().apply {
                        putParcelable("userReview", reviews[position])
                    }
                    val fragment = AddReviewFragment().apply {
                        arguments = bundle
                    }
                    fragmentTransaction?.replace(R.id.frameHome, fragment)
                } else {
                    // Handle the case when no matching user ID is found
                    // You may show a message or take appropriate action
                }
            }
        } else {
            // If reviews list is empty or null, replace the fragment without passing any data
            val serviceId = dataValue
            val bundle = Bundle().apply {
                putString("serviceId", serviceId)
            }
            val fragment = AddReviewFragment().apply {
                arguments = bundle
            }
            fragmentTransaction?.replace(R.id.frameHome, fragment)
        }

        fragmentTransaction?.addToBackStack(null)
        fragmentTransaction?.commit()
    }

    private fun maplocate() {
        val label = "Destination" // Replace with a label for the destination

        val gmmIntentUri = Uri.parse("geo:$latitude,$longitude?q=$latitude,$longitude($label)")
        val mapIntent = Intent(Intent.ACTION_VIEW, gmmIntentUri)
        val chooser = Intent.createChooser(mapIntent, "Choose a maps app")

        if (context?.packageManager?.let { chooser.resolveActivity(it) } != null) {
            startActivity(chooser)  // Use the chooser intent instead of mapIntent
        } else {
            // Google Maps is not installed, prompt the user to install a maps app
            context?.let {
                AlertDialog.Builder(it)
                    .setMessage("To view the map, you need a maps application. Would you like to install one?")
                    .setPositiveButton("Yes") { _, _ ->
                        // Redirect the user to the Google Play Store to install a maps app
                        val marketUri = Uri.parse("market://details?id=com.google.android.apps.maps")
                        val marketIntent = Intent(Intent.ACTION_VIEW, marketUri)
                        startActivity(marketIntent)
                    }
                    .setNegativeButton("No") { _, _ ->
                        // Handle the case where the user doesn't want to install a maps app
                        // You may display a message or take other appropriate actions.
                    }
                    .show()
            }
        }
    }

}