package codeflies.com.mcc.Fragment

import android.Manifest
import android.app.Activity
import android.app.Dialog
import android.content.Intent
import android.content.pm.PackageManager
import android.graphics.Bitmap
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.media.MediaScannerConnection
import android.net.Uri
import android.os.Bundle
import android.os.Environment
import android.os.Handler
import android.os.Looper
import android.provider.MediaStore
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import android.widget.Toast
import androidx.core.content.ContextCompat.checkSelfPermission
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Adapter.CarImageAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Helper.getRealPathFromUri
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentUpcomingImageBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import okhttp3.MediaType.Companion.toMediaTypeOrNull
import okhttp3.MultipartBody
import okhttp3.RequestBody.Companion.asRequestBody
import okhttp3.RequestBody.Companion.toRequestBody
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.io.File
import java.io.FileOutputStream

class ServicesImageFragment : Fragment() {

    private var binding: FragmentUpcomingImageBinding? = null
    private lateinit var adapter: CarImageAdapter
    private var imageUriList = mutableListOf<Uri>()
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDialog: ProgressDisplay
    private var vehicleId: Int = 0
    private val REQUEST_CODE_PERMISSION = 123
    private val REQUEST_CODE_PICK_IMAGE = 200
    private val REQUEST_CAMERA_PICK_IMAGE = 199

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        binding = FragmentUpcomingImageBinding.inflate(inflater, container, false)
        return binding?.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            vehicleId = arguments?.getInt("vehicleId", -1) ?: -1

            sharedPreference = SharedPreference(requireContext())
            progressDialog = ProgressDisplay(requireContext())

            binding?.apply {
                addUpcomingUpdate.setOnClickListener {
                    progressDialog.show()
                    uploadVehicle()
                }

                uploadImage.setOnClickListener {
                    if (checkSelfPermission(requireContext(), Manifest.permission.READ_EXTERNAL_STORAGE) == PackageManager.PERMISSION_GRANTED) {
                        chooseDialog()
                    } else {
                        requestPermissions(arrayOf(Manifest.permission.READ_EXTERNAL_STORAGE), REQUEST_CODE_PERMISSION)
                    }
                }
            }
        }
    }

    override fun onRequestPermissionsResult(
        requestCode: Int,
        permissions: Array<out String>,
        grantResults: IntArray
    ) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
        if (requestCode == REQUEST_CODE_PERMISSION && grantResults.isNotEmpty() && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            chooseDialog()
        }
    }

    private fun openGalleryForImages() {
        val intent = Intent(Intent.ACTION_OPEN_DOCUMENT)
        intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
        intent.addCategory(Intent.CATEGORY_OPENABLE)
        intent.type = "image/*"
        startActivityForResult(intent, REQUEST_CODE_PICK_IMAGE)
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (requestCode == REQUEST_CODE_PICK_IMAGE && resultCode == Activity.RESULT_OK) {
            data?.clipData?.let { clipData ->
                for (i in 0 until clipData.itemCount) {
                    imageUriList.add(clipData.getItemAt(i).uri)
                    Log.e("fileanmwe",clipData.getItemAt(i).uri.path.toString())

                }
            }
            data?.data?.let {
                imageUriList.add(it)
                Log.e("fileanmwe",imageUriList.get(0).toString())

            }
            showSelectedImages()
        } else if (resultCode == Activity.RESULT_OK && requestCode == REQUEST_CAMERA_PICK_IMAGE) {
            val imageBitmap = data?.extras?.get("data") as Bitmap
            val imageUri = saveImageToGallery(imageBitmap) // Save the captured image to the gallery and get its Uri
            imageUriList.add(imageUri)
            showSelectedImages()
        }
    }

    private fun saveImageToGallery(bitmap: Bitmap): Uri {
        val imagesDir = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES)
        val imageFile = File(imagesDir, "${System.currentTimeMillis()}.jpg")
        FileOutputStream(imageFile).use { outputStream ->
            bitmap.compress(Bitmap.CompressFormat.JPEG, 100, outputStream)
        }
        // Update the gallery so that the newly captured image is visible
        MediaScannerConnection.scanFile(requireActivity(), arrayOf(imageFile.absolutePath), arrayOf("image/jpeg"), null)
        return Uri.fromFile(imageFile)
    }

    private fun showSelectedImages() {
        binding?.apply {
            oneImageFrameUpcoming.visibility = View.GONE
            multiImageUpcoming.visibility = View.VISIBLE
            multiImageUpcoming.layoutManager = LinearLayoutManager(requireContext(), LinearLayoutManager.HORIZONTAL, false)
            adapter = CarImageAdapter(imageUriList) { clickedPosition ->
                adapter.removeImage(clickedPosition)
                adapter.notifyDataSetChanged()
            }
            multiImageUpcoming.adapter = adapter
            adapter.notifyDataSetChanged()
        }
    }

    private fun uploadVehicle() {
        val token = sharedPreference.getData("token").toString()
        val user_id = sharedPreference.getData("user_id").toString()

        val type = "service".toRequestBody("text/plain".toMediaTypeOrNull())
        val user_idValue = user_id.toRequestBody("text/plain".toMediaTypeOrNull())
        val idRequestBody = vehicleId.toString().toRequestBody("text/plain".toMediaTypeOrNull())

        val imageParts = mutableListOf<MultipartBody.Part>()
        for (uri in imageUriList) {
            val fileName = getRealPathFromUri(requireContext(), uri)
            Log.e("fileanmwe",fileName.toString())
            if (fileName != null) {
                val file = File(requireContext().cacheDir, File(fileName).name)
                requireContext().contentResolver.openInputStream(uri)?.use { inputStream ->
                    file.outputStream().use { outputStream ->
                        inputStream.copyTo(outputStream)
                    }
                }
                val requestFile = file.asRequestBody("image/*".toMediaTypeOrNull())
                val imagePart = MultipartBody.Part.createFormData("image[]", fileName, requestFile)
                imageParts.add(imagePart)
            }
        }

        val vehicleCall = RetrofitClient.apiService.uploadServiceImage(
            "Bearer $token",
            type,user_idValue,
            idRequestBody,
            imageParts
        )

        vehicleCall.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDialog.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(requireContext(), apiResponse.message.toString(), Color.parseColor("#ca9730"))
                        Handler(Looper.getMainLooper()).postDelayed({
                           startActivity(Intent(requireActivity(),MainActivity::class.java))
                           // activity?.finishAffinity()
                        }, 2000)
                    } else {
                        SnackBarUtils.showTopSnackbar(requireContext(), apiResponse?.message.toString(), Color.RED)
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(requireContext(), errorMessage.toString(), Color.RED)
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(requireContext(), e.message.toString(), Color.RED)
                    }
                }
            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDialog.dismiss()
                SnackBarUtils.showTopSnackbar(requireContext(), t.message.toString(), Color.RED)
            }
        })
    }


    private fun chooseDialog() {

        // val mainActivity = AppManager.instance.getMainActivity()

        val dialog = activity?.let { Dialog(it) }
        dialog?.setContentView(R.layout.choose_dialog)
        dialog?.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(true)
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))

        val gallery = dialog.findViewById<TextView>(R.id.gallery)
        val camera = dialog.findViewById<TextView>(R.id.camera)


        gallery.setOnClickListener {
            openGalleryForImages()
            dialog.dismiss()
        }

        camera.setOnClickListener {
            val captureIntent = Intent(MediaStore.ACTION_IMAGE_CAPTURE)

            // Check if there is a camera activity available to handle the intent
            if (captureIntent.resolveActivity(requireActivity().packageManager) != null) {
                // Start the camera activity
                startActivityForResult(captureIntent, REQUEST_CAMERA_PICK_IMAGE)
                dialog.dismiss()
            } else {
                // Handle the case where no camera activity is available
                Toast.makeText(requireActivity(), "No camera app found", Toast.LENGTH_SHORT).show()
                dialog.dismiss()
            }
        }

        dialog.show()
    }

}
