package codeflies.com.mcc.Fragment

import android.app.Dialog
import android.content.Intent
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Activity.LoginActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Activity.ReminderActivity
import codeflies.com.mcc.Adapter.CustomLanguageAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentSettingBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import com.skydoves.elasticviews.ElasticButton
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class SettingFragment : Fragment() {

    private var binding: FragmentSettingBinding? = null
    val items = listOf("Language", "English")
    val distance = listOf("Distance Metric", "Km", "Mileage")
    val currency = listOf("Currency", "AUD")

    private lateinit var progressDisplay: ProgressDisplay

    var value = false
    var sharedPreference: SharedPreference? = null

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentSettingBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            sharedPreference = context?.let { SharedPreference(it) }
            progressDisplay = context?.let { ProgressDisplay(it) }!!

            MainActivity.status = true



            binding!!.dayNightSwitch.setOnCheckedChangeListener { buttonView, isChecked ->

                if (isChecked) {
                    // Switch is ON
                    // Perform actions for ON state (e.g., enable dark mode)
                    value = true
                    Log.e("Main_value", value.toString())
                    sharedPreference?.saveModeValues("mode", value)
                    activity?.finishAffinity()
                    startActivity(Intent(context, MainActivity::class.java))
                    // Toast.makeText(Dashboard.this, "ON", Toast.LENGTH_SHORT).show();
                } else {
                    // Switch is OFF
                    // Perform actions for OFF state (e.g., disable dark mode)
                    // showToast("Dark mode disabled");
                    value = false
                    // sharedPreference.saveData("modeButton",String.valueOf(count));
                    Log.e("Main_value", value.toString())
                    sharedPreference?.saveModeValues("mode", value)
                    activity?.finishAffinity()
                    startActivity(Intent(context, MainActivity::class.java))
                    // Toast.makeText(Dashboard.this, "OFF", Toast.LENGTH_SHORT).show();
                }
            }
            val adapter = CustomLanguageAdapter(requireActivity(), items)
            binding!!.languageSpinner.adapter = adapter
            val distanceAdapter = CustomLanguageAdapter(requireActivity(), distance)
            binding!!.distanceSpinner.adapter = distanceAdapter
            val currencyAdapter = CustomLanguageAdapter(requireActivity(), currency)
            binding!!.currencySpinner.adapter = currencyAdapter

            binding!!.changeSetting.setOnClickListener {
                startActivity(Intent(context, CommonActivity::class.java))
                CommonActivity.replaceFragment = ChangePasswordFragment()
                CommonActivity.titleTop = getString(R.string.change_password)
            }
            binding!!.deleteSetting.setOnClickListener {
                startActivity(Intent(context, CommonActivity::class.java))
                CommonActivity.replaceFragment = DeleteFragment()
                CommonActivity.titleTop = getString(R.string.delete_my_account)
            }

            binding!!.logoutSetting.setOnClickListener {
                logoutApp()
            }

            binding!!.calendarReminder.setOnClickListener {
                startActivity(Intent(requireActivity(), ReminderActivity::class.java))
            }
        }

    }

    private fun logoutApp() {
        val dialog = Dialog(requireContext())
        dialog.setContentView(R.layout.logout_layout)
        dialog.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(true)
        dialog.window!!.attributes.windowAnimations = R.style.animation
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        val yes = dialog.findViewById<ElasticButton>(R.id.yes)
        val no = dialog.findViewById<ElasticButton>(R.id.no)
        val title = dialog.findViewById<TextView>(R.id.title)
        val desc = dialog.findViewById<TextView>(R.id.desc)

        yes.text = "Logout"
        no.text = "Cancel"
        title.text = "Logout"
        desc.text = "Are you sure to want logout from MYCC?"
        yes.setOnClickListener {
            logoutMethod()
            dialog.dismiss()
        }
        no.setOnClickListener { dialog.dismiss() }
        dialog.show()
    }

    private fun logoutMethod() {
        progressDisplay.show()
        val authorizationToken = "Bearer " + sharedPreference?.getData("token")
        val userId = "" + sharedPreference?.getData("user_id")

        val callLogout = RetrofitClient.apiService.logout(authorizationToken, userId)

        callLogout.enqueue(object : Callback<CommonModel> {
            override fun onResponse(call: Call<CommonModel>, response: Response<CommonModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status.equals("true")) {
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            apiResponse.message.toString(),
                            Color.parseColor("#ca9730")
                        )
                        sharedPreference?.saveModeValues("mode", false)
                        sharedPreference?.saveData("token", "")
                        sharedPreference?.saveData("user_id", "")
                        startActivity(Intent(requireActivity(), LoginActivity::class.java))
                        activity?.finishAffinity()


                    } else {
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            apiResponse?.message.toString(),
                            Color.RED
                        )
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            errorMessage.toString(),
                            Color.RED
                        )
                    } catch (e: Exception) {
                        SnackBarUtils.showTopSnackbar(
                            context!!,
                            e.message.toString().toString(),
                            Color.RED
                        )

                    }
                }

            }

            override fun onFailure(call: Call<CommonModel>, t: Throwable) {
                progressDisplay.dismiss()
                SnackBarUtils.showTopSnackbar(context!!, t.message.toString(), Color.RED)
            }
        })
    }


}