package codeflies.com.mcc.Fragment

import android.Manifest
import android.app.Activity
import android.app.Dialog
import android.content.Intent
import android.content.pm.PackageManager
import android.graphics.Bitmap
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.media.MediaScannerConnection
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.os.Environment
import android.provider.MediaStore
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Adapter.CarImageAdapter
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Helper.getRealPathFromUri
import codeflies.com.mcc.Model.VehicleModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentVehicleImageBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import com.skydoves.elasticviews.ElasticButton
import okhttp3.MediaType.Companion.toMediaTypeOrNull
import okhttp3.MultipartBody
import okhttp3.RequestBody.Companion.asRequestBody
import okhttp3.RequestBody.Companion.toRequestBody
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.io.File
import java.io.FileOutputStream


class VehicleImageFragment : Fragment() {

    private var binding: FragmentVehicleImageBinding? = null

    private lateinit var adapter: CarImageAdapter
    private var imageUriList = mutableListOf<Uri>()
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDialog: ProgressDisplay
    private var vehicleId: Int = 0
    private val REQUEST_CODE_PERMISSION = 123

    val REQUEST_CODE = 200
    val REQUEST_CODE_CAMERA = 199
    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentVehicleImageBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            vehicleId = arguments?.getInt("vehicleId", -1) ?: -1

            sharedPreference = context?.let { SharedPreference(it) }!!
            progressDialog = context?.let { ProgressDisplay(it) }!!



            binding!!.addVehicleUpdate.setOnClickListener {
                progressDialog.show()
                uploadVehicle()
            }

            binding!!.uploadImage.setOnClickListener {
                val permissionsToRequest = mutableListOf<String>()

                if (Build.VERSION.SDK_INT < Build.VERSION_CODES.TIRAMISU) {
                    if (context?.checkSelfPermission(Manifest.permission.READ_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
                        permissionsToRequest.add(Manifest.permission.READ_EXTERNAL_STORAGE)
                        requestPermissions(
                            permissionsToRequest.toTypedArray(),
                            REQUEST_CODE_PERMISSION
                        )
                    } else {
                        chooseDialog()
                    }
                } else {
                    if (context?.checkSelfPermission(Manifest.permission.READ_MEDIA_IMAGES) != PackageManager.PERMISSION_GRANTED) {
                        permissionsToRequest.add(Manifest.permission.READ_MEDIA_IMAGES)
                        requestPermissions(
                            permissionsToRequest.toTypedArray(),
                            REQUEST_CODE_PERMISSION
                        )
                    } else {
                        chooseDialog()
                    }
                }
            }
        }
    }

    override fun onRequestPermissionsResult(
        requestCode: Int,
        permissions: Array<out String>,
        grantResults: IntArray
    ) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
        if (requestCode == REQUEST_CODE_PERMISSION && grantResults.isNotEmpty() && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            // Permission granted, proceed with accessing images
            chooseDialog()
        } else {
            // Permission denied, handle accordingly (e.g., show a message to the user)
        }
    }




    private fun openGalleryForImages() {
        val validImageTypes = arrayOf("image/jpeg", "image/jpg", "image/png")

        if (Build.VERSION.SDK_INT < 19) {
            // For earlier versions
            val intent = Intent()
            intent.type = "image/*"
            intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
            intent.action = Intent.ACTION_GET_CONTENT
            startActivityForResult(Intent.createChooser(intent, "Choose Pictures"), REQUEST_CODE)
        } else {
            // For API LEVEL 19 and above
            val intent = Intent(Intent.ACTION_OPEN_DOCUMENT)
            intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
            intent.addCategory(Intent.CATEGORY_OPENABLE)

            // Set the MIME type filter
            intent.type = "image/*"
            intent.putExtra(Intent.EXTRA_MIME_TYPES, validImageTypes)

            startActivityForResult(intent, REQUEST_CODE)
        }

    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)

        if (resultCode == Activity.RESULT_OK && requestCode == REQUEST_CODE) {

            // if multiple images are selected
            if (data?.clipData != null) {
                val count = data.clipData!!.itemCount

                for (i in 0 until count) {
                    val imageUri: Uri = data.clipData!!.getItemAt(i).uri
                    //     val filePath = getPathFromUri(imageUri)
                    // Log.e("filePath","filePath = "+filePath)
                    // Now 'filePath' contains the file path corresponding to the Uri
                    imageUriList.add(imageUri)
                    // iv_image.setImageURI(imageUri) Here you can assign your Image URI to the ImageViews
                }

                binding!!.oneImageFrame.visibility = View.GONE
                binding!!.multiImage.visibility = View.VISIBLE

                binding!!.multiImage.layoutManager =
                    LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
                adapter = CarImageAdapter(imageUriList) { clickedPosition ->
                    // Handle the delete button click event (remove the image at the clicked position)
                    adapter.removeImage(clickedPosition)
                    adapter.notifyDataSetChanged()
                }
                binding!!.multiImage.adapter = adapter
                adapter.notifyDataSetChanged()

            } else if (data?.data != null) {
                // if a single image is selected

                val imageUri: Uri = data.data!!
                // val filePath = getPathFromUri(imageUri)
                // Now 'filePath' contains the file path corresponding to the Uri
                imageUriList.add(imageUri)

                binding!!.oneImageFrame.visibility = View.GONE
                binding!!.multiImage.visibility = View.VISIBLE

                binding!!.multiImage.layoutManager =
                    LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
                adapter = CarImageAdapter(imageUriList) { clickedPosition ->
                    // Handle the delete button click event (remove the image at the clicked position)
                    adapter.removeImage(clickedPosition)
                    adapter.notifyDataSetChanged()
                }
                binding!!.multiImage.adapter = adapter
                adapter.notifyDataSetChanged()
                // iv_image.setImageURI(imageUri) Here you can assign the picked image uri to your imageview
            }
        } else if (resultCode == Activity.RESULT_OK && requestCode == REQUEST_CODE_CAMERA) {
            val imageBitmap = data?.extras?.get("data") as Bitmap
            val imageUri =
                saveImageToGallery(imageBitmap) // Save the captured image to the gallery and get its Uri
            imageUriList.add(imageUri)
        }
        binding!!.oneImageFrame.visibility = View.GONE
        binding!!.multiImage.visibility = View.VISIBLE

        binding!!.multiImage.layoutManager =
            LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
        adapter = CarImageAdapter(imageUriList) { clickedPosition ->
            // Handle the delete button click event (remove the image at the clicked position)
            adapter.removeImage(clickedPosition)
            adapter.notifyDataSetChanged()
        }
        binding!!.multiImage.adapter = adapter
        adapter.notifyDataSetChanged()
    }

    private fun saveImageToGallery(bitmap: Bitmap): Uri {
        val imagesDir =
            Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES)
        val imageFile = File(imagesDir, "${System.currentTimeMillis()}.jpg")
        FileOutputStream(imageFile).use { outputStream ->
            bitmap.compress(Bitmap.CompressFormat.JPEG, 100, outputStream)
        }
        // Update the gallery so that the newly captured image is visible
        MediaScannerConnection.scanFile(
            requireActivity(),
            arrayOf(imageFile.absolutePath),
            arrayOf("image/jpeg"),
            null
        )
        return Uri.fromFile(imageFile)
    }



    private fun getFileNameFromUriWithoutPath(uri: Uri): String? {
        // Get the last segment of the URI's path, which should be the file name
        return uri.lastPathSegment
    }

    fun getFileNameWithoutExtension(uri: Uri): String? {
        val pathSegments = uri.pathSegments
        val lastSegment = pathSegments.lastOrNull()

        // Split the last segment based on ":"
        val splitSegments = lastSegment?.split(":")

        // Check if the split was successful and get the last part
        val fileNameWithoutExtension = splitSegments?.lastOrNull()

        return fileNameWithoutExtension
    }




    private fun VehicleUpload() {
        val dialog = context?.let { Dialog(it) }
        dialog?.setContentView(R.layout.payment_dialog)
        dialog?.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(false)
        dialog.window!!.attributes.windowAnimations = R.style.animation
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        val yes = dialog.findViewById<ElasticButton>(R.id.yes)
        val no = dialog.findViewById<TextView>(R.id.no)
        val title = dialog.findViewById<TextView>(R.id.title)
        val des = dialog.findViewById<TextView>(R.id.des)

        title.text = "Vehicle Uploaded!"
        des.text ="Congratulations! Your vehicle has been successfully added to the MYCC!"
//            "Your vehicle has been uploaded successfully, once approved by admin you will be able to see your vehicle"
        yes.setOnClickListener {
            dialog.dismiss()
            startActivity(Intent(context, MainActivity::class.java))
            activity?.finishAffinity()
        }
        no.setOnClickListener { dialog.dismiss() }
        dialog.show()
    }


    private fun chooseDialog() {

        // val mainActivity = AppManager.instance.getMainActivity()

        val dialog = activity?.let { Dialog(it) }
        dialog?.setContentView(R.layout.choose_dialog)
        dialog?.window!!.setLayout(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        )
        dialog.setCancelable(true)
        dialog.window!!.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))

        val gallery = dialog.findViewById<TextView>(R.id.gallery)
        val camera = dialog.findViewById<TextView>(R.id.camera)


        gallery.setOnClickListener {
            openGalleryForImages()
            dialog.dismiss()
        }

        camera.setOnClickListener {
            val captureIntent = Intent(MediaStore.ACTION_IMAGE_CAPTURE)

            // Check if there is a camera activity available to handle the intent
            if (captureIntent.resolveActivity(requireActivity().packageManager) != null) {
                // Start the camera activity
                startActivityForResult(captureIntent, REQUEST_CODE_CAMERA)
                dialog.dismiss()
            } else {
                // Handle the case where no camera activity is available
                Toast.makeText(requireActivity(), "No camera app found", Toast.LENGTH_SHORT).show()
                dialog.dismiss()
            }
        }

        dialog.show()
    }


    private fun uploadVehicle() {
        val token = sharedPreference.getData("token").toString()
        val user_id = sharedPreference.getData("user_id").toString()

        // Create a RequestBody for form_step and id
        val formStepRequestBody = "3"
            .toRequestBody("text/plain".toMediaTypeOrNull())
        val idRequestBody =
            vehicleId.toString().toRequestBody("text/plain".toMediaTypeOrNull())

        // Create a list of MultipartBody.Part for images
        val imageParts = prepareImageParts()

        if (imageParts.isNotEmpty()) {
            progressDialog.show()

            // Make the API call
            val vehicleCall = RetrofitClient.apiService.uploadVehicleImage(
                "Bearer $token",
                formStepRequestBody,
                idRequestBody,
                imageParts
            )

            vehicleCall.enqueue(object : Callback<VehicleModel> {
                override fun onResponse(call: Call<VehicleModel>, response: Response<VehicleModel>) {
                    progressDialog.dismiss()
                    if (response.isSuccessful) {
                        val apiResponse = response.body()
                        if (apiResponse != null && apiResponse.status) {
                            VehicleUpload()
                        } else {
                            handleErrorResponse(apiResponse?.message.toString())
                        }
                    } else {
                        handleErrorResponse(getErrorMessage(response.errorBody()?.string()))
                    }
                }

                override fun onFailure(call: Call<VehicleModel>, t: Throwable) {
                    progressDialog.dismiss()
                    handleErrorResponse(t.message.toString())
                }
            })
        } else {
            // Handle case where no valid image parts are available
            progressDialog.dismiss()
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "No images selected or captured",
                    Color.RED
                )
            }

        }
    }

    private fun prepareImageParts(): List<MultipartBody.Part> {
        val imageParts = mutableListOf<MultipartBody.Part>()

        for (uri in imageUriList) {
            val fileName = getFileNameFromUriWithoutPath(uri)
            val filePath = getRealPathFromUri(requireContext(), uri)

            if (!fileName.isNullOrEmpty() && !filePath.isNullOrEmpty()) {
                val file = File(filePath)
                if (file.exists()) {
                    val requestFile = file.asRequestBody("image/*".toMediaTypeOrNull())
                    val imagePart = MultipartBody.Part.createFormData("image[]", fileName, requestFile)
                    imageParts.add(imagePart)
                } else {
                    Log.e("FileNotFound", "File not found for URI: $uri")
                    // Optionally notify the user or handle the error
                }
            } else {
                Log.e("FileNameOrPathNull", "File name or path is null for URI: $uri")
                // Optionally notify the user or handle the error
            }
        }
        return imageParts
    }

    private fun handleErrorResponse(errorMessage: String) {
        context?.let {
            SnackBarUtils.showTopSnackbar(
                it,
                errorMessage,
                Color.RED
            )
        }
    }

    private fun getErrorMessage(errorResponse: String?): String {
        val gson = Gson()
        try {
            val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
            return errorJson.get("message").asString
        } catch (e: Exception) {
            return e.message.toString()
        }
    }

}

