package codeflies.com.mcc.Fragment

import android.Manifest
import android.app.DatePickerDialog
import android.content.ContentResolver
import android.content.ContentValues
import android.content.Intent
import android.content.pm.PackageManager
import android.graphics.Color
import android.os.Build
import android.os.Bundle
import android.provider.CalendarContract
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Helper.ProgressDisplay
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.SharedPreference
import codeflies.com.mcc.Helper.SnackBarUtils
import codeflies.com.mcc.Model.VehicleModel
import codeflies.com.mcc.R
import codeflies.com.mcc.databinding.FragmentVehicleSecondStepBinding
import com.google.gson.Gson
import com.google.gson.JsonObject
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.text.SimpleDateFormat
import java.util.Calendar
import java.util.Locale
import java.util.TimeZone


class VehicleSecondStepFragment : Fragment() {

    private var binding: FragmentVehicleSecondStepBinding? = null
    private lateinit var selectedDate: String

    private var vehicleId: Int = 0
    private var dateValue: Int = 0
    private lateinit var sharedPreference: SharedPreference
    private lateinit var progressDisplay: ProgressDisplay

    private val REQUEST_CODE_PERMISSION = 123


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        // Inflate the layout for this fragment
        binding = FragmentVehicleSecondStepBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (isAdded) {
            vehicleId = arguments?.getInt("vehicleId", -1) ?: -1

            progressDisplay = context?.let { ProgressDisplay(it) }!!
            sharedPreference = context?.let { SharedPreference(it) }!!

            binding!!.addVehicleUpdate.setOnClickListener {
                if (validation()) {
                    progressDisplay.show()
                    uploadVehicle()
                }
//                replaceFrame(1)
            }

            binding!!.plateExpireTxt.setOnClickListener {
                dateValue = 1
                showDatePicker()
            }
            binding!!.vinExpireTxt.setOnClickListener {
                dateValue = 2
                showDatePicker()
            }
            binding!!.memberExpireTxt.setOnClickListener {
                dateValue = 3
                showDatePicker()
            }
            binding!!.policyExpireTxt.setOnClickListener {
                dateValue = 4
                showDatePicker()
            }

            requestCalendarPermissions()
        }
    }

    private fun validation(): Boolean {
        if (binding!!.plateTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Enter Plate Number!",
                    Color.RED
                )
            }
            binding!!.plateTxt.requestFocus()
            return false
        } else if (binding!!.plateExpireTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Select Plate Expire Date!",
                    Color.RED
                )
            }
            binding!!.plateExpireTxt.requestFocus()
            return false
        } else if (binding!!.vinTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Enter VIN Number!",
                    Color.RED
                )
            }
            binding!!.vinTxt.requestFocus()
            return false
        } else if (binding!!.memberExpireTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Select Membership Expire Date!",
                    Color.RED
                )
            }
            binding!!.memberExpireTxt.requestFocus()
            return false
        } else if (binding!!.policyTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Enter Policy Number!",
                    Color.RED
                )
            }
            binding!!.policyTxt.requestFocus()
            return false
        } else if (binding!!.policyExpireTxt.text?.length == 0) {
            context?.let {
                SnackBarUtils.showTopSnackbar(
                    it,
                    "Please Select Policy Expire Date!",
                    Color.RED
                )
            }
            binding!!.policyExpireTxt.requestFocus()
            return false
        }
        return true
    }

    private fun replaceFrame(vehicleId: Int) {
        // Create a new instance of the next fragment
        val nextFragment = VehicleImageFragment()

        // Pass the id value to the next fragment using arguments
        val bundle = Bundle()
        bundle.putInt("vehicleId", vehicleId)
        nextFragment.arguments = bundle

        // Replace the current fragment with the next fragment

        CommonActivity.replaceFragment = nextFragment
        CommonActivity.titleTop = getString(R.string.add_vehicle)
        startActivity(Intent(context, CommonActivity::class.java))
    }


    private fun showDatePicker() {
        val calendar = Calendar.getInstance()
        val year = calendar.get(Calendar.YEAR)
        val month = calendar.get(Calendar.MONTH)
        val day = calendar.get(Calendar.DAY_OF_MONTH)

        val datePickerDialog = context?.let {
            DatePickerDialog(
                it,
                DatePickerDialog.OnDateSetListener { _, selectedYear, selectedMonth, selectedDay ->
                    // Handle the selected date
                    onDateSet(selectedYear, selectedMonth, selectedDay)
                },
                year,
                month,
                day
            )
        }
        //  datePickerDialog.datePicker.minDate = System.currentTimeMillis() - 1000

        datePickerDialog?.show()
    }

    private fun onDateSet(selectedYear: Int, selectedMonth: Int, selectedDay: Int) {
        val formattedMonth = selectedMonth + 1
        val formattedDate = "$selectedYear-$formattedMonth-$selectedDay"
        selectedDate = "$selectedYear-$formattedMonth-$selectedDay"
        if (dateValue == 1) {
            binding!!.plateExpireTxt.setText(formattedDate)
            if (::selectedDate.isInitialized) {
                if (sharedPreference.getData("car_status").equals("1")){
                    addReminderToCalendar(
                        "Reminder",
                        "Don't forget your reg. number expired today!",
                        selectedDate
                    )

                }
            } else {
                Toast.makeText(context, "Please select a date first", Toast.LENGTH_SHORT)
                    .show()
            }
        } else if (dateValue == 2) {
            binding!!.vinExpireTxt.setText(formattedDate)
            if (::selectedDate.isInitialized) {
                addReminderToCalendar(
                    "Reminder",
                    "Don't forget your vin number expired today!",
                    selectedDate
                )
            } else {
                Toast.makeText(context, "Please select a date first", Toast.LENGTH_SHORT)
                    .show()
            }
        } else if (dateValue == 3) {
            binding!!.memberExpireTxt.setText(formattedDate)
            if (::selectedDate.isInitialized) {
                if (sharedPreference.getData("member_status").equals("1")){
                    addReminderToCalendar(
                        "Reminder",
                        "Don't forget your membership expired today!",
                        selectedDate
                    )

                }
            } else {
                Toast.makeText(context, "Please select a date first", Toast.LENGTH_SHORT)
                    .show()
            }

        } else if (dateValue == 4) {
            binding!!.policyExpireTxt.setText(formattedDate)
            if (::selectedDate.isInitialized) {
                if (sharedPreference.getData("policy_status").equals("1")){
                    addReminderToCalendar(
                        "Reminder",
                        "Don't forget your policy expired today!",
                        selectedDate
                    )

                }
            } else {
                Toast.makeText(context, "Please select a date first", Toast.LENGTH_SHORT)
                    .show()
            }

        }
    }

    private fun uploadVehicle() {
        var token = sharedPreference.getData("token").toString()
        var user_id = sharedPreference.getData("user_id").toString()

        val vehicleCall = RetrofitClient.apiService.uploadVehicleSecond(
            "Bearer $token",
            "2",
            vehicleId.toString(),
            binding!!.plateTxt.text.toString(),
            binding!!.plateExpireTxt.text.toString(),
            binding!!.vinTxt.text.toString(),
            binding!!.memberTxt.text.toString(),
            binding!!.memberExpireTxt.text.toString(),
            binding!!.policyTxt.text.toString(),
            binding!!.policyExpireTxt.text.toString()
        )

        vehicleCall.enqueue(object : Callback<VehicleModel> {
            override fun onResponse(call: Call<VehicleModel>, response: Response<VehicleModel>) {
                progressDisplay.dismiss()
                if (response.isSuccessful) {
                    val apiResponse = response.body()
                    if (apiResponse != null && apiResponse.status) {
                        replaceFrame(apiResponse.data[0].id)
                    } else {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                apiResponse?.message.toString(),
                                Color.RED
                            )
                        }
                    }
                } else {
                    val errorResponse = response.errorBody()?.string()
                    val gson = Gson()
                    try {
                        val errorJson = gson.fromJson(errorResponse, JsonObject::class.java)
                        val errorMessage = errorJson.get("message").asString
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                errorMessage.toString(),
                                Color.RED
                            )
                        }
                    } catch (e: Exception) {
                        context?.let {
                            SnackBarUtils.showTopSnackbar(
                                it,
                                e.message.toString(),
                                Color.RED
                            )
                        }
                    }
                }

            }

            override fun onFailure(call: Call<VehicleModel>, t: Throwable) {
                progressDisplay.dismiss()
                context?.let { SnackBarUtils.showTopSnackbar(it, t.message.toString(), Color.RED) }
            }

        })
    }

    private fun addReminderToCalendar(title: String, description: String, selectedDate: String) {
        val cr: ContentResolver = context?.contentResolver!!
        val selectedDateTime =
            SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()).parse(selectedDate)?.time ?: return

        val values = ContentValues().apply {
            put(CalendarContract.Events.TITLE, title)
            put(CalendarContract.Events.DESCRIPTION, description)
            put(CalendarContract.Events.DTSTART, selectedDateTime)
            put(
                CalendarContract.Events.DTEND,
                selectedDateTime + (60 * 60 * 1000)
            ) // 1 hour duration
            put(CalendarContract.Events.CALENDAR_ID, 1) // Use 1 as default calendar
            put(CalendarContract.Events.EVENT_TIMEZONE, TimeZone.getDefault().id)
            put(CalendarContract.Events.HAS_ALARM, 1) // 1 for true, 0 for false
            put(CalendarContract.Events.CUSTOM_APP_URI, selectedDate) // Store selected date
        }

        val uri = cr.insert(CalendarContract.Events.CONTENT_URI, values)
        val eventId = uri?.lastPathSegment?.toLongOrNull()

        if (eventId != null) {
            // Add a reminder for the event
            val reminderValues = ContentValues().apply {
                put(CalendarContract.Reminders.EVENT_ID, eventId)
                put(CalendarContract.Reminders.METHOD, CalendarContract.Reminders.METHOD_ALERT)
                put(CalendarContract.Reminders.MINUTES, 15) // 15 minutes before the event
            }
            cr.insert(CalendarContract.Reminders.CONTENT_URI, reminderValues)

        } else {
//            Toast.makeText(context, "Failed to add reminder", Toast.LENGTH_SHORT).show()
        }
    }


    private fun requestCalendarPermissions() {
        val permissionsToRequest = mutableListOf<String>()

        // Check if the device is running Android 6.0 (API level 23) or higher
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            // Check if the app has permission to read the calendar
            if (ContextCompat.checkSelfPermission(
                    requireContext(),
                    Manifest.permission.READ_CALENDAR
                ) != PackageManager.PERMISSION_GRANTED
            ) {
                // Permission is not granted, request the permission
                permissionsToRequest.add(Manifest.permission.READ_CALENDAR)
            }
            // Check if the app has permission to write to the calendar
            if (ContextCompat.checkSelfPermission(
                    requireContext(),
                    Manifest.permission.WRITE_CALENDAR
                ) != PackageManager.PERMISSION_GRANTED
            ) {
                // Permission is not granted, request the permission
                permissionsToRequest.add(Manifest.permission.WRITE_CALENDAR)
            }
        }

        // Request permissions if there are any
        if (permissionsToRequest.isNotEmpty()) {
            requestPermissions(
                permissionsToRequest.toTypedArray(),
                REQUEST_CODE_PERMISSION
            )
        } else {
            // Permissions are already granted, perform your calendar-related tasks here
            // For example, add an event to the calendar
            // addEventToCalendar()
        }
    }

    override fun onRequestPermissionsResult(
        requestCode: Int,
        permissions: Array<out String>,
        grantResults: IntArray
    ) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
        if (requestCode == REQUEST_CODE_PERMISSION) {
            // Check if all required permissions have been granted
            if (grantResults.all { it == PackageManager.PERMISSION_GRANTED }) {
                // All permissions have been granted, perform your calendar-related tasks here
                // For example, add an event to the calendar
//                addEventToCalendar()
            } else {
                // Permission denied, handle this case accordingly
                // For example, show an explanation or disable calendar-related functionality
                Toast.makeText(
                    requireContext(),
                    "Calendar permissions are required to perform this action.",
                    Toast.LENGTH_SHORT
                ).show()
            }
        }
    }

}