package codeflies.com.mcc.Helper

import codeflies.com.mcc.Model.BrandModel
import codeflies.com.mcc.Model.BrandModelData
import codeflies.com.mcc.Model.CarListModel
import codeflies.com.mcc.Model.CityModel
import codeflies.com.mcc.Model.CommonModel
import codeflies.com.mcc.Model.CountryModel
import codeflies.com.mcc.Model.CustomerModel
import codeflies.com.mcc.Model.DistanceTypeModel
import codeflies.com.mcc.Model.ExportResponse
import codeflies.com.mcc.Model.FuelModelData
import codeflies.com.mcc.Model.NotificationModel
import codeflies.com.mcc.Model.PDFResponse
import codeflies.com.mcc.Model.PaymentModel
import codeflies.com.mcc.Model.PlanModel
import codeflies.com.mcc.Model.PriceModel
import codeflies.com.mcc.Model.RatingModel
import codeflies.com.mcc.Model.ResponseDigiDocs
import codeflies.com.mcc.Model.ServiceDetailsResponse
import codeflies.com.mcc.Model.ServiceListResponse
import codeflies.com.mcc.Model.ServiceModel
import codeflies.com.mcc.Model.ServicesModel
import codeflies.com.mcc.Model.SignUpModel
import codeflies.com.mcc.Model.SubscribersUser
import codeflies.com.mcc.Model.TermsModel
import codeflies.com.mcc.Model.UpcomingRepairsResponse
import codeflies.com.mcc.Model.VariantModel
import codeflies.com.mcc.Model.VehicleDetailsModel
import codeflies.com.mcc.Model.VehicleModel
import okhttp3.MultipartBody
import okhttp3.RequestBody
import retrofit2.Call
import retrofit2.http.Field
import retrofit2.http.FormUrlEncoded
import retrofit2.http.GET
import retrofit2.http.Header
import retrofit2.http.Headers
import retrofit2.http.Multipart
import retrofit2.http.POST
import retrofit2.http.Part
import retrofit2.http.Path
import retrofit2.http.Query

interface ApiService {

    @FormUrlEncoded
    @POST("api/v1/user/register")
    fun signUp(
        @Field("first_name") first_name: String,
        @Field("last_name") last_name: String,
        @Field("email") email: String,
        @Field("password") password: String,
        @Field("password_confirmation") password_confirmation: String,
        @Field("fcm_token") fcm_token: String,
        @Field("latitude") latitude: String,
        @Field("longitude") longitude: String,
        @Field("device_type") type: String
    ): Call<SignUpModel>


    @FormUrlEncoded
    @POST("api/v1/user/login")
    fun login(
        @Field("email") email: String,
        @Field("password") password: String,
        @Field("fcm_token") fcm_token: String,
        @Field("login_type") login_type: String,
        @Field("device_type") type: String,
    ): Call<SignUpModel>

    @FormUrlEncoded
    @POST("api/v1/user/login")
    fun googleLogin(
        @Field("google_id") google_id: String,
        @Field("google_token") google_token: String,
        @Field("first_name") first_name: String,
        @Field("last_name") last_name: String,
        @Field("email") email: String,
        @Field("fcm_token") fcm_token: String,
        @Field("login_type") login_type: String,
        @Field("device_type") type: String,
    ): Call<SignUpModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/user/logout")
    fun logout(
        @Header("Authorization") authorization: String,
        @Field("user_id") userId: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/vehicle/update")
    fun policyUpdate(
        @Header("Authorization") authorization: String,
        @Field("vehicle_id") vehicle_id: String,
        @Field("policy_expiry_date") policy_expiry_date: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/vehicle/update")
    fun memberUpdate(
        @Header("Authorization") authorization: String,
        @Field("vehicle_id") vehicle_id: String,
        @Field("membership_expiry_date") policy_expiry_date: String
    ): Call<CommonModel>
 @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/vehicle/update")
    fun regUpdate(
        @Header("Authorization") authorization: String,
        @Field("vehicle_id") vehicle_id: String,
        @Field("reg_expiry_date") reg_expiry_date: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/user/reset/password")
    fun resetPassword(
        @Header("Authorization") authorization: String,
        @Field("user_id") userId: String,
        @Field("old_password") old_password: String,
        @Field("password") password: String,
        @Field("password_confirmation") password_confirmation: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/user/update-forgot-password")
    fun forgotPassword(
        @Field("email") email: String,
        @Field("token") token: String,
        @Field("password") password: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/user/profile/update")
    fun updateProfile(
        @Header("Authorization") authorization: String,
        @Field("user_id") userId: String,
        @Field("first_name") first_name: String,
        @Field("last_name") last_name: String,
        @Field("country_id") country: String,
        @Field("city_id") city: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/user/delete")
    fun deleteProfile(
        @Header("Authorization") authorization: String,
        @Field("user_id") userId: String,
        @Field("reason") reason: String
    ): Call<CommonModel>


    @Headers("Accept: application/json")
    @GET("api/v1/user/{userId}")
    fun userData(
        @Header("Authorization") authorization: String,
        @Path("userId") userId: Int
    ): Call<SignUpModel>


    @FormUrlEncoded
    @POST("api/v1/user/forgot/password")
    fun forgot(
        @Field("email") email: String
    ): Call<CommonModel>


    @GET("api/v1/page")
    fun terms(@Query("type") type: String)
            : Call<TermsModel>


    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/user/contact")
    fun contactUs(
        @Header("Authorization") authorization: String,
        @Field("user_id") userId: String,
        @Field("message") reason: String,
        @Field("mobile") mobile: String
    ): Call<CommonModel>


    @Headers("Accept: application/json")
    @GET("api/v1/location/countries")
    fun countryGet(
        @Header("Authorization") authorization: String
    ): Call<CountryModel>


    @Headers("Accept: application/json")
    @GET("api/v1/location/cities/{country_id}")
    fun cityData(
        @Header("Authorization") authorization: String,
        @Path("country_id") country_id: Int
    ): Call<CityModel>


    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/service/store")
    fun uploadServices(
        @Header("Authorization") Authorization: String,
        @Field("user_id") user_id: String,
        @Field("name") name: String,
        @Field("description") description: String,
        @Field("country_id") country_id: String,
        @Field("city_id") city_id: String,
        @Field("address") address: String,
        @Field("latitude") latitude: String,
        @Field("longitude") longitude: String
    ): Call<CommonModel>


    @Headers("Accept: application/json")
    @GET("api/v1/service/all")
    fun servicesData(
        @Header("Authorization") authorization: String
    ): Call<ServicesModel>

    @Headers("Accept: application/json")
    @GET("api/v1/service/singleService/{service_id}")
    fun getServicesData(
        @Header("Authorization") authorization: String,
        @Path("service_id") service_id: String
    ): Call<ServicesModel>

    @Headers("Accept: application/json")
    @GET("api/v1/service/ratings")
    fun getRatingData(
        @Header("Authorization") authorization: String
    ): Call<RatingModel>

    @Headers("Accept: application/json")
    @GET("api/v1/service/prices")
    fun getPriceData(
        @Header("Authorization") authorization: String
    ): Call<PriceModel>


    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/service/review")
    fun uploadReview(
        @Header("Authorization") Authorization: String,
        @Field("user_id") user_id: String,
        @Field("content") content: String,
        @Field("service_id") service_id: String,
        @Field("service_rating_id") service_rating_id: String,
        @Field("service_price_id") service_price_id: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/vehicle/service/store")
    fun uploadService(
        @Header("Authorization") Authorization: String,
        @Field("vehicle_id") vehicle_id: String,
        @Field("performed_date") performed_date: String,
        @Field("performed_at") performed_at: String,
        @Field("performed_distance_type_id") performed_distance_type_id: String,
        @Field("service_type_id") service_type_id: String,
        @Field("next_service_at") next_service_at: String,
        @Field("next_service_date") next_service_date: String,
        @Field("next_service_distance_type_id") next_service_distance_type_id: String,
        @Field("center_name") center_name: String,
        @Field("user_id") user_id: String
    ): Call<ServiceModel>
    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/vehicle/service/update")
    fun updateService(
        @Header("Authorization") Authorization: String,
        @Field("vehicle_id") vehicle_id: String,
        @Field("performed_date") performed_date: String,
        @Field("performed_at") performed_at: String,
        @Field("performed_distance_type_id") performed_distance_type_id: String,
        @Field("service_type_id") service_type_id: String,
        @Field("next_service_at") next_service_at: String,
        @Field("next_service_date") next_service_date: String,
        @Field("next_service_distance_type_id") next_service_distance_type_id: String,
        @Field("center_name") center_name: String,
        @Field("user_id") user_id: String,
        @Field("id") id: String
    ): Call<ServiceModel>

    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/vehicle/repair/store")
    fun uploadUpcomingRepairs(
        @Header("Authorization") Authorization: String,
        @Field("form_step") form_step: String,
        @Field("user_id") user_id: String,
        @Field("vehicle_id") vehicle_id: String,
        @Field("service_caption") service_caption: String,
        @Field("repair_center") repair_center: String,
        @Field("notes") note: String,
        @Field("repair_cost") repair_cost: String,
        @Field("repair_date") repair_date: String,
        @Field("mileage") mileage: String,
        @Field("distance_type_id") distance_type_id: String
    ): Call<VehicleModel>
    @Headers("Accept: application/json")
    @FormUrlEncoded
    @POST("api/v1/vehicle/repair/update")
    fun updateUpcomingRepairs(
        @Header("Authorization") Authorization: String,
        @Field("form_step") form_step: String,
        @Field("user_id") user_id: String,
        @Field("vehicle_id") vehicle_id: String,
        @Field("service_caption") service_caption: String,
        @Field("repair_center") repair_center: String,
        @Field("notes") note: String,
        @Field("repair_cost") repair_cost: String,
        @Field("repair_date") repair_date: String,
        @Field("mileage") mileage: String,
        @Field("distance_type_id") distance_type_id: String,
        @Field("id") id: String
    ): Call<VehicleModel>


    @Headers("Accept: application/json")
    @GET("api/v1/notifications/{user_id}")
    fun getNotificationData(
        @Header("Authorization") authorization: String,
        @Path("user_id") user_id: String
    ): Call<NotificationModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/report")
    fun getReportData(
        @Header("Authorization") authorization: String,
        @Query("user_id") user_id: String,
        @Query("vehicle_id") vehicle_id: String
    ): Call<ExportResponse>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/report-export")
    fun getPDFData(
        @Header("Authorization") authorization: String,
        @Query("user_id") user_id: String,
        @Query("vehicle_id") vehicle_id: String
    ): Call<PDFResponse>


    @Headers("Accept: application/json")
    @GET("api/v1/notifications/read/{notification_id}")
    fun getNotificationRead(
        @Header("Authorization") authorization: String,
        @Path("notification_id") notification_id: String
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/brands")
    fun brandGet(
        @Header("Authorization") authorization: String
    ): Call<BrandModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/models/{brand_id}")
    fun modelGet(
        @Header("Authorization") authorization: String,
        @Path("brand_id") brand_id: String
    ): Call<BrandModelData>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/fuels")
    fun fuelGet(
        @Header("Authorization") authorization: String
    ): Call<FuelModelData>


    @FormUrlEncoded
    @Headers("Accept: application/json")
    @POST("api/v1/vehicle/store")
    fun uploadVehicle(
        @Header("Authorization") authorization: String,
        @Field("form_step") form_step: String,
        @Field("user_id") user_id: String,
        @Field("vehicle_type_id") vehicle_type_id: String,
        @Field("name") name: String,
        @Field("brand_id") brand_id: String,
        @Field("vehicle_model_id") vehicle_model_id: String,
        @Field("vehicle_variant_id") varient: String,
        @Field("vehicle_engine_id") engine: String,
        @Field("vehicle_fuel_id") vehicle_fuel_id: String,
        @Field("vehicle_price") vehicle_price: String,
        @Field("purchase_date") purchase_date: String,
        @Field("brand_type") brand_type: String,
        @Field("model_type") model_type: String,
        @Field("variant_type") variant_type: String,
        @Field("engine_type") engine_type: String
    ): Call<VehicleModel>

    @FormUrlEncoded
    @Headers("Accept: application/json")
    @POST("api/v1/vehicle/store")
    fun uploadVehicleSecond(
        @Header("Authorization") authorization: String,
        @Field("form_step") form_step: String,
        @Field("id") id: String,
        @Field("reg_plate_number") reg_plate_number: String,
        @Field("reg_expiry_date") reg_expiry_date: String,
        @Field("vin_number") vin_number: String,
        @Field("membership_detail") membership_detail: String,
        @Field("membership_expiry_date") membership_expiry_date: String,
        @Field("policy_number") policy_number: String,
        @Field("policy_expiry_date") policy_expiry_date: String

    ): Call<VehicleModel>

    @Multipart
    @Headers("Accept: application/json")
    @POST("api/v1/vehicle/store")
    fun uploadVehicleImage(
        @Header("Authorization") authorization: String,
        @Part("form_step") formStep: RequestBody,
        @Part("id") id: RequestBody,
        @Part image: List<MultipartBody.Part>
    ): Call<VehicleModel>

    @Multipart
    @Headers("Accept: application/json")
    @POST("api/v1/vehicle/repair/store")
    fun uploadUpcomingImage(
        @Header("Authorization") authorization: String,
        @Part("form_step") formStep: RequestBody,
        @Part("id") id: RequestBody,
        @Part image: List<MultipartBody.Part>
    ): Call<VehicleModel>

    @Multipart
    @Headers("Accept: application/json")
    @POST("api/v1/vehicle/images/store")
    fun uploadServiceImage(
        @Header("Authorization") authorization: String,
        @Part("type") type: RequestBody,
        @Part("user_id") user_id: RequestBody,
        @Part("id") id: RequestBody,
        @Part image: List<MultipartBody.Part>
    ): Call<CommonModel>


    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/vehicles/{user_id}")
    fun getVehicleData(
        @Header("Authorization") authorization: String,
        @Path("user_id") user_id: String
    ): Call<VehicleDetailsModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/service/detail/{service_id}")
    fun getServiceData(
        @Header("Authorization") authorization: String,
        @Path("service_id") service_id: String
    ): Call<ServiceDetailsResponse>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/repair/list/{user_id}")
    fun getUpcomingList(
        @Header("Authorization") authorization: String,
        @Path("user_id") user_id: String
    ): Call<UpcomingRepairsResponse>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/repair/detail/{repair_id}")
    fun getRepairDetails(
        @Header("Authorization") authorization: String,
        @Path("repair_id") repair_id: String
    ): Call<UpcomingRepairsResponse>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/service/list/{user_id}")
    fun getServiceList(
        @Header("Authorization") authorization: String,
        @Path("user_id") user_id: String
    ): Call<ServiceListResponse>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/list/{user_id}")
    fun getCarListData(
        @Header("Authorization") authorization: String,
        @Path("user_id") user_id: String
    ): Call<CarListModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/service/types")
    fun getServiceTypeData(
        @Header("Authorization") authorization: String
    ): Call<CarListModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/show/{vehicleId}")
    fun getVehicleDetails(
        @Header("Authorization") authorization: String,
        @Path("vehicleId") vehicleId: String
    ): Call<VehicleDetailsModel>

    @Headers("Accept: application/json")
    @GET("api/v1/user-analytics")
    fun getUserAnalytics(): Call<SubscribersUser>


    @Multipart
    @Headers("Accept: application/json")
    @POST("api/v1/user/feedback")
    fun uploadFeedback(
        @Header("Authorization") authorization: String,
        @Part("user_id") user_id: RequestBody,
        @Part("message") message: RequestBody,
        @Part("type") type: RequestBody,
        @Part("feedbackable_id") feedbackable_id: RequestBody,
        @Part image: List<MultipartBody.Part>
    ): Call<CommonModel>


    @Headers("Accept: application/json")
    @GET("api/v1/plans/list")
    fun getPlans(
        @Header("Authorization") authorization: String
    ): Call<PlanModel>


    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/variants/{model_id}")
    fun getVariant(
        @Header("Authorization") authorization: String,
        @Path("model_id") model_id: Int
    ): Call<VariantModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/engines/{variant_id}")
    fun getEngine(
        @Header("Authorization") authorization: String,
        @Path("variant_id") variant_id: Int
    ): Call<VariantModel>

    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/distance-type")
    fun getType(
        @Header("Authorization") authorization: String,
    ): Call<DistanceTypeModel>


    @Headers("Accept: application/json")
    @GET("api/v1/notifications/read-all")
    fun readAllNotification(
        @Header("Authorization") authorization: String
    ): Call<CommonModel>
    @Headers("Accept: application/json")
    @GET("api/v1/vehicle/delete/{car_id}")
    fun deleteCar(
        @Header("Authorization") authorization: String,
        @Path("car_id") car_id: String,
    ): Call<CommonModel>

    @Headers("Accept: application/json")
    @GET("api/v1/digi-docs/list/{user_id}")
    fun getDocuments(
        @Header("Authorization") authorization: String,
        @Path("user_id") user_id: String,
    ): Call<ResponseDigiDocs>


    @FormUrlEncoded
    @Headers("Accept: application/json")
    @POST("api/v1/user/reminder-setting")
    fun reminderStatusChange(
        @Header("Authorization") authorization: String,
        @Field("name") name: String,
        @Field("is_enabled") is_enabled: Int
    ): Call<CommonModel>

    @POST("v1/customers")
    fun getCustomer(
        @Header("Authorization") Authorization: String,
    ): Call<CustomerModel>

    @FormUrlEncoded
    @POST("v1/ephemeral_keys")
    fun getEphemeralKeys(
        @Header("Authorization") Authorization: String,
        @Header("Stripe-Version") version: String,
        @Field("customer") customer: String
    ): Call<CustomerModel>

    @FormUrlEncoded
    @POST("v1/payment_intents")
    fun getPaymentIntent(
        @Header("Authorization") authorization: String,
        @Field("customer") customer: String,
        @Field("amount") amount: Int,
        @Field("currency") currency: String,
    ): Call<PaymentModel>
}