package codeflies.com.mcc.Helper

import android.app.ActivityManager
import android.app.DownloadManager
import android.content.Context
import android.net.Uri
import android.os.Environment
import android.widget.Toast
import java.io.File
import kotlin.math.min


class Constants {

    companion object {
        var IMAGE_URL = "https://carcoll.localserverpro.com/storage/app/public/"
        const val IMAGE_DIRECTORY = "MCC_Images"



        fun isAppIsInBackground(context: Context): Boolean {
            var isInBackground = true
            val am = context.getSystemService(Context.ACTIVITY_SERVICE) as ActivityManager
            val runningProcesses: List<ActivityManager.RunningAppProcessInfo> = am.runningAppProcesses
            for (processInfo in runningProcesses) {
                if (processInfo.importance == ActivityManager.RunningAppProcessInfo.IMPORTANCE_FOREGROUND) {
                    for (activeProcess in processInfo.pkgList) {
                        if (activeProcess == context.packageName) {
                            isInBackground = false
                        }
                    }
                }
            }
            return isInBackground
        }

        fun downloadFile(context: Context, title: String, url: String?) {
            if (url == null) {
                Toast.makeText(context, "Invalid file URL", Toast.LENGTH_SHORT).show()
                return
            }

            val sanitizedTitle =
                title.replace("[^a-zA-Z0-9.-]".toRegex(), "_").substring(0, min(title.length, 100))

            val directory =
                Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DOWNLOADS)
            val destinationUri = Uri.fromFile(File(directory, sanitizedTitle))

            val request = DownloadManager.Request(Uri.parse(url))
                .setTitle(sanitizedTitle)
                .setDescription("Downloading $sanitizedTitle...")
                .setNotificationVisibility(DownloadManager.Request.VISIBILITY_VISIBLE_NOTIFY_COMPLETED)
                .setDestinationUri(destinationUri)

            val downloadManager =
                context.getSystemService(Context.DOWNLOAD_SERVICE) as DownloadManager
            downloadManager.enqueue(request)
        }

        fun downloadPDF(context: Context, title: String, url: String?) {
            if (url == null || !url.endsWith(".pdf")) {
                Toast.makeText(context, "Invalid PDF URL or format", Toast.LENGTH_SHORT).show()
                return
            }

            downloadFile(context, title, url)
        }


        fun downloadImage(context: Context, title: String, url: String) {
            val request = DownloadManager.Request(Uri.parse(url))
                .setTitle(title)
                .setDescription("Downloading $title...")
                .setNotificationVisibility(DownloadManager.Request.VISIBILITY_VISIBLE_NOTIFY_COMPLETED)

            val downloadManager = context.getSystemService(Context.DOWNLOAD_SERVICE) as DownloadManager
            downloadManager.enqueue(request)

            Toast.makeText(context, "Downloading $title...", Toast.LENGTH_SHORT).show()
        }

    }


}