package codeflies.com.mcc.Helper

import android.content.Context
import android.content.Intent
import android.content.SharedPreferences
import android.os.Bundle
import android.os.Vibrator
import android.util.Log
import codeflies.com.mcc.Activity.CommonActivity
import codeflies.com.mcc.Activity.MainActivity
import codeflies.com.mcc.Activity.RepairDetailsActivity
import codeflies.com.mcc.Activity.ServiceDetailsActivity
import codeflies.com.mcc.Fragment.Car_DetailsFragment
import com.google.firebase.messaging.FirebaseMessagingService
import com.google.firebase.messaging.RemoteMessage

class MyFirebaseMessagingService : FirebaseMessagingService() {
    private val TAG: String = MyFirebaseMessagingService::class.java.simpleName

    private var notificationUtils: NotificationUtils? = null
    private val channelId = "channel-01"

    var id = ""
    var name = ""
    private var imageUrl: String? = null
    private var timestamp: String? = null
    private val pattern = longArrayOf(0, 100, 1000)
    private var sPref: SharedPreferences? = null
    private var v: Vibrator? = null

    override fun onMessageReceived(remoteMessage: RemoteMessage) {
        super.onMessageReceived(remoteMessage)
        Log.e(TAG, "From: " + remoteMessage.from)
        v = getSystemService(Context.VIBRATOR_SERVICE) as Vibrator

        if (remoteMessage.data.isNotEmpty()) {
            Log.e(TAG, "Data Payload: " + remoteMessage.data.toString())
            try {
                if (remoteMessage.data["type"].equals("vehicle")){
                    id = remoteMessage.data["id"].toString()
                    name = remoteMessage.data["name"].toString()
                }else if (remoteMessage.data["type"].equals("repair")){
                    id = remoteMessage.data["id"].toString()
                }else if (remoteMessage.data["type"].equals("service")){
                    id = remoteMessage.data["id"].toString()
                }
                handleDataMessage(remoteMessage.data["body"], remoteMessage.data["title"],remoteMessage.data["type"],)
            } catch (e: Exception) {
                Log.e(TAG, "Exception: " + e.message)
            }
        }
    }

    override fun onNewToken(token: String) {
        Log.d(TAG, "Refreshed token: $token")
    }

    private fun handleDataMessage(title: String?, desc: String?, type: String?) {
        try {

            if (type.equals("vehicle")){

                val fullScreenIntent = Intent(this, CommonActivity::class.java)
                    .setFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_NO_HISTORY)
                showNotificationMessage(applicationContext, desc, title,  fullScreenIntent)
                CommonActivity.titleTop = name

                val carDetailsFragment = Car_DetailsFragment()

                val bundle = Bundle()
                bundle.putString(
                    "vehicleId",
                    id
                ) // replace "vehicleId" with the actual key and item data
                carDetailsFragment.arguments = bundle

                CommonActivity.replaceFragment = carDetailsFragment

            }else if(type.equals("repair")){
                val fullScreenIntent = Intent(this, RepairDetailsActivity::class.java)
                    .setFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_NO_HISTORY)
                showNotificationMessage(applicationContext, desc, title,  fullScreenIntent)
                RepairDetailsActivity.vehicleId = id

            }else if (type.equals("service")){

                val fullScreenIntent = Intent(this, ServiceDetailsActivity::class.java)
                    .setFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_NO_HISTORY)
                showNotificationMessage(applicationContext, desc, title,  fullScreenIntent)
                ServiceDetailsActivity.serviceId = id

            }else{
                val fullScreenIntent = Intent(this, MainActivity::class.java)
                    .setFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK)
                    .addFlags(Intent.FLAG_ACTIVITY_NO_HISTORY)
                showNotificationMessage(applicationContext, desc, title,  fullScreenIntent)

            }

        } catch (e: Exception) {
            Log.e(TAG, "Json Exception: " + e.message)
        }
    }

    private fun showNotificationMessage(context: Context, title: String?, message: String?,  intent: Intent) {
        notificationUtils = NotificationUtils(context, channelId)
        intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP)
        notificationUtils!!.showNotificationMessage(title, message, intent)
    }

    private fun showNotificationMessageWithBigImage(context: Context, title: String?, message: String?,  intent: Intent, imageUrl: String?) {
        notificationUtils = NotificationUtils(context, channelId)
        intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP)
        notificationUtils!!.showNotificationMessage(title, message, intent, imageUrl)
    }

    override fun onDestroy() {
        super.onDestroy()
    }
}
