package codeflies.com.mcc.Helper


import android.app.NotificationChannel
import android.app.NotificationManager
import android.app.PendingIntent
import android.content.ContentResolver
import android.content.Context
import android.content.Intent
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.media.AudioManager
import android.media.MediaPlayer
import android.media.RingtoneManager
import android.net.Uri
import android.os.Build
import android.text.Html
import android.text.TextUtils
import android.util.Patterns
import androidx.core.app.NotificationCompat
import codeflies.com.mcc.R
import java.io.IOException
import java.io.InputStream
import java.net.HttpURLConnection
import java.net.URL
import java.text.ParseException
import java.text.SimpleDateFormat
import java.util.Locale

class NotificationUtils(private val mContext: Context, private val channelId: String) {

    companion object {
        const val NOTIFICATION_ID = 100
    }

    private var mMediaPlayer: MediaPlayer? = null

    fun showNotificationMessage(title: String?, message: String?,  intent: Intent) {
        showNotificationMessage(title, message, intent, null)
    }

    fun showNotificationMessage(title: String?, message: String?, intent: Intent, imageUrl: String?) {
        if (TextUtils.isEmpty(message)) return

        val icon = R.drawable.logo
        intent.flags = Intent.FLAG_ACTIVITY_CLEAR_TOP or Intent.FLAG_ACTIVITY_SINGLE_TOP
        val resultPendingIntent = PendingIntent.getActivity(mContext, 0, intent, PendingIntent.FLAG_MUTABLE)

        val alarmSound = Uri.parse(ContentResolver.SCHEME_ANDROID_RESOURCE + "://" + mContext.packageName + "/raw/noti.mp3")

        val mBuilder = NotificationCompat.Builder(mContext, channelId)
        val soundUri = RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION)

        if (!TextUtils.isEmpty(imageUrl)) {
            if (imageUrl != null && imageUrl.length > 4 && Patterns.WEB_URL.matcher(imageUrl).matches()) {
                val bitmap = getBitmapFromURL(imageUrl)
                if (bitmap != null) {
                    showBigNotification(bitmap, mBuilder, icon, title, message, resultPendingIntent, alarmSound)
                    playNotificationSound()
                } else {
                    showSmallNotification(mBuilder, icon, title, message,  resultPendingIntent, alarmSound)
                    playNotificationSound()
                }
            }
        } else {
            showSmallNotification(mBuilder, icon, title, message,  resultPendingIntent, alarmSound)
            playNotificationSound()
        }
    }

    private fun showSmallNotification(
        mBuilder: NotificationCompat.Builder,
        icon: Int,
        title: String?,
        message: String?,
        resultPendingIntent: PendingIntent,
        alarmSound: Uri
    ) {
        val soundUri = RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION)
        val notificationManager = mContext.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
        val inboxStyle = NotificationCompat.InboxStyle()
        inboxStyle.addLine(message)

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            val channel = NotificationChannel(channelId, "Channel human readable title", NotificationManager.IMPORTANCE_HIGH)
            notificationManager.createNotificationChannel(channel)
            mBuilder.setSmallIcon(R.drawable.logo)
                .setAutoCancel(true)
                .setContentTitle(title)
                .setContentIntent(resultPendingIntent)
                .setSound(alarmSound)
                .setStyle(inboxStyle)
                .setContentText(message)
                .setChannelId(channelId)
                .setStyle(NotificationCompat.BigTextStyle().bigText(message))
                .setSound(soundUri)
                .setPriority(NotificationManager.IMPORTANCE_HIGH)
        } else {
            mBuilder.setSmallIcon(R.drawable.logo)
                .setAutoCancel(true)
                .setContentTitle(title)
                .setContentIntent(resultPendingIntent)
                .setSound(alarmSound)
                .setStyle(inboxStyle)
                .setContentText(message)
                .setChannelId(channelId)
                .setStyle(NotificationCompat.BigTextStyle().bigText(message))
                .setSound(soundUri)
                .setPriority(NotificationManager.IMPORTANCE_HIGH)
        }

        notificationManager.notify(NOTIFICATION_ID, mBuilder.build())
    }

    private fun showBigNotification(
        bitmap: Bitmap,
        mBuilder: NotificationCompat.Builder,
        icon: Int,
        title: String?,
        message: String?,
        resultPendingIntent: PendingIntent,
        alarmSound: Uri
    ) {
        val soundUri = RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION)
        val bigPictureStyle = NotificationCompat.BigPictureStyle()
        bigPictureStyle.setBigContentTitle(title)
        bigPictureStyle.setSummaryText(Html.fromHtml(message).toString())
        bigPictureStyle.bigPicture(bitmap)

        val notificationManager = mContext.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            val channel = NotificationChannel(channelId, "Channel human readable title", NotificationManager.IMPORTANCE_HIGH)
            notificationManager.createNotificationChannel(channel)
            mBuilder.setSmallIcon(R.drawable.logo)
                .setAutoCancel(true)
                .setContentTitle(title)
                .setContentIntent(resultPendingIntent)
                .setSound(alarmSound)
                .setStyle(bigPictureStyle)
                .setContentText(message)
                .setChannelId(channelId)
                .setStyle(NotificationCompat.BigTextStyle().bigText(message))
                .setSound(soundUri)
                .setPriority(NotificationManager.IMPORTANCE_HIGH)
        } else {
            mBuilder.setSmallIcon(R.drawable.logo)
                .setAutoCancel(true)
                .setContentTitle(title)
                .setContentIntent(resultPendingIntent)
                .setSound(alarmSound)
                .setStyle(bigPictureStyle)
                .setContentText(message)
                .setChannelId(channelId)
                .setStyle(NotificationCompat.BigTextStyle().bigText(message))
                .setSound(soundUri)
                .setPriority(NotificationManager.IMPORTANCE_HIGH)
        }

        notificationManager.notify(NOTIFICATION_ID, mBuilder.build())
    }

    private fun getBitmapFromURL(strURL: String): Bitmap? {
        return try {
            val url = URL(strURL)
            val connection = url.openConnection() as HttpURLConnection
            connection.doInput = true
            connection.connect()
            val input: InputStream = connection.inputStream
            BitmapFactory.decodeStream(input)
        } catch (e: IOException) {
            e.printStackTrace()
            null
        }
    }

    private fun playNotificationSound() {
        try {

            mMediaPlayer = MediaPlayer()
            mMediaPlayer = MediaPlayer.create(mContext, R.raw.noti)
            mMediaPlayer!!.setAudioStreamType(AudioManager.STREAM_MUSIC)
            mMediaPlayer!!.prepare()
            mMediaPlayer!!.start()
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    fun cancelNotification() {
        mMediaPlayer?.stop()
    }

    fun getTimeMilliSec(timeStamp: String?): Long {
        val format = SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.getDefault())
        return try {
            val date = format.parse(timeStamp)
            date?.time ?: 0
        } catch (e: ParseException) {
            e.printStackTrace()
            0
        }
    }



    fun clearNotifications() {
        val notificationManager = mContext.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
        notificationManager.cancelAll()
    }
}
