package codeflies.com.mcc.Payment

import android.os.Bundle
import android.util.Log
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.Helper.RetrofitClient
import codeflies.com.mcc.Helper.Utils.Publishable_key
import codeflies.com.mcc.Helper.Utils.Secret_key
import codeflies.com.mcc.Model.CustomerModel
import codeflies.com.mcc.Model.PaymentModel
import codeflies.com.mcc.databinding.ActivityStripePaymentBinding
import com.github.kittinunf.fuel.httpPost
import com.github.kittinunf.fuel.json.responseJson
import com.github.kittinunf.result.Result
import com.stripe.android.PaymentConfiguration
import com.stripe.android.paymentsheet.PaymentSheet
import com.stripe.android.paymentsheet.PaymentSheetResult
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class StripePayment : AppCompatActivity() {

    private lateinit var binding: ActivityStripePaymentBinding
    var ClientSecret = ""
    var customerId = ""
    var EmphericalKey = ""
    lateinit var paymentSheet: PaymentSheet
    lateinit var customerConfig: PaymentSheet.CustomerConfiguration
    lateinit var paymentIntentClientSecret: String
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityStripePaymentBinding.inflate(layoutInflater)
        setContentView(binding.root)

        paymentSheet = PaymentSheet(this, ::onPaymentSheetResult)
        "http://example.com/payment-sheet/payment-sheet".httpPost().responseJson { _, _, result ->
            if (result is Result.Success) {
                val responseJson = result.get().obj()
                paymentIntentClientSecret = responseJson.getString("paymentIntent")
                customerConfig = PaymentSheet.CustomerConfiguration(
                    responseJson.getString("customer"),
                    responseJson.getString("ephemeralKey")
                )
                val publishableKey = responseJson.getString(Publishable_key)
                PaymentConfiguration.init(this, publishableKey)
            }
        }


        binding.payment.setOnClickListener {
            presentPaymentSheet()
        }


    }


    private fun getCustomer() {
        val call = RetrofitClient.apiServiceStripe.getCustomer(
            "Bearer $Secret_key"
        )
        call.enqueue(object : Callback<CustomerModel> {
            override fun onResponse(call: Call<CustomerModel>, response: Response<CustomerModel>) {
                if (response.isSuccessful) {
                    customerId = response.body()?.id.toString()
                    getEphemeralKeys("Bearer $Secret_key", response.body()?.id.toString())
                    Log.e("StripeData", "get Customer " + response.body()?.id.toString())
                } else {
                    // Handle unsuccessful response
                    Log.e("StripeData", "get Customer " + response.code())
                }
            }

            override fun onFailure(call: Call<CustomerModel>, t: Throwable) {
                // Handle failure
                Log.e("StripeData", "get Customer " + t.message.toString())

            }
        })
    }

    private fun getEphemeralKeys(authorization: String, customer: String) {
        val call =
            RetrofitClient.apiServiceStripe.getEphemeralKeys(authorization, "2022-11-15", customer)
        call.enqueue(object : Callback<CustomerModel> {
            override fun onResponse(call: Call<CustomerModel>, response: Response<CustomerModel>) {
                if (response.isSuccessful) {
                    EmphericalKey = response.body()?.id.toString()
                    getPaymentIntent(authorization, customer, 1099, "eur")
                    Log.e("StripeData", "get Ephemeral $EmphericalKey")
                } else {
                    Log.e("StripeData", "get Ephemeral ${response.code()}")
                }
            }

            override fun onFailure(call: Call<CustomerModel>, t: Throwable) {
                Log.e("StripeData", "get Customer ${t.message.toString()}")
            }
        })
    }
    private fun getPaymentIntent(authorization: String, customer: String, amount: Int, currency: String) {
        val call = RetrofitClient.apiServiceStripe.getPaymentIntent(
            authorization,
            customer,
            amount,
            currency
        )
        call.enqueue(object : Callback<PaymentModel> {
            override fun onResponse(call: Call<PaymentModel>, response: Response<PaymentModel>) {
                if (response.isSuccessful) {
                    Log.e(
                        "StripeData",
                        "get Intent Secret Key " + response.body()?.client_secret.toString()
                    )
                    ClientSecret = response.body()?.client_secret.toString()

                } else {
                    Log.e("StripeData", "get Ephemeral " + response.code())
                }
            }

            override fun onFailure(call: Call<PaymentModel>, t: Throwable) {
                // Handle failure
                Log.e("StripeData", "get Customer " + t.message.toString())

            }
        })
    }

    private fun onPaymentSheetResult(paymentSheetResult: PaymentSheetResult) {
        when (paymentSheetResult) {
            is PaymentSheetResult.Canceled -> {
                print("Canceled")
            }

            is PaymentSheetResult.Failed -> {
                print("Error: ${paymentSheetResult.error}")
            }

            is PaymentSheetResult.Completed -> {
                // Display for example, an order confirmation screen
                print("Completed")
            }
        }
    }


    fun presentPaymentSheet() {
        paymentSheet.presentWithPaymentIntent(
            paymentIntentClientSecret,
            PaymentSheet.Configuration(
                merchantDisplayName = "My merchant name",
                customer = customerConfig,
                // Set `allowsDelayedPaymentMethods` to true if your business handles
                // delayed notification payment methods like US bank accounts.
                allowsDelayedPaymentMethods = true
            )
        )
    }
}